function CamProfileDesign(Action, Argument2)
% This program allows users to specify eight segments of the profile in a 360 deg cycle.
% Therefore, eight sets of h_start, h_end, h_Hs, h_He and h_popup are generated.
% h_start: its value specifies the segment starting angle. The first one should be 0.
% h_Hs: its value specifies the height of the starting angle
% h_end: its value specifies the segment ending angle. The last one should be 360.
% h_He: its value specifies the height of the ending angle
% h_popup: its value specifies the calculation method.
%  		  its userdata specifies the total number of segment.

%load profileWindow
global outputData;
if nargin == 0 & isempty(findobj('Tag','cam_profile_dsgn'))
	Action = 'initialize';
elseif nargin == 0 & findobj('Tag','cam_profile_dsgn')
   Action = 'None';
end

if ~strcmp(Action,'initialize') 
% To retrieve handles for uicontrols   
   a = findobj('Tag','cam_profile_dsgn');
   handles = get(a,'UserData');
   h_start = handles(1:8);
	h_Hs = handles(9:16);
	h_end = handles(17:24);
	h_He = handles(25:32);
   h_popup = handles(33:40);
   h_status = handles(41);
   set(h_status,'String','');
%   if judge == 1
%		direction = '+';
%	else      
      direction = '-';
%   end
%	ainc = get(h_inc,'userdata');
	% To retrieve graphics handles
	seg_number = get(h_popup(1),'userdata');
   for i = 1:seg_number
      start(i) = get(h_start(i),'userdata');
      ending(i) = get(h_end(i),'userdata');
      Hs(i) = get(h_Hs(i),'userdata');
      He(i) = get(h_He(i),'userdata');
   end
   b = findobj('Tag','cam_profile_axes');   
   handles =get(b,'UserData');
   position = handles(1);
   velocity = handles(2);
   acceleration = handles(3);
   if findobj('Tag','cam_dsgn')
   	c = findobj('Tag','cam_dsgn');
      handles = get(a,'UserData');
      dtheta = get(handles(11),'userdata')
   else
      dtheta = 5;
   end
end
switch Action
case 'None' 
	findobj('Tag','cam__profile_dsgn');

case 'initialize'
   OpenProfileFig;
   CamProfileDesign('Draw Axes');
   
case 'Draw Axes' 
   fact=pi/180;

% Compute the displacement of the flat-faced follower.  The variable
% dtheta will change the resolution of the cam.  Make it smaller for
% accurate results.
%rise = 5;
%   dtheta=ainc;
%   if direction=='+'
%   	dtheta=-ainc;
%   end
   temp=-dtheta;
   n=abs(360/dtheta);

% Plot the displacement profile, velocity and acceleration for 
% the follower.  Start by normalizing f, fp, and fpp
   
%   temp=-1;
      
   for i = 1:seg_number
      type = He(i) - Hs(i);
      if type == 0		% Dwell
         nType = 1; 
      elseif type > 0	% Rise
			nType = 2;      
		else					% Return
         nType = 3;
      end
      nMethod = get(h_popup(i),'Value');
      nstart = ceil((start(i)+1)/dtheta);
      nstop = floor((ending(i)+1)/dtheta);
      n = ceil((ending(i)-start(i))/dtheta);
      for j=nstart:nstop
         temp=temp+dtheta;
         thetal(j)=temp;
         switch nMethod
         case 1
      	  [coords]=follower_uni(thetal(j),Hs(i),He(i),nType,start(i),ending(i));
         case 2
      	  [coords]=follower_par(thetal(j),Hs(i),He(i),nType,start(i),ending(i));
         case 3
      	  [coords]=follower_har(thetal(j),Hs(i),He(i),nType,start(i),ending(i));
         case 4
      	  [coords]=follower_poly(thetal(j),Hs(i),He(i),nType,start(i),ending(i));
         case 5
      	  [coords]=follower_cyc(thetal(j),Hs(i),He(i),nType,start(i),ending(i));
         end
      	fl(j)=coords(1);	
      	flp(j)=coords(2);
      	flpp(j)=coords(3);
      end
   end
   profileRes = [fl;flp;flpp];
   set(h_status,'Userdata',profileRes);
   fmax=max(fl);
   fmin=min(fl);
   fpmax=max(flp);
   fpmin=min(flp);
   fppmax=max(flpp);
   fppmin=min(flpp);
   fn=max([abs(fmax), abs(fmin)]);
   fpn=max([abs(fpmax), abs(fpmin)]);
   fppn=max([abs(fppmax), abs(fppmin)]);
   fnorm=fl/fn;
   fpnorm=flp/fpn;
   if fppn == 0
      fppn == 1;
   end
   fppnorm=flpp/fppn;

% Set up the axes for displacement drawing.

   width=0.9;
   height=0.8;
   hdl = findobj('tag','cam_profile_axes');
   axes(hdl);
   %xlabel('Cam Angle','color', 'k')
   %ylabel('Follower Displacement, Velocity, and Acceleration','color', 'k')
   %title('\it{Follower Displacement Diagram}','color', 'r','fontsize', 12)

   xpmin=0;
   xpmax=365;
   ypmina=min([min(fnorm), min(fpnorm), min(fppnorm)]);
   ypmaxa=max([max(fnorm), max(fpnorm), max(fppnorm)]);
   yprange=ypmaxa-ypmina;
   ypmin=ypmina-0.1*yprange;
   ypmax=ypmaxa+0.1*yprange;
   axis([xpmin xpmax ypmin ypmax]);
   
   set(hdl, 'XTick',[0 40 80 120 160 200 240 280 320 360]);
   set(position,'xdata',thetal, 'ydata',fnorm);
   set(velocity,'xdata',thetal,'ydata', fpnorm);
   set(acceleration,'xdata',thetal, 'ydata',fppnorm);
%   text(10, -0.4,['Max. Pos. is: ', num2str(fn) ], 'color', 'r');
%   text(10, -0.5,['Max. Vel. is: ', num2str(fpn), ' ( \omega', ' )' ],'color', 'b');
%   text(10, -0.6,['Max. Acc. is: ', num2str(fppn), ' ( \omega^2', ' )' ], 'color', 'k');

case 'Change Start'
   n = Argument2;
   newval = get(h_start(n),'string');
   oldval = get(h_start(n),'userdata');
	val=check_val(oldval,newval);
   set(h_start(n),'UserData',val,'string',num2str(val));
   set(h_popup(2),'Userdata',n);
   
   % For the consistence, the value of h_start(n) should be the same as the value 
   % of h_end(n-1)
   if n~= 1
      if val > 0
         set(h_end(n-1),'UserData',val,'string',num2str(val));
      end
   end
   if(n>seg_number)
	   set(h_popup(1),'Userdata',n);
   end
   
case 'Change End'
   n = Argument2;
   newval = get(h_end(n),'string');
   oldval = get(h_end(n),'userdata');
	val=check_val(oldval,newval);
   set(h_end(n),'UserData',val,'string',num2str(val));
   n2 = get(h_popup(2),'Userdata');
   
   % If the value of h_end(n) does not equals 360, it is not the last h_end. Then for
   % the consistence, the value of h_end(n) should be the same as the value 
   % of h_start(n+1)
   if val < 360
      set(h_start(n+1),'string',num2str(val),'Userdata',val);
      start(n+1) = val;
      set(h_popup(2),'Userdata',n+1);
   	set(h_popup(1),'Userdata',n+1);
   end
   % n is the index of current modified h_end
   % n2 is the last modified h_start.
   % Because we set up the total seqment number while users specify the value of 
   % h_end, we don't want to make mistake if users only go back to modify the previous
   % value of h_end. Therefore, the total segment number stored in the userdata of
   % h_popup(1) is set up a new value only when users add new segment, that is, n>n2.
   if n > n2
      set(h_popup(2),'Userdata',n);
   	set(h_popup(1),'Userdata',n);
   end
   
   if val == 360
      for j = n+1:8
      	set(h_start(j),'string','');
      	set(h_Hs(j),'string','');
      	set(h_end(j),'string','');
      	set(h_He(j),'string','');
      end  
   	set(h_popup(1),'Userdata',n);    
   end
   
case 'Change Hs'
   n = Argument2;
   newval = get(h_Hs(n),'string');
   oldval = get(h_Hs(n),'userdata');
	val=check_val(oldval,newval);
	set(h_Hs(n),'UserData',val,'string',num2str(val));
   set(h_popup(2),'Userdata',n);
   
   % For the consistence, the value of h_Hs(n) should be the same as the value 
   % of h_He(n-1)
   if n~= 1
      if val > 0
         set(h_He(n-1),'UserData',val,'string',num2str(val));
      end
   end
   if(n>seg_number)
	   set(h_popup(1),'Userdata',n);
   end
   
case 'Change He'
   n = Argument2;
   newval = get(h_He(n),'string');
   oldval = get(h_He(n),'userdata');
	val=check_val(oldval,newval);
   set(h_He(n),'UserData',val,'string',num2str(val));
   n2 = get(h_popup(2),'Userdata');
   if ((n < seg_number) | (n < n2))
   	set(h_Hs(n+1),'string',num2str(val),'Userdata',val);
   end
   
   
case 'New'
   set(h_end(1),'String','');
   set(h_He(1),'String','','Userdata',0);
   for i = 2:8
      set(h_start(i),'String','');
      set(h_end(i),'String','');
      set(h_Hs(i),'String','','Userdata',0);
      set(h_He(i),'String','','Userdata',0);
   end
   
case 'Display'
   n2 = get(h_popup(2),'Userdata');
   
   % Check if the value of h_end for the last segment is missing.
   % If it is, add the last h_end and assign proper values to its attribute
   if ~(seg_number > n2)
      seg_number = n2;
      set(h_popup(1),'Userdata',n2);
%      set(h_end(n2),'String','360');
% 		CamProfileDesign('Change End',n2);     
      set(h_end(n2),'Userdata',360,'String','360');
      set(h_He(n2),'Userdata',0,'String','0');
      ending(n2) = 360;
      He(n2) = 0;
      set(h_popup(n2),'Value',2);
   end
   
   % Check if the final height is zero. If not, modify the value and show 
   % error message to users
   
   if He(seg_number) ~= 0
      set(h_He(seg_number),'Userdata',0,'String','0');
      set(h_status,'String','The endingg height should be zero');
      return
   end
   for i = 1:seg_number
      if ending(i) <= start(i)
         set(h_status,'String','number input inconsistent');
         return
      end
   end
   
   CamProfileDesign('Draw Axes'); 
   refresh;
   
end

function OpenProfileFig()
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Control the color of the UI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
StdColor = get(0,'DefaultUIcontrolBackgroundColor');
hdls = zeros(40,0);
bgframe = StdColor;
bgedit = [1 1 1];
bgtext = bgframe;
strPopup1 = ['Uniform         ';...
             'Parabolic       ';...
             'Harmonic        ';...
             'Polynomial (5th)';...
             'Cycloidal       '];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The Main Figure of Cam Profile Design
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ScreenSize = get(0,'ScreenSize');
sx = 425;
sy = 500;
FigPos = [ 500 ScreenSize(4)-sy-40 sx sy ] ;

a = figure('Units','pixels', ...
	'Color',[0.8 0.8 0.8], ...
	'Name','Cam Profile Window', ...
	'NumberTitle','off', ...
   'Position',FigPos, ...
  	'Tag','cam_profile_dsgn');
b = axes('Parent',a, ...
	'Box','on', ...
	'CameraUpVector',[0 1 0], ...
	'Color',[1 1 1], ...
	'Position',[0.0047 0.4778 0.69178 0.5202], ...
	'Tag','cam_profile_axes');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Menu controls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h_menu = uimenu('Parent',a, ...
	'Label','Parameter', ...
	'Tag','menu_parameter');
b = uimenu('Parent',h_menu, ...
	'Callback','CamProfileDesign(''Get File'')', ...
	'Label','Load Parameters', ...
	'Tag','submenu_load');
b = uimenu('Parent',h_menu, ...
	'Callback','CamProfileDesign(''Put File'',1)', ...
	'Label','Save Parameters', ...
	'Tag','submenu_save1');
b = uimenu('Parent',h_menu, ...
	'Callback','CamProfileDesign(''Put File'',2)', ...
	'Label','Save Result Data', ...
	'Tag','submenu_save2');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Frame controls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.0071 0.0060 0.9906 0.4657], ...
	'Style','frame', ...
	'Tag','Frame6');
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.7035 0.4798 0.2918 0.5141], ...
	'Style','frame');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Popup menu controls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h_popup(1) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',StdColor, ...
	'Position',[0.6 0.3669 0.3835 0.05], ...
   'String',strPopup1, ...
	'Style','popupmenu', ...
   'Userdata',4, ...
	'Value',5);
h_popup(2) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',StdColor, ...
	'Position',[0.6 0.3165 0.3835 0.05], ...
   'String',strPopup1, ...
   'Style','popupmenu', ...
   'Userdata',4, ...
	'Value',5);
h_popup(3) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',StdColor, ...
	'Position',[0.6 0.2661 0.3835 0.05], ...
   'String',strPopup1, ...
	'Style','popupmenu', ...
	'Value',5);
h_popup(4) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',StdColor, ...
	'Position',[0.6 0.2157 0.3835 0.05], ...
   'String',strPopup1, ...
	'Style','popupmenu', ...
	'Value',5);
h_popup(5) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',StdColor, ...
	'Position',[0.6 0.1653 0.3835 0.05], ...
   'String',strPopup1, ...
	'Style','popupmenu', ...
	'Value',1);
h_popup(6) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',StdColor, ...
	'Position',[0.6 0.1149 0.3835 0.05], ...
   'String',strPopup1, ...
	'Style','popupmenu', ...
	'Value',1);
h_popup(7) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',StdColor, ...
	'Position',[0.6 0.0645 0.3835 0.05], ...
   'String',strPopup1, ...
	'Style','popupmenu', ...
	'Value',1);
h_popup(8) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',StdColor, ...
	'Position',[0.6 0.0141 0.3835 0.05], ...
   'String',strPopup1, ...
	'Style','popupmenu', ...
	'Value',1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Editable box controls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h_start(1) = uicontrol('Parent',a, ...
   'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Start'',1)', ...
	'Position',[0.061 0.3669 0.086 0.05], ...
   'String','0', ...
   'Userdata',0, ...
   'Enable','off', ...
	'Style','edit');
h_start(2) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Start'',2)', ...
	'Position',[0.061 0.3165 0.086 0.05], ...
   'Userdata',90, ...
	'String','90', ...
	'Style','edit');
h_start(3) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Start'',3)', ...
	'Position',[0.061 0.2661 0.086 0.05], ...
   'Userdata',180, ...
	'String','180', ...
	'Style','edit');
h_start(4) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Start'',4)', ...
	'Position',[0.061 0.2157 0.086 0.05], ...
   'Userdata',240, ...
	'String','240', ...
	'Style','edit');
h_start(5) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Start'',5)', ...
	'Position',[0.061 0.1653 0.086 0.05], ...
	'String','', ...
	'Style','edit');
h_start(6) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Start'',6)', ...
	'Position',[0.061 0.1149 0.086 0.05], ...
	'String','', ...
	'Style','edit');
h_start(7) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Start'',7)', ...
	'Position',[0.061 0.0645 0.086 0.05], ...
	'String','', ...
	'Style','edit');
h_start(8) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Start'',8)', ...
	'Position',[0.061 0.0141 0.086 0.05], ...
	'String','', ...
	'Style','edit');
h_Hs(1) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Hs'',1)', ...
	'Position',[0.151 0.3669 0.14 0.05], ...
   'Enable','off', ...
   'Userdata',0, ...
	'String','0', ...
	'Style','edit');
h_Hs(2) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Hs'',2)', ...
	'Position',[0.151 0.3165 0.14 0.05], ...
   'Userdata',0, ...
	'String','0', ...
	'Style','edit');
h_Hs(3) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Hs'',3)', ...
	'Position',[0.151 0.2661 0.14 0.05], ...
   'Userdata',5, ...
	'String','5', ...
	'Style','edit');
h_Hs(4) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Hs'',4)', ...
	'Position',[0.151 0.2157 0.14 0.05], ...
   'Userdata',5, ...
	'String','5', ...
	'Style','edit');
h_Hs(5) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Hs'',5)', ...
	'Position',[0.151 0.1653 0.14 0.05], ...
   'Userdata',0, ...
	'String','', ...
	'Style','edit');
h_Hs(6) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Hs'',6)', ...
	'Position',[0.151 0.1149 0.14 0.05], ...
   'Userdata',0, ...
	'String','', ...
	'Style','edit');
h_Hs(7) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Hs'',7)', ...
	'Position',[0.151 0.0645 0.14 0.05], ...
   'Userdata',0, ...
	'String','', ...
	'Style','edit');
h_Hs(8) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change Hs'',8)', ...
	'Position',[0.151 0.0141 0.14 0.05], ...
   'Userdata',0, ...
	'String','', ...
	'Style','edit');
h_end(1) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change End'',1)', ...
	'Position',[0.333 0.3669 0.086 0.05], ...
   'Userdata',90, ...
	'String','90', ...
	'Style','edit');
h_end(2) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change End'',2)', ...
	'Position',[0.333 0.3165 0.086 0.05], ...
   'Userdata',180, ...
	'String','180', ...
	'Style','edit');
h_end(3) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change End'',3)', ...
	'Position',[0.333 0.2661 0.086 0.05], ...
   'Userdata',240, ...
	'String','240', ...
	'Style','edit');
h_end(4) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change End'',4)', ...
	'Position',[0.333 0.2157 0.086 0.05], ...
   'Userdata',360, ...
	'String','360', ...
	'Style','edit');
h_end(5) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change End'',5)', ...
	'Position',[0.333 0.1653 0.086 0.05], ...
   'Userdata',0, ...
	'String','', ...
	'Style','edit');
h_end(6) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change End'',6)', ...
	'Position',[0.333 0.1149 0.086 0.05], ...
   'Userdata',0, ...
	'String','', ...
	'Style','edit');
h_end(7) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change End'',7)', ...
	'Position',[0.333 0.0645 0.086 0.05], ...
   'Userdata',0, ...
	'String','', ...
	'Style','edit');
h_end(8) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0.8 0 0.2], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change End'',8)', ...
	'Position',[0.333 0.0141 0.086 0.05], ...
   'Userdata',0, ...
	'String','', ...
	'Style','edit');
h_He(1) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change He'',1)', ...
	'Position',[0.423 0.3669 0.14 0.05], ...
   'Userdata',0, ...
	'String','0', ...
	'Style','edit');
h_He(2) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change He'',2)', ...
	'Position',[0.423 0.3165 0.14 0.05], ...
   'Userdata',5, ...
	'String','5', ...
	'Style','edit');
h_He(3) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change He'',3)', ...
	'Position',[0.423 0.2661 0.14 0.05], ...
   'Userdata',5, ...
	'String','5', ...
	'Style','edit');
h_He(4) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change He'',4)', ...
	'Position',[0.423 0.2157 0.14 0.05], ...
   'Userdata',0, ...
	'String','0', ...
	'Style','edit');
h_He(5) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change He'',5)', ...
	'Position',[0.423 0.1653 0.14 0.05], ...
   'Userdata',0, ...
	'String','', ...
	'Style','edit');
h_He(6) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change He'',6)', ...
	'Position',[0.423 0.1149 0.14 0.05], ...
   'Userdata',0, ...
	'String','', ...
	'Style','edit');
h_He(7) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change He'',7)', ...
	'Position',[0.423 0.0645 0.14 0.05], ...
   'Userdata',0, ...
	'String','', ...
	'Style','edit');
h_He(8) = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'ForegroundColor',[0 0.7 0.3], ...
	'BackgroundColor',[1 1 1], ...
	'Callback','CamProfileDesign(''Change He'',8)', ...
	'Position',[0.423 0.0141 0.14 0.05], ...
   'Userdata',0, ...
	'String','', ...
	'Style','edit');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Push button controls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',StdColor, ...
	'Callback','CamProfileDesign(''New'')', ...
	'Position',[0.792 0.9052 0.1773 0.0625], ...
	'String','New', ...
	'Tag','CloseButon');
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',StdColor, ...
	'Callback','CamProfileDesign(''Display'')', ...
	'Position',[0.792 0.8306 0.1773 0.0625], ...
	'String','Display', ...
	'Tag','CloseButon');
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',StdColor, ...
	'Callback','CamProfileDesign(''Analysis'')', ...
	'Position',[0.792 0.621 0.1773 0.0625], ...
	'String','Analysis', ...
	'Tag','AnalysisButton');
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',StdColor, ...
	'Callback','CamProfileDesign(''Close'')', ...
	'Position',[0.792 0.6915 0.1773 0.0625], ...
	'String','Close', ...
	'Tag','CloseButon');
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',StdColor, ...
	'Callback','CamProfileDesign(''Help'')', ...
	'Position',[0.792 0.758 0.1773 0.0625], ...
	'String','Info', ...
	'Tag','InfoButton');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Text controls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.0565 0.418 0.095 0.035], ...
	'String','from', ...
	'Style','text');
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.14 0.418 0.167 0.035], ...
	'String','at height', ...
	'Style','text');
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.339 0.418 0.095 0.035], ...
	'String','to', ...
	'Style','text');
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.41 0.418 0.167 0.035], ...
	'String','at height', ...
	'Style','text');
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6941 0.418 0.207 0.035], ...
	'String','method', ...
	'Style','text');
h_status = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.71 0.5 0.28 0.0625], ...
	'String','message', ...
	'Style','text');

% Set up vectors to be drawn in the follower displacement plot
hdls = [h_start h_Hs h_end h_He h_popup h_status];
a = findobj('Tag','cam_profile_dsgn');
set(a,'userdata',hdls);
position=line('xdata', [], 'ydata' ,[], 'linewidth',1,...
   'erasemode', 'none','linestyle', '-', 'color', 'r');
velocity=line('xdata', [], 'ydata' ,[], 'linewidth',0.75,...
   'erasemode', 'none','linestyle', '--','color', 'b');
acceleration=line('xdata', [], 'ydata' ,[], 'linewidth' ,0.5, 'erasemode',...
   'none','linestyle', '-.','color', 'k');
hdls = [position velocity acceleration];
b = findobj('Tag','cam_profile_axes');
set(b,'userdata',hdls);
%if nargout > 0, fig = a; end

function val=check_val(oldval,newval)
% Check if the user input is number input
% if not, retrieve the previous value in userdata
val=zeros(1);

if ~isequal(length(oldval),length(str2num(newval))),
  	val=oldval;
%	set(findobj(gcf,'Tag','status_txt'),'String', ...
%   ['Warning: An invalid property value has been entered.']);
else
   val=round(str2num(newval));
   if val < 0
      val = oldval;
      set(h_status,'String','Negative number is not allowed');
   end
end
