function []=FFCamDesign(Action,Argument2)
% ff_cam.m 
%
% This program determines the cam profile for a translating flat-faced
% follower.  

% Variables for calculation 
%   rb=base circle radius
%   tmin=length of follower face below centerline of stem
%   tmax=lenght of follower face above centerline of stem
%   xc=x coordinate of cam point
%   yc=y coordinate of cam point
%   rise = maximum follower displacement
%   direction = direction of cam rotation [CW(-), CCW(+)]
%   ainc = cam rotation angle increment (deg)

%   Graphics Variables

%   h1=handle on the first axes in the window (cam animation)
%   h2=handle on the second axes in the window (displacement diagram)
%   h3=handle on the fourth axes in the window (pressure angle)
%   Displ=line representing the follower displacement
%   dbead=bead which follows the displacement throughout the animation
%   stem=line for follower stem
%   face=line for follower face
%   cam=line for cam
%   baset=line for top of slider guide
%   baseb=line for bottom of slider guide
%   pin=line for the cam axis
%   bush=line representing the cam bushing
%   xmin, xmax= x limits for the axes
%   ymin, ymax= y limits for the axes

% program 
global g_AnaRes
%g_AnaRes = zeros(36,3);
if nargin == 0 & isempty(findobj('Tag','ff_cam_dsgn'))
	Action = 'initialize';
elseif nargin == 0 & findobj('Tag','ff_cam_dsgn')
   Action = 'None';
end

if ~strcmp(Action,'initialize') 
% To retrieve handles for uicontrols   
   a = findobj('Tag','ff_cam_dsgn');
   handles = get(a,'UserData');
   h_popupmenu = handles(1);
	h_length = handles(2:9);
	h_inc = handles(10);
	h_Dradio = handles(11:12);
%Input the linkage variables	
	rb = get(h_length(1),'userdata');
	rise = get(h_length(2),'userdata');
	tmax = get(h_length(3),'userdata');	
   tmin = get(h_length(4),'userdata');
   judge = get(h_Dradio(1),'value');
   if judge == 1
		direction = '+';
	else      
      direction = '-';
   end
	ainc = get(h_inc,'userdata');;
   if ~strcmp(Action,'Change Cam Style')  
% To retrieve graphics handles   
      b = findobj('Tag','ff_cam_axes');   
      handles =get(b,'UserData');
      cam = handles(1);
      stem = handles(2);
      face = handles(3);
      baset = handles(4);
      baseb = handles(5);
      bush = handles(6);
      pin = handles(7);
      
   end
end
switch Action
case 'None' 
findobj('Tag','ff_cam_dsgn');

case 'initialize'
   LocalOpenFig;
   FFCamDesign('Change Cam Style');  
   FFCamDesign('Draw Axes');
   
case 'Draw Axes'   
   fact=pi/180;

% Compute the displacement of the flat-faced follower.  The variable
% dtheta will change the resolution of the cam.  Make it smaller for
% accurate results.
		
   dtheta=ainc;
   sign=1;
   if direction=='+'
   	dtheta=-ainc;
   	sign=-1;
   end
   temp=-dtheta;
   n=abs(360/dtheta);

% Compute the follower displacement and follower center coordinates 
% relative to cam.

   for j=1:1:n
   	temp=temp+dtheta;
   	theta(j)=temp;
   	camangle(j)=abs(theta(j));
   	[coords]=follower(camangle(j),rise);
   	f(j)=coords(1);	
   	fp(j)=coords(2);
   	fpp(j)=coords(3);
   	tt=theta(j)*fact;
   	ct=cos(tt);
   	st=sin(tt);
   	xc(j)=(rb+f(j))*ct-sign*fp(j)*st;
   	yc(j)=(rb+f(j))*st+sign*fp(j)*ct;
   	rho(j)=rb+f(j)+	fpp(j);
   end
   thetaa = theta';
   xcc = xc';
   ycc = yc';
   g_AnaRes = [thetaa xcc ycc];

   xc(n+1)=xc(1);
   yc(n+1)=yc(1);


% If rho is large, truncate it for drawing purposes

   rhom=2*sqrt((max(xc))^2+(max(yc))^2);
   for j=1:1:n
   	rhod(j)=rho(j);
   	if abs(rho(j))>rhom
   		rhod(j)=rhom*rho(j)/abs(rho(j));
   	end
   end
	
% Set up coordinates of bushings and pins.

   rpivot=rb/10;
   ninc=20;  
   npoints=ninc+1;
   centerx=0;
   centery=0;
   coord=circle2(rpivot,centerx,centery,ninc);

% find coordinates of cam pin

   for i=1:1:npoints
   	xcoordcp(i)=coord(i,1);
   	ycoordcp(i)=coord(i,2);
   end

% Find coordinates of cam bushing

   binc=ninc/2;
   coord1=bushing(rpivot,centerx,centery,binc,0);
   bpoints=ninc/2+16;
   for i=1:1:bpoints
   	xbush(i)=coord1(i,1);
   	ybush(i)=coord1(i,2);
   end

% Set up coordinates of follower face in position 1.

   flag=1;
   npointf=ninc+1;
   x0=xc(1);
   y0=yc(1)-tmin;
   height=tmax+tmin;
   length=0.1*height;
   angle=0;
   coord = rect(length,height,x0,y0,angle,flag);

% find coordinates of follower face

   for i=1:1:5
   	xcoordf(i)=coord(i,1);
   	ycoordf(i)=coord(i,2);
   end

% Find coordinates of follower stem

   centerxf=x0+length;
   centeryf=0;
   xstem(1)=centerxf;
   ystem(1)=centeryf+length/2;
   xstem(2)=xstem(1)+2*rise;
   ystem(2)=ystem(1);
   xstem(4)=centerxf;
   ystem(4)=centeryf-length/2;
   xstem(3)=xstem(2);
   ystem(3)=ystem(4);

% set up coordinates of top sliderline.
		
   length=rise;
   ndash=8;
   xe = xstem(1)+rise;
   ye = ystem(1)+0.3*(ystem(1)-ystem(3));
   flag=-1;
   coordf1=frameline(length,xe,ye,ndash,0,flag);					
   npoints1=3*ndash;
   for i=1:1:npoints1
   	xsl1(i)=coordf1(i,1);
   	ysl1(i)=coordf1(i,2);
   end

% set up coordinates of bottom sliderline.	
	ye = ystem(3)-0.3*(ystem(1)-ystem(3));
	flag=1;
	coordf2=frameline(length,xe,ye,ndash,0,flag);					
	for i=1:1:npoints1
		xsl2(i)=coordf2(i,1);
		ysl2(i)=coordf2(i,2);
	end

% Set up the axes for first drawing.
	width=0.95;
	height=0.95;
	cx=[ xsl1, xsl2, xstem, xcoordf, xbush, xcoordcp,xc,xcoordf];
	cy=[ ysl1, ysl2, ystem, ycoordf, ybush, ycoordcp,yc,ycoordf];

	xmina=min(cx);
	xmaxa=max(cx);
	ymina=min(cy);
	if ymina>-.5; ymina=-0.5; end
	ymaxa=max(cy);
	rangex=xmaxa-xmina;
	rangey=ymaxa-ymina;
	xmin=xmina-0.2*rangex;
	xmax=xmaxa+0.2*rangex;
	ymin=ymina-0.2*rangey;
	ymax=ymaxa+0.2*rangey;
	values=axisadjust(xmin, xmax, ymin, ymax, width, height);
	xmin=values(1);
	xmax=values(2);
	ymin=values(3);
	ymax=values(4);
	axis([xmin xmax ymin ymax]);

% draw the pin and bushing.
	set(pin,'xdata', xcoordcp, 'ydata',ycoordcp);
	set(bush,'xdata', xbush,'ydata', ybush);

% Draw the top and bottom frame lines
	set (baset,'xdata', xsl1, 'ydata',ysl1)
	set (baseb,'xdata', xsl2, 'ydata',ysl2)

% Draw the cam.
	set (cam,'xdata', xc, 'ydata', yc);

% Draw follower roller.
	set (face, 'xdata', xcoordf, 'ydata',ycoordf);

% Draw follower stem
	set (stem, 'xdata', xstem, 'ydata',ystem);

%flush the draw buffer
	refresh; 

case 'Change Length'
   n = Argument2;
   newval=get(h_length(n),'string');
   oldval = [rb rise tmax tmin 0 0 0 0];
	value(n)=check_val(oldval(n),newval);
	set(h_length(n),'UserData',value(n),'string',num2str(value(n)));
	FFCamDesign('Draw Axes');      
   
case 'Change Rise'
	newval=get(h_length(2),'string');
	rise=check_val(rise,newval);
	set(h_length(2),'UserData',rise,'string',num2str(rise));
   FFCamDesign('Draw Axes');
   if ~isempty(findobj('Tag','FF Cam Profile Window'))
      a = findobj('Tag','FF Cam Profile Window');
      close(a);
      FFCamDesign('Profile');
   end
   
case 'Change Cam Style'
   case1 = [3.2  2  2.6 1.6  0   0   0   0 ];
   case2 = [ 2  15   0   0   6   0   9  0.5];
   case3 = [ 2   2   0   0   0  0.5  0   1 ];
   case4 = [ 2  30   0   0   6   1   5.2 30];
   direction = '+';
   ainc = 5;
   nStyle = get(h_popupmenu,'value');
   if (nStyle == 1) % ff_cam
      for n = 1:4
         set(h_length(n),'Enable','on','String',num2str(case1(n)),'Userdata',case1(n));
      end
      for n = 5:8
         set(h_length(n),'Enable','off');
      end
      CreateCamPlot;
   elseif (nStyle == 2) % off_cam
      for n = 1:2
         set(h_length(n),'Enable','on','String',num2str(case2(n)),'Userdata',case2(n));
      end
      for n = 3:4
         set(h_length(n),'Enable','off');
      end
      set(h_length(5),'Enable','on','String',num2str(case2(5)),'Userdata',case2(5));
      set(h_length(6),'Enable','off');
      for n = 7:8
         set(h_length(n),'Enable','on','String',num2str(case2(n)),'Userdata',case2(n));
      end
   elseif (nStyle == 3) % rf_cam
      for n = 1:2
         set(h_length(n),'Enable','on','String',num2str(case3(n)),'Userdata',case3(n));
      end
      for n = 3:5
         set(h_length(n),'Enable','off');
      end
      set(h_length(6),'Enable','on','String',num2str(case3(6)),'Userdata',case3(6));
      set(h_length(7),'Enable','off');
      set(h_length(8),'Enable','on','String',num2str(case3(8)),'Userdata',case3(8));
   else %(nStyle == 4) orf_cam
      for n = 1:2
         set(h_length(n),'Enable','on','String',num2str(case4(n)),'Userdata',case4(n));
      end
      for n = 3:4
         set(h_length(n),'Enable','off');
      end
      for n = 5:7
         set(h_length(n),'Enable','on','String',num2str(case4(n)),'Userdata',case4(n));
      end
      set(h_length(8),'Enable','off');
   end
	FFCamDesign('Draw Axes');      
   
case 'Change Increment'
	newval=get(h_inc,'string');
	ainc=check_val(ainc,newval);
	set(h_inc,'UserData',ainc,'string',num2str(ainc));
	FFCamDesign('Draw Axes');      
   
case 'Dradio'
   num_buttons = 2;
   n = Argument2;
   set(h_Dradio(n),'value',1);
   set(h_Dradio([1:(n-1), (n+1):num_buttons]),'value',0);
	FFCamDesign('Draw Axes');      
   
case 'None'      
	% the following command will bring the existing figure 
	% to foreground
	a = findobj('Tag','ff_cam_dsgn');
	figure(a);
   
case 'Close'   
	% if the target window exist then close it
	if findobj('Tag','FF Cam Analysis Window')
	   ff_cam_ana('Stop');
   	a = findobj('Tag','FF Cam Analysis Window');   
	  	close(a);
	end
   
	a = findobj('Tag','ff_cam_dsgn');
	close(a);
   
case 'Analysis'
   ff_cam_ana('initialize',rb,rise,tmin,tmax,direction,ainc);
   
case 'Profile'
   if isempty(findobj('Tag','FF Cam Profile Window'));   
      OpenProfileFig;
   else
  		figure(findobj('Tag','FF Cam Profile Window'));
% Bring the figure to front, if it already exists
   end
   fact=pi/180;

% Compute the displacement of the flat-faced follower.  The variable
% dtheta will change the resolution of the cam.  Make it smaller for
% accurate results.
		
   dtheta=ainc;
   sign=1;
   if direction=='+'
   	dtheta=-ainc;
   	sign=-1;
   end
   temp=-dtheta;
   n=abs(360/dtheta);

% Plot the displacement profile, velocity and acceleration for 
% the follower.  Start by normalizing f, fp, and fpp
   
   temp=-1;
   for j=1:1:360
   	temp=temp+1;
   	thetal(j)=temp;
   	[coords]=follower(thetal(j),rise);
   	fl(j)=coords(1);	
   	flp(j)=coords(2);
   	flpp(j)=coords(3);
   end
   fmax=max(fl);
   fmin=min(fl);
   fpmax=max(flp);
   fpmin=min(flp);
   fppmax=max(flpp);
   fppmin=min(flpp);
   fn=max([abs(fmax), abs(fmin)]);
   fpn=max([abs(fpmax), abs(fpmin)]);
   fppn=max([abs(fppmax), abs(fppmin)]);
   fnorm=fl/fn;
   fpnorm=flp/fpn;
   fppnorm=flpp/fppn;

% Set up the axes for displacement drawing.

   width=0.9;
   height=0.8;
   hdl = findobj('tag','ff_cam_profile');
   handles = get(hdl,'userdata');
   position = handles(1);
   velocity = handles(2);
   acceleration = handles(3);
   axes(hdl);
   xlabel('Cam Angle','color', 'k')
   ylabel('Follower Displacement, Velocity, and Acceleration','color', 'k')
   title('\it{Follower Displacement Diagram}','color', 'r','fontsize', 12)

   xmin=0;
   xmax=365;
   ymina=min([min(fnorm), min(fpnorm), min(fppnorm)]);
   ymaxa=max([max(fnorm), max(fpnorm), max(fppnorm)]);
   yrange=ymaxa-ymina;
   ymin=ymina-0.1*yrange;
   ymax=ymaxa+0.1*yrange;
   axis([xmin xmax ymin ymax]);
   
   set(hdl, 'XTick',[0 40 80 120 160 200 240 280 320 360]);
   set(position,'xdata',thetal, 'ydata',fnorm);
   set(velocity,'xdata',thetal,'ydata', fpnorm);
   set(acceleration,'xdata',thetal, 'ydata',fppnorm);
   text(10, -0.4,['Max. Pos. is: ', num2str(fn) ], 'color', 'r');
   text(10, -0.5,['Max. Vel. is: ', num2str(fpn), ' ( \omega', ' )' ],'color', 'b');
   text(10, -0.6,['Max. Acc. is: ', num2str(fppn), ' ( \omega^2', ' )' ], 'color', 'k');

case 'Help'
%-------On-line help  
   HelpStr={'Flat-faced Cam Analysis';
    '';
    '		''FFCamDesign'' is a program to design a crank rocker coupler curve mechanism ';
    'and to analyze the result.  The program contains two windows: a design';
    'window and an analysis window.  The nomenclature used by the program';
    'is that given in the textbook, Kinematics, Dynamics, and Design of ';
    'Mechanisms by Kenneth Waldron and Gary Kinzel.';
    '';
    '		In the design window, the variables are the five link length (frame,';
    'crank, coupler, rocker and coupler radius) and two angles (beta and frame ';
    'angle) and the angular velocity of the driver.  More options are given to ';
    'present the mechanisms in different modes, line or triangular coupler, crank  ';
    'or coupler driver, half or whole coupler point path (one or both mode radio ';
    'button set), and assembly mode (1 or -1).  One of the program features ';
    'is that users can drag the mouse to change the coupler point in a continuous ';
    'fashion. This changes both the beta angle and coupler radius.  In addition, ';
    'five more link lengths of the cognates mechanism are shown and updated ';
    'dynamically. Two assembly modes (1 or -1) are available in radio buttons. ';
    'Because changing the coupler point can move the mechanism plot out of the ';
    'figure window, ''zoom in'' and ''zoom out'' buttons are available to downsize' ;
    'and upsize the mechanism plot.';
    '';
    '		In the analysis window, users can control the number of plots (up ';
    'to four) and the contents of each plot (four options) are provided.  ';
    'Furthermore, the animation speed can be easily adjusted by clicking on';
    'the speed buttons.';
    '';
    '		Two buttons connect the two windows.  The ''return'' button in the';
    'analysis window closes the analysis window and brings back the design ';
    'window, while the ''analysis'' button in the design window open the ';
    'analysis window and start the linkage animation.  Every time the ';
    '''analysis'' button is pressed, all of the design parameters are updated ';
    'to start a new animation. ';
    '';
    '		There is a status bar at the bottom of the design window.  If the ';
    'chosen values for the variables cannot be used to create a crank rocker ';
    'coupler curve mechanism, an error message will be shown in the status box.'; 
    ' '};
   helpwin(HelpStr,'Flat-faced Cam Analysis');
   
case 'Get File'
% Get the file name using the UIGETFILE
	[sFileName sFilePath] = uigetfile('*.dat','Load File');
  
	if sFileName == 0 & sFilePath == 0
	   return;
	end   
   
% Combine the path and file name together
	sTemp = strcat( sFilePath, sFileName );
% get the size to erase the '.dat' extension   
	sz  = size(sFileName);
% load the data file  
	load(sTemp);
% assign the parameter to a variable
	Parameter = eval(sFileName(1:(sz(2)-4)));
	if max(size((Parameter))) == 6
	 	rb = Parameter(1);
	   rise = Parameter(2);
	   tmin = Parameter(3);
	   tmax = Parameter(4);
	   ndirec = Parameter(5);
	   ainc = Parameter(6);
		set(h_length(1),'UserData',rb,'string',num2str(rb));
		set(h_length(2),'UserData',rise,'string',num2str(rise));
		set(h_length(3),'UserData',tmin,'string',num2str(tmin));
		set(h_length(4),'UserData',tmax,'string',num2str(tmax));
		set(h_inc,'UserData',ainc,'string',num2str(ainc));
   	if ndirec == 2
	      FFCamDesign('Dradio',2);
      else 
         FFCamDesign('Dradio',1);
	   end
		   FFCamDesign('Draw Axes');      
   	refresh;
	else
	   set(h_status,'string','invalid file format');  
	   return;
	end          
   
case 'Put File'
   if direction == '-'
      ndirec = 2;
   else
      ndirec = 1;
   end
	[sFileName sFilePath] = uiputfile('*.dat','Save As');
	if Argument2 == 1   
		ParameterData = [rb; rise; tmin; tmax; ndirec; ainc];
	else
	   ParameterData = g_AnaRes;
	end
  
%sTemp = strcat( sFilePath, sFileName);
	[sTemp , errMsg] = sprintf('%s%s', sFilePath, sFileName);
	[strCmd, errMsg] = sprintf('%s %s %s', 'save', sTemp, ' -ascii ParameterData');
	eval(strCmd);   

end   

function val=check_val(oldval,newval)
% Check if the user input is number input
% if not, retrieve the previous value in userdata
val=zeros(1);
if ~isequal(length(oldval),length(str2num(newval))),
  	val=oldval;
%	set(findobj(gcf,'Tag','status_txt'),'String', ...
%   ['Warning: An invalid property value has been entered.']);
else
  	val=str2num(newval);
end

function LocalOpenFig()
hdls = zeros(25,0);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Control the color of the UI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
StdColor = get(0,'DefaultUIcontrolBackgroundColor');
%PointsPerPixel = 72/get(0,'ScreenPixelsPerInch');
bgframe = StdColor;
bgedit = [1 1 1];
bgtext = bgframe;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The Main Figure of Crank Rocker Design
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ScreenSize = get(0,'ScreenSize');
sx = 480;
sy = 400;
FigPos = [ 10 ScreenSize(4)-sy-40 sx sy ] ;
a = figure('Units','pixels', ...
	'Color',[0.8 0.8 0.8], ...
	'Name','Cam Synthesis', ...
	'NumberTitle','off', ...
	'Position',FigPos, ...
  	'Tag','ff_cam_dsgn');
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% menu uicontrols
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
b = uimenu('Parent',a, ...
	'Label','Parameter', ...
	'Tag','menu_parameter');
  
c = uimenu('Parent',b, ...
	'Callback','FFCamDesign(''Get File'')', ...
	'Label','Load Parameters', ...
	'Tag','submenu_load');
   
c = uimenu('Parent',b, ...
	'Callback','FFCamDesign(''Put File'',1)', ...
	'Label','Save Parameters', ...
	'Tag','submenu_save1');

c = uimenu('Parent',b, ...
	'Callback','FFCamDesign(''Put File'',2)', ...
	'Label','Save Result Data', ...
	'Tag','submenu_save2');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Draw Frame First
% This will prevent the frames from been drawn on top of
% other UICONTROLS. 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.0125 0.0119332 0.98 0.1106], ...
	'Style','frame', ...
	'Tag','Frame_status');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.6125 0.8125 0.38 0.11], ...
	'Style','frame');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.6125 0.6425 0.38 0.1625], ...
	'Style','frame');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.6125 0.4725 0.38 0.1625], ...
	'Style','frame');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.6125 0.395 0.38 0.07], ...
	'Style','frame');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.6125 0.315 0.38 0.075], ...
	'Style','frame');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.6125 0.2225 0.38 0.085], ...
	'Style','frame');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.6125 0.13 0.38 0.0850], ...
	'Style','frame', ...
	'Tag','Frame_pushbutton');
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Create graphics window for design input
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%-------Reference axis
b = axes('Parent',a, ...
  	'Box','on', ...
  	'Color',[1 1 1], ...
	'Position',[0.0125 0.13 0.5896 0.85], ...
  	'XColor',[0 0 0], ...
  	'XGrid','off', ...
  	'XTick',[],...
  	'YColor',[0 0 0], ...
  	'YGrid','off', ...
  	'YTick',[], ...
  	'ZColor',[0 0 0], ...
  	'ZGrid','off', ...
  	'ZTick',[]);
  
b = axes('Parent',a, ...
   'Box','off', ...
  	'DataAspectRatio',[1 1 1],...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Position',[0.0125 0.13 0.5896 0.85], ...
	'Tag','ff_cam_axes');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Popup Menu controls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h_popupmenu = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'ListboxTop',0, ...
	'Callback','FFCamDesign(''Change Cam Style'')', ...
	'Position',[0.6125 0.9225 0.38 0.0575], ...
	'String',['Axial Flat-Faced Follower Cam       ';'Oscillating Flat-Faced Follower Cam ';'Roller Follower Cam                 ';'Oscillating Cylindrical Follower Cam'], ...
	'Style','popupmenu', ...
	'Tag','PopupMenu1', ...
	'Value',1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Editable box controls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h_length(1) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','FFCamDesign(''Change Length'',1)', ...
	'Position',[0.8333 0.8675 0.1333 0.0475], ...
	'String','3.2', ...
	'Style','edit', ...
	'UserData',3.2);   

h_length(2) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','FFCamDesign(''Change Length'',2)', ...
	'Position',[0.8333 0.8225 0.1333 0.0475], ...
	'String','2', ...
	'Style','edit', ...
	'UserData',2);   

h_length(3) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','FFCamDesign(''Change Length'',3)', ...
	'Position',[0.8333 0.7475 0.1333 0.0475], ...
	'String','2.6', ...
	'Style','edit', ...
	'UserData',2.6);   

h_length(4) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','FFCamDesign(''Change Length'',4)', ...
	'Position',[0.8333 0.6975 0.1333 0.0475], ...
	'String','1.6', ...
	'Style','edit', ...
	'UserData',1.6);   

h_length(5) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','FFCamDesign(''Change Length'',5)', ...
   'Position',[0.8333 0.6475 0.1333 0.0475], ...
   'Enable','off', ...
	'String','0', ...
	'Style','edit', ...
	'UserData',0);   

h_length(6) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','FFCamDesign(''Change Length'',6)', ...
	'Position',[0.8333 0.5800 0.1333 0.0475], ...
   'Enable','off', ...
	'String','0', ...
	'Style','edit', ...
	'UserData',0);   

h_length(7) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','FFCamDesign(''Change Length'',7)', ...
	'Position',[0.8333 0.5300 0.1333 0.0475], ...
   'Enable','off', ...
	'String','0', ...
	'Style','edit', ...
	'UserData',0);   

h_length(8) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','FFCamDesign(''Change Length'',8)', ...
	'Position',[0.8333 0.4800 0.1333 0.0475], ...
   'Enable','off', ...
	'String','0', ...
	'Style','edit', ...
	'UserData',0);   

h_inc = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','FFCamDesign(''Change Increment'')', ...
	'Position',[0.8333 0.3225 0.1333 0.0475], ...
	'String','5', ...
	'Style','edit', ...
	'UserData',5);   

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% push button controls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Callback','FFCamDesign(''Profile'')', ...
	'Position',[0.6208 0.235 0.1801 0.0625], ...
	'String','Profile', ...
	'Tag','CloseButon');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Callback','FFCamDesign(''Definition'')', ...
	'Position',[0.803 0.235 0.1801 0.0625], ...
	'String','Definitions', ...
	'Tag','CloseButon');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Callback','FFCamDesign(''Analysis'')', ...
	'Position',[0.6208 0.14 0.120 0.0625], ...
	'String','Analysis', ...
	'Tag','AnalysisButton');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Callback','FFCamDesign(''Close'')', ...
	'Position',[0.8646 0.14 0.120 0.0625], ...
	'String','Close', ...
	'Tag','CloseButon');
   
b = uicontrol('Parent',a, ...
  	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Callback','FFCamDesign(''Help'')', ...
	'Position',[0.7437 0.14 0.12 0.0625], ...
	'String','Info', ...
	'Tag','InfoButton');
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% radio button controls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h_Dradio(1) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Callback','FFCamDesign(''Dradio'',1)', ...
	'Position',[0.8063 0.4075 0.09 0.0475], ...
   'Style','radiobutton', ...
   'value',0, ...
	'String','CCW');
   
h_Dradio(2) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Callback','FFCamDesign(''Dradio'',2)', ...
	'Position',[0.897 0.4075 0.09 0.0475], ...
   'Style','radiobutton', ...
   'value',1, ...
	'String','CW');
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% text controls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h_status = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'HorizontalAlignment','left', ...
	'Position',[0.05625 0.0275 0.9083 0.0775], ...
	'String',' ', ...
	'Style','text', ...
	'Tag','status_txt');
    
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6146 0.865 0.2062 0.04], ...
	'String','base radius', ...
	'Style','text');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6146 0.8225 0.2062 0.04], ...
	'String','rise height', ...
	'Style','text');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6146 0.7425 0.2062 0.04], ...
	'String','distance to top', ...
	'Style','text');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6146 0.695 0.2062 0.04], ...
	'String','distance to buttom', ...
	'Style','text');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6146 0.6475 0.2062 0.04], ...
	'String','pivots distance', ...
	'Style','text');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6146 0.575 0.2062 0.04], ...
   'String','follower radius', ...
	'Style','text');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6146 0.5275 0.2062 0.04], ...
	'String','follower length', ...
	'Style','text');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6146 0.48 0.2062 0.04], ...
	'String','follower offset', ...
	'Style','text');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6375 0.41 0.1583 0.04], ...
	'String','direction of cam rotation', ...
	'Style','text');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6229 0.3325 0.2062 0.04], ...
	'String','angle increment', ...
	'Style','text');
   
axis off;

hdls = [h_popupmenu h_length h_inc h_Dradio];
a = findobj('Tag','ff_cam_dsgn');
set(a,'UserData',hdls );	


function CreateCamPlot()
% Set up vectors to be drawn in the first plot

cam=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode',...
      'xor','color', 'k');
stem=line('xdata', [], 'ydata' ,[], 'linewidth',1,...
      'erasemode', 'xor','color', 'k');
face=line('xdata', [], 'ydata' ,[], 'linewidth',1,...
      'erasemode', 'xor','color', 'k');		
baset=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode',...
      'xor','color', 'r');
baseb=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode',...
      'xor','color', 'r');
bush=line('xdata',[],'ydata',[],'erasemode','none','color','r');
pin=line('xdata',[],'ydata',[],'erasemode','none','color','r');

hdls = [	cam stem face baset ...
      	baseb bush pin];
b = findobj('Tag','ff_cam_axes');
set(b,'userdata',hdls );
drawnow;   
function OpenProfileFig()
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	Profile Figure
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ScreenSize = get(0,'ScreenSize');
sx = 400;
sy = 350;
FigPos = [ ScreenSize(3)-sx-30 ScreenSize(4)-sy-80 sx sy ] ;
a = figure('Units','Pixels', ...
	'Color',[0.8 0.8 0.8], ...
   'Name','FF Cam Profile Window', ... 
   'NumberTitle','off', ...
	'Position',FigPos, ...
 	'Tag','FF Cam Profile Window');
 
 b = axes('Parent',a, ...
   'Box','off', ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Position',[0.15 0.15 0.75 0.75], ...
	'Tag','ff_cam_profile');

% Set up vectors to be drawn in the follower displacement plot

position=line('xdata', [], 'ydata' ,[], 'linewidth',1,...
   'erasemode', 'none','linestyle', '-', 'color', 'r');
velocity=line('xdata', [], 'ydata' ,[], 'linewidth',0.75,...
   'erasemode', 'none','linestyle', '--','color', 'b');
acceleration=line('xdata', [], 'ydata' ,[], 'linewidth' ,0.5, 'erasemode',...
   'none','linestyle', '-.','color', 'k');
hdls = [position velocity acceleration];
set(b,'userdata',hdls);
	
