function []=Inflection4barAnalysis(Action, Argument2)

%Variables
%   r1=frame length (cm)
%   r2=crank length (cm)
%   r3=coupler length (cm)
%   r4=rocker length (cm)
%   Q1=frame angle (deg)
%   Q11=frame angle (rad)
%   Q2=crank angle (deg)
%   Q21=crank angle (deg)
%   Q3=coupler angle (deg)
%   Q4=rocker angle (deg)
%   mode=assembly mode
%   tt=number of cycles to animate
%   dt=number of animation positions per revolution
%   bush1,bush2=x,y coordinates of the bushings
%   cir1,cir2=x,y coordinates of the circles inside the bushings
%   Bx,By=x,y coordinates of the crank pin
%   Cx,Cy=x,y coordinates of the rocker pin
%   Bx2,By2=x,y coordinates of the crank pointer
%   Cx2,Cy2=x,y coordinates of the rocker pointer
%   d2r,r2d=conversion factors between radians and degrees

%Graphics variables
%   xmin,xmax,ymin,ymax=axes limits
%   bushy1=line representing the bushing at the crank hinge
%   bushy2=line representing the bushing at the rocker hinge
%   circ1=line representing the circle inside the bushing at the crank hinge 
%   circ2=line representing the circle inside the bushing at the rocker hinge
%   joint1=line representing the joint at the crank pin 
%   joint2=line representing the joint at the rocker pin
%   crank=line representing the crank 
%   coupler=line representing the coupler
%   rocker=line representing the rocker

%Program  
global d2r
global r2d
global nCheckLength
global g_AnaRes
global nAxisChange
% The flag nAxisChange is to reduce the redundance of redrawing the fixed 
% mechanism objects while moving the mouse around.

if nargin == 0 & isempty(findobj('Tag','inflection4bar_dsgn'))% Inflection4barAnalysis is being initialized
	Action = 'initialize';
   
elseif nargin == 0 & findobj('Tag','inflection4bar_dsgn')	  % Inflection4barAnalysis is already open
   Action = 'None';
end

if ~strcmp(Action,'initialize') & ~strcmp(Action,'Help')
   % retrieve the previous variable values from userdata of objects
   a = findobj('Tag','inflection4bar_dsgn');		
   handles = get(a,'userdata');
   h_Edit = handles(1:9);
   
   % To make sure the link lengths entered by users can be assemblied 
   % before it is stored as userdata while lengths are modified. Flag
   % nCheckLength is true (other than 0) to retrieve data from the 
   % string value of Editable boxes. Then the checking is processed 
   % case 'Draw Axes' to make sure that the A and Astar are not conincident  
   % When nCheckLength is false ( value 1) for modification other than 
   % the length change, it retrieve the length from the userdata directly.
   if nCheckLength == 0
	   for i = 1:4
         r(i) = get(h_Edit(i),'userdata');
      end
   else
      for i = 1:4
         r(i) = str2num(get(h_Edit(i),'string'));
      end
   end
   r1 = r(1);
   r2 = r(2);
   r3 = r(3);
   r4 = r(4);
   
   Q1 = get(h_Edit(5),'userdata');
   Q21 = get(h_Edit(6),'userdata');
   theta = get(h_Edit(7),'userdata');
   Ax = get(h_Edit(8),'userdata');
   Ay = get(h_Edit(9),'userdata');
         
   h_ASradio = handles(10:11);
   if get(h_ASradio(1),'value') == 1
      mode = 1;
   else
      mode = -1;
	end      
   h_status = handles(12);
   h_Astar = handles(13:14);
   b = findobj('Tag','inflection4bar_axe');
   handles = get(b,'userdata');
   joint1 = handles(1);
   joint2 = handles(2);
   crank = handles(3);
   coupler = handles(4);
   rocker = handles(5);
   bushy1 = handles(6);
   bushy2 = handles(7);
   circ1 = handles(8);
   circ2 = handles(9);
   gridpt = handles(10);
   Icircle = handles(11);
   Icpoint = handles(12);
   Jpoint = handles(13);
   Poletangent = handles(14);
	Aline = handles(15);
	Aarc = handles(16);
	Apoint = handles(17);
	Astarpt = handles(18);
	JApoint = handles(19);
   
end  

switch Action
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	Initialize the User Interface
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
case  'initialize'
   nCheckLength = 0;
   nAxisChange = 1;
   if nargin >= 2 | findobj('tag','menu_page')															
	   LocalOpenFig;
      Inflection4barAnalysis('Draw Axes');
   else
   	show_me_logo('initialize','Inflection4barAnalysis');
   end
   
case 'Draw Axes'     
% Define constants
	sizefact=1;
	Q11=Q1*pi/180;
% Define constants

	d2r=pi/180;
	r2d=180/pi;
	qstart=0.0;
	qstop=360.0;
   
% Check for the Grashof type
	r=[r1 r2 r3 r4];
	[rnew,Inew]=sort(r);
	drock=1;
	if (rnew(1)+rnew(4)<rnew(2)+rnew(3))    
		drock=0;
		if r3==rnew(1); drock=1; end		
	end
	if drock ==1
		qstart=1.00001*r2d*acos(((r2+r3)^2+r1^2-r4^2)/(2*r1*(r2+r3)));
		qstop=0.99999*r2d*acos((r1^2+r2^2-(r3+r4)^2)/(2*r1*r2));
	end	

% Analyze the linkage for one position.
	range=(qstop+qstart)/2;
	Q2=Q21;
%	if Q21<qstart | Q21>qstop; Q2=qstart+range/2; end

% Call function to compute the position
	para = fourbar(r1,r2,r3,r4,Q2,1,0,mode,Q1,1); 
	Q3=para(7);
	Q4=para(8);
	assem=para(29);

% Store position information in matrices.
	a2(1)= para(17);
	a2(2)= para(18);
	b2(1)= para(19);
	b2(2)= para(20);
	a1(1)=0.0;
	a1(2)=0.0;
	b1(1)=r1*cos(Q11);
	b1(2)=r1*sin(Q11);
	coords=lineintersect(a1,a2,b1,b2);
	Ix=coords(1);
	Iy=coords(2);

% Determine JA and JB.
	if (a1(1) == a2(1)) & (a1(2) == a2(2))
	   set(h_status,'string','A and Astar are coincident, please reenter the parameter');
	   for i = 1:4
	      oldval = get(h_Edit(i),'userdata');
         set(h_Edit(i),'string',num2str(oldval));
	   end
      return
      nCheckLength = 0;
	   Inflection4barAnalysis('Draw Axes');
	end
   for i = 1:4
      set(h_Edit(i),'userdata',r(i));
   end
   set(h_status,'string','');
	coordA = inflection2(a2(1),a2(2),Ix,Iy,a1(1),a1(2),0,0,0,0);
	coordB = inflection2(b2(1),b2(2),Ix,Iy,b1(1),b1(2),0,0,0,0);
	JAx=coordA(1);
	JAy=coordA(2);
	JBx=coordB(1);
	JBy=coordB(2);
	
% Find the center of the inflection circle.
	coordC = pole([JAx, JAy], [JBx, JBy], [JBx, JBy], [Ix, Iy]);
	Cx=coordC(1);
	Cy=coordC(2);

% Compute radius of inflection circle and location of J.
	CdIx=Cx-Ix;
	CdIy=Cy-Iy;
	CdI=sqrt(CdIx^2+CdIy^2);
	angle=atan2(CdIy,CdIx);
	R=abs(CdI);
	D=2*R;
	Jx=Ix+D*cos(angle);
	Jy=Iy+D*sin(angle);

% Compute points on the inflection circle.
	dalpha=2*pi/30;
	for j=1:1:31
		alpha=(j-1)*dalpha;
		Icirx(j)=Cx+(D/2)*cos(alpha);
		Iciry(j)=Cy+(D/2)*sin(alpha);
	end

% Draw inflecton circle.
	fact=pi/180;
	naxx=max(Icirx);
	ninx=min(Icirx);
	naxy=max(Iciry);
	niny=min(Iciry);
	dx=(naxx-ninx);
	dy=(naxy-niny);
	maxx=naxx+sizefact*dx;
	minx=ninx-sizefact*dx;
	maxy=naxy+sizefact*dy;
	miny=niny-sizefact*dy;

	Ex = r1*cos(Q11);
	Ey = r1*sin(Q11);
	xmax=max([maxx, a2(1), b2(1), Ix, Ex]);
	if xmax>3*r1; xmax=3*r1; end

	ymax=max([maxy, a2(2), b2(2), Iy, Ey]);
	if ymax>6*r4; ymax=6*r4; end

	xmin=min([minx,a2(1), b2(1), Ix, Ex]);
	if xmin<-3*r1; xmin=-3*r1; end

	ymin=min([miny, a2(2), b2(2), Iy, Ey]);
	if ymin<-2*r4; ymin=-2*r4; end

%get the bushing points
	bush1=bushing(((ymax-ymin)/100),0,0,20,0);
	cir1=circle2(((ymax-ymin)/120),0,0,20);
	bush2=bushing(((ymax-ymin)/100), Ex, Ey, 20,0);
	cir2=circle2(((ymax-ymin)/120), Ex, Ey, 20);
   
   if nAxisChange == 1
		set(bushy1,'xdata', bush1(:,1), 'ydata',bush1(:,2));
		set(bushy2,'xdata', bush2(:,1), 'ydata',bush2(:,2));
		set(circ1,'xdata', cir1(:,1), 'ydata',cir1(:,2));
		set(circ2,'xdata', cir2(:,1), 'ydata',cir2(:,2));
		set(gridpt,'xdata', cir1(:,1), 'ydata',cir1(:,2));

		width=0.95;
		height=0.95;

		max1=max(bush1(:, 1));
		max2=max(bush2(:, 1));
		xmax1=max([max1, max2, xmax]);
		max1=max(bush1(:, 2));
		max2=max(bush2(:, 2));
		ymax1=max([max1, max2, ymax]);
		min1=min(bush1(:, 1));
		min2=min(bush2(:, 1));
		xmin1=min([min1, min2, xmin]);
		min1=min(bush1(:, 2));
		min2=min(bush2(:, 2));
		ymin1=min([min1, min2, ymin]);
		xmina=xmin1-0.1*abs(xmin1);
		xmaxa=xmax1+0.1*abs(xmax1);
		ymina=ymin1-0.1*abs(ymin1);
		ymaxa=ymax1+0.1*abs(ymax1);
		rangex=xmaxa-xmina;
		rangey=ymaxa-ymina;
		xmin=xmina-0.05*rangex;
		xmax=xmaxa+0.05*rangex;
		ymin=ymina-0.05*rangey;
		ymax=ymaxa+0.05*rangey;
		values=axisadjust(xmin, xmax, ymin, ymax, width, height);
		xmin=values(1);
		xmax=values(2);
		ymin=values(3);
		ymax=values(4);
		axis([xmin xmax ymin ymax]);
	   a = findobj('Tag','inflection4bar_dsgn');
	   hdls = get(a,'userdata');
	   hdls(15:18) =[xmin xmax ymin ymax];
	   set(a,'userdata',hdls);
   end
% Plot the instance of the linkage alone
	set(Icircle, 'xdata', Icirx, 'ydata', Iciry);
	set(Jpoint, 'xdata', Jx, 'ydata', Jy);
	set(Icpoint, 'xdata', Ix, 'ydata', Iy);
		
% Plot the instant center tangent
	Ptanx1=Ix+D*sin(angle);
	Ptanx2=Ix-D*sin(angle);
	Ptany1=Iy-D*cos(angle);
	Ptany2=Iy+D*cos(angle);
	set(Poletangent, 'xdata',[Ptanx1, Ptanx2], 'ydata', [Ptany1, Ptany2]);
   
% Plot the linkage.
	set(joint1,'xdata', a2(1), 'ydata',a2(2));
	set(joint2,'xdata', b2(1), 'ydata',b2(2));
	set(crank,'xdata',[a1(1) a2(1)],'ydata', [a1(2) a2(2)]);
	set(coupler,'xdata', [a2(1) b2(1)],'ydata', [a2(2) b2(2)]);
	set(rocker,'xdata', [b1(1) b2(1)],'ydata', [b1(2) b2(2)]);
	set(gridpt,'xdata',Ix, 'ydata' ,Iy);
%	drawnow;   %flush the draw buffer
% Find the center of curvature.
	Astarx=0;
	Astary=0;
	gamma=60;
	ptflag=0;
	icflag=0;
	coords= inflection3(Ax,Ay,Ix,Iy,Astarx,Astary,Cx,Cy,Jx,Jy,ptflag,icflag);
	JAx=coords(1);
	JAy=coords(2);
	gamma=coords(5);
	Astarx=coords(11);
   Astary=coords(12);
   set(h_Astar(1),'string',num2str(Astarx));
   set(h_Astar(2),'string',num2str(Astary));
	
% Define arc with radius AA* centered at A*

	r=sqrt((Astarx-Ax)^2+(Astary-Ay)^2);
	astart=atan2((Ay-Astary),(Ax-Astarx));
	thetarad=theta*pi/180;

% Determine angle corresponding to arc length of theta for inflection circle.

	angle=thetarad*D/(2*r);
	dalpha=angle/10;
	alpha=atan2((Ay-Astary),(Ax-Astarx))-angle/2-dalpha;
	for j=1:1:10
		alpha=alpha+dalpha;
		Aarcx(j)=Astarx+r*cos(alpha);
		Aarcy(j)=Astary+r*sin(alpha);
	end

% Plot A, Astar, and JA.
	set(Apoint, 'xdata',Ax, 'ydata', Ay);
	set(Astarpt, 'xdata',Astarx, 'ydata', Astary);
	set(JApoint, 'xdata',JAx, 'ydata', JAy);
	set(Aline, 'xdata',[Ax,Astarx,JAx,Ix], 'ydata', [Ay,Astary,JAy,Iy]);
   set(Aarc, 'xdata',Aarcx, 'ydata', Aarcy);
	drawnow;   
   b = findobj('Tag','inflection4bar_axe');
   hdls = get(b,'userdata');
   hdls(20:26) =[Cx Cy Ix Iy Jx Jy D];
   set(b,'userdata',hdls);
   set([Aarc Apoint],...
     'buttondownfcn','Inflection4barAnalysis(''Set Calls'',1);Inflection4barAnalysis(''Move'',1)');
   set([crank],...
     'buttondownfcn','Inflection4barAnalysis(''Set Calls'',2);Inflection4barAnalysis(''Move'',2)');

case 'Set Calls'
 
% get the handle of the objects used to control
% the mouse input 
	a = findobj('Tag','inflection4bar_dsgn');
	n = Argument2;
	if n == 1
   	set(a,'windowbuttonupfcn', 'a = findobj(''Tag'',''inflection4bar_dsgn'');set(a,''windowbuttonmotion'','''');refresh ');
	   set(a,'windowbuttonmotionfcn','Inflection4barAnalysis(''Move'',1)');
   else % n == 2
   	set(a,'windowbuttonupfcn', 'a = findobj(''Tag'',''inflection4bar_dsgn'');set(a,''windowbuttonmotion'','''');refresh ');
	   set(a,'windowbuttonmotionfcn','Inflection4barAnalysis(''Move'',2)');
   end   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The Callbacks When The User Moves the Mouse Button.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
case 'Move'
   n = Argument2;
   nCheckLength = 1;
% Find out where the mouse pointer is located.
%   set(h_status,'string','');
   b = findobj('Tag','inflection4bar_axe');
   hdls = get(b,'userdata');
   Cx = hdls(20);
   Cy = hdls(21); 
   Ix = hdls(22); 
   Iy = hdls(23); 
   Jx = hdls(24); 
   Jy = hdls(25); 
   D = hdls(26); 

  	pt = get(b,'currentpoint');
   pt = pt(1,1:2);
   
   if n == 1
      Ax = pt(1);
	   Ay = pt(2);
% Store the value in the current axes UserData
% where it can be retrieved by an application.
   	set(h_Edit(8),'userdata',Ax,'string',num2str(Ax));
	   set(h_Edit(9),'userdata',Ay,'string',num2str(Ay));
   
	else  % n == 2%
%      Ax = get(h_Edit(8),'userdata');
%      Ay = get(h_Edit(9),'userdata');
      Q21 = (atan2(pt(2),pt(1)))*180/pi;
      if Q21 > 180
	      Q21 = Q21 - 360;
	   elseif Q21 < -180
	      Q21 = Q21+360;     
	   end   

		set(h_Edit(6),'userdata',Q21,'string',num2str(Q21));
		nAxisChange = 0;
      Inflection4barAnalysis('Draw Axes');
      return
   end   
      
% Find the center of curvature.

	Astarx=0;
	Astary=0;
	gamma=60;
	ptflag=0;
	icflag=0;
	coords= inflection3(Ax,Ay,Ix,Iy,Astarx,Astary,Cx,Cy,Jx,Jy,ptflag,icflag);
	JAx=coords(1);
	JAy=coords(2);
	gamma=coords(5);
	Astarx=coords(11);
   Astary=coords(12);
   set(h_Astar(1),'string',num2str(Astarx));
   set(h_Astar(2),'string',num2str(Astary));
	
% Define arc with radius AA* centered at A*

	r=sqrt((Astarx-Ax)^2+(Astary-Ay)^2);
	astart=atan2((Ay-Astary),(Ax-Astarx));
	thetarad=theta*pi/180;

% Determine angle corresponding to arc length of theta for inflection circle.

	angle=thetarad*D/(2*r);
	dalpha=angle/10;
	alpha=atan2((Ay-Astary),(Ax-Astarx))-angle/2-dalpha;
	for j=1:1:10
		alpha=alpha+dalpha;
		Aarcx(j)=Astarx+r*cos(alpha);
		Aarcy(j)=Astary+r*sin(alpha);
	end

% Plot A, Astar, and JA.

	set(Apoint, 'xdata',Ax, 'ydata', Ay);
	set(Astarpt, 'xdata',Astarx, 'ydata', Astary);
	set(JApoint, 'xdata',JAx, 'ydata', JAy);
	set(Aline, 'xdata',[Ax, Astarx, JAx,Ix], 'ydata', [Ay, Astary, JAy, Iy]);
	set(Aarc, 'xdata',Aarcx, 'ydata', Aarcy);

  
%flush the draw buffer
   drawnow; 
	nCheckLength = 0;
case 'Change Value'
   n = Argument2;
   nAxisChange = 1;
   nCheckLength = 1;
   newval = get(h_Edit(n),'string');
   oldval = get(h_Edit(n),'userdata');
   val=check_val(oldval,newval);
   if n >4
	   set(h_Edit(n),'UserData',val);
	   set(h_Edit(n),'string',num2str(val));
   end
   Inflection4barAnalysis('Draw Axes'); 

case 'AS_radio'   
   nAxisChange = 1;
   num_buttons = 2;
   button = Argument2;
   if get(h_ASradio(button),'value') == 0
   	set(h_ASradio(button),'value',1);
   end
   set(h_ASradio([1:(button-1), (button+1):num_buttons]),'value',0);
   Inflection4barAnalysis('Draw Axes');   

case 'Resize'
   n = Argument2;
% To retrieve current axis limits   
   a = findobj('Tag','inflection4bar_dsgn');
   hdls = get(a,'userdata');
   xmin = hdls(15);
   xmax = hdls(16);
   ymin = hdls(17);
   ymax = hdls(18);
% If 'Zoom out' button is pressed, downsize the figure by increasing x any y axis limits
% If 'Zoom In' button is pressed, enlarge the figure by decreasing x any y axis limits
   if n ==1
      factor = 1.05;
   else
      factor = 0.95;
   end   
   xmin = xmin* factor;
   xmax = xmax* factor;
   ymin = ymin* factor;
   ymax = ymax* factor;
   hdls(15:18) = [xmin xmax ymin ymax];
   set(a,'userdata',hdls);
   axis([xmin xmax ymin ymax]);
   
case 'None'      
% the following command will bring the existing figure 
% to foreground
   a = findobj('Tag','inflection4bar_dsgn');
   figure(a);
   
case 'Close'   
% if the target window exist then close it
   if findobj('Tag','Fourbar Analysis Window')
      fourbar_ana('Stop');
      a = findobj('Tag','Fourbar Analysis Window');   
     	close(a);
   end
   
   a = findobj('Tag','inflection4bar_dsgn');
   close(a);
   
case 'Analysis'
   fourbar_ana('initialize',r,beta1,Q1,wdr,cpflag,driver,times,mode,1);

case 'Show Definitions'
   Show_definition('initialize','Inflection4barAnalysis.jpg');
   
case 'Help'
%-------On-line help  
   HelpStr={'Inflection Circle for the Four Bar Linkage Design';
    '';
    '		"Inflection4barAnalysis" is a  program to  graphically display ';
    'the solution of the Euler-Savary equation for a four-bar linkage.';
    'Only the design window is available.   The  nomenclature used by ';
    'the  program is that given in the textbook, Kinematics, Dynamics,';
    'and Design of Mechanisms by Kenneth Waldron and Gary Kinzel.     ';
    '';
    '		In this program, four link lengths (frame,crank, coupler and ';
    'rocker ) and  three angles ( frame, crabk and arc angles) can be ';
    'specified by users.   One of the  program features is that users ';
    'can  drag  the  mouse to  change not  only the circle point in a ';
    'continuous fashion, but also the crank angle.   In addition, Two ';
    'assembly modes (1 or -1) are available in radio buttons. Because ';
    'changing the circle point can move the mechanism plot out of the ';
    'figure window, "zoom in" and "zoom out" buttons are available to ' ;
    'downsize and upsize the mechanism plot.';
    ' '};
   helpwin(HelpStr,'Inflection Circle for the Four Bar Linkage Design');

case 'Get File'
% Get the file name using the UIGETFILE
   [sFileName sFilePath] = uigetfile('*.dat','Load File');
  
   if sFileName == 0 & sFilePath == 0
      return;
   end   
   
% Combine the path and file name together
   sTemp = strcat( sFilePath, sFileName );
% get the size to erase the '.dat' extension   
   sz  = size(sFileName);
% load the data file  
   load(sTemp);
% assign the parameter to a variable
   Parameter = eval(sFileName(1:(sz(2)-4)));
   if length(Parameter) == 10
      val = Parameter(1:9);
      mode = Parameter(10);
   	for i=1:9
    		set(h_Edit(i),'UserData',val(i),'string',num2str(val(i)));
      end    
      if mode == 1
      	Inflection4barAnalysis('AS_radio',1);
      else 
      	Inflection4barAnalysis('AS_radio',2);
      end
	Inflection4barAnalysis('Draw Axes');
      
      refresh;
   else
      set(h_status,'string','invalid file format');  
      return;
   end          
   
case 'Put File'
   [sFileName sFilePath] = uiputfile('*.dat','Save As');
   ParameterData = [r1; r2; r3; r4; Q1; Q21; theta; Ax; Ay; mode];
   %sTemp = strcat( sFilePath, sFileName);
   [sTemp , errMsg] = sprintf('%s%s', sFilePath, sFileName);
   [strCmd, errMsg] = sprintf('%s %s %s', 'save', sTemp, ' -ascii ParameterData');
   eval(strCmd);   

end   

function LocalOpenFig()

hdls = zeros(1,20);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Control the color of the UI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
StdColor = get(0,'DefaultUIcontrolBackgroundColor');
%PointsPerPixel = 72/get(0,'ScreenPixelsPerInch');
bgframe = StdColor;
bgedit = [1 1 1];
bgtext = bgframe;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The Main Figure of Crank Rocker Design
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ScreenSize = get(0,'ScreenSize');
sx = 480;
sy = 400;
FigPos = [ 10 ScreenSize(4)-sy-40 sx sy ] ;

a = figure('Units','pixels', ...
	'Color',[0.8 0.8 0.8], ...
	'Name','Inflection Fourbar Analysis', ...
	'NumberTitle','off', ...
	'Position',FigPos, ...
  	'Tag','inflection4bar_dsgn');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Draw Frame First
% This will prevent the frames from been drawn on top of
% other UICONTROLS. 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.0083 0.01 0.9833 0.11], ...
	'Style','frame'	, ...
  	'Tag','Frame1');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.6 0.7175 0.3896 0.255], ...
	'Style','frame', ...
	'Tag','Frame_link');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.6 0.51 0.3896 0.2], ...
	'Style','frame', ...
	'Tag','Frame7');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.6 0.32 0.3896 0.183], ...
	'Style','frame', ...
  	'Tag','Frame6');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.6 0.22 0.3896 0.0925], ...
	'Style','frame', ...
	'Tag','Frame_assemode');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.0083 0.1275 0.5833 0.0850], ...
	'Style','frame', ...
	'Tag','Frame_zoombutton');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'Position',[0.6 0.1275 0.3896 0.085], ...
	'Style','frame', ...
	'Tag','Frame_pushbutton');
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% menu uicontrols
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
b = uimenu('Parent',a, ...
	'Label','Parameter', ...
	'Tag','menu_parameter');
  
c = uimenu('Parent',b, ...
	'Callback','Inflection4barAnalysis(''Get File'')', ...
	'Label','Load Parameters', ...
	'Tag','submenu_load');
   
c = uimenu('Parent',b, ...
	'Callback','Inflection4barAnalysis(''Put File'')', ...
	'Label','Save Parameters', ...
	'Tag','submenu_save1');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Create graphics window for design input
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%-------Reference axis
b = axes('Parent',a, ...
  	'Box','on', ...
  	'Color',[1 1 1], ...
	'Position',[0.0083 0.22 0.5833 0.755], ...
  	'XColor',[0 0 0], ...
  	'XGrid','off', ...
  	'XTick',[],...
  	'YColor',[0 0 0], ...
  	'YGrid','off', ...
  	'YTick',[], ...
  	'ZColor',[0 0 0], ...
  	'ZGrid','off', ...
  	'ZTick',[]);
  
b = axes('Parent',a, ...
   'Box','off', ...
  	'DataAspectRatio',[1 1 1],...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Position',[0.0083 0.22 0.5833 0.755], ...
	'Tag','inflection4bar_axe');
axis off;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% edit related uicontrols
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h_Edit(1) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','Inflection4barAnalysis(''Change Value'',1)', ...
	'Position',[0.825 0.91 0.1375 0.05], ...
	'String','6.928', ...
	'Style','edit', ...
	'Tag','R_edit(1)', ...
	'UserData',6.928);
  
h_Edit(2) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','Inflection4barAnalysis(''Change Value'',2)', ...
	'Position',[0.825 0.8525 0.1375 0.05], ...
	'String','4', ...
	'Style','edit', ...
	'Tag','R_edit(2)', ...
	'UserData',4);
   
h_Edit(3) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','Inflection4barAnalysis(''Change Value'',3)', ...
	'Position',[0.825 0.795 0.1375 0.05], ...
	'String','4', ...
	'Style','edit', ...
	'Tag','R_edit(3)', ...
	'UserData',4);
   
h_Edit(4) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','Inflection4barAnalysis(''Change Value'',4)', ...
	'Position',[0.825 0.7375 0.1375 0.05], ...
	'String','6.9282', ...
	'Style','edit', ...
	'Tag','R_edit(4)', ...
	'UserData',6.9282);
      
h_Edit(5) = uicontrol('Parent',a, ...
  	'Units','normalized', ...
  	'BackgroundColor',bgedit, ...
	'Callback','Inflection4barAnalysis(''Change Value'',5)', ...
	'Position',[0.825 0.6425 0.1375 0.05], ...
	'String','120', ...
	'Style','edit', ...
	'Tag','Q1_edit', ...
  	'UserData',120);
  
h_Edit(6) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','Inflection4barAnalysis(''Change Value'',6)', ...
	'Position',[0.825 0.585 0.1375 0.05], ...
	'String','90', ...
	'Style','edit', ...
	'Tag','Q21_edit', ...
  	'UserData',90);
   
h_Edit(7) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','Inflection4barAnalysis(''Change Value'',7)', ...
	'Position',[0.825 0.5255 0.1375 0.05], ...
	'String','30', ...
	'Style','edit', ...
	'Tag','theta_edit', ...
  	'UserData',30);
  
h_Edit(8) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','Inflection4barAnalysis(''Change Value'',8)', ...
	'Position',[0.6833 0.3750 0.1375 0.05], ...
	'String','1.26', ...
	'Style','edit', ...
	'Tag','Ax_edit', ...
	'UserData',1.26);
   
h_Edit(9) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgedit, ...
	'Callback','Inflection4barAnalysis(''Change Value'',9)', ...
	'Position',[0.825 0.3750 0.1375 0.05], ...
	'String','1.99', ...
	'Style','edit', ...
	'Tag','Ay_edit', ...
	'UserData',1.99);
      
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% radio button controls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h_ASradio(1) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Callback','Inflection4barAnalysis(''AS_radio'',1)', ...
	'Position',[0.82 0.265 0.1 0.0425], ...
	'String',' 1', ...
	'Style','radiobutton', ...
	'Tag','assmode_radio1', ...
	'Value',1);
   
h_ASradio(2) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Callback','Inflection4barAnalysis(''AS_radio'',2)', ...
	'Position',[0.82 0.2275 0.1 0.041], ...
	'String','-1', ...
	'Style','radiobutton', ...
	'Tag','assmode_radio2', ...
	'Value',0);
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% push button controls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Callback','Inflection4barAnalysis(''Close'')', ...
	'Position',[0.7958 0.14 0.1854 0.06], ...
	'String','Close');
   
b = uicontrol('Parent',a, ...
  	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Callback','Inflection4barAnalysis(''Help'')', ...
	'Position',[0.6083 0.14 0.1854 0.06], ...
	'String','Info');
   
b = uicontrol('Parent',a, ...
  	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Callback','Inflection4barAnalysis(''Resize'',1)', ...
   'Position',[0.0187 0.14 0.1854 0.06], ...
	'String','Zoom Out');
  
b = uicontrol('Parent',a, ...
  	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Callback','Inflection4barAnalysis(''Resize'',2)', ...
	'Position',[0.2062 0.14 0.1854 0.06], ...
   'String','Zoom In');
   
b = uicontrol('Parent',a, ...
  	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Callback','Inflection4barAnalysis(''Show Definitions'')', ...
	'Position',[0.3937 0.14 0.1854 0.06], ...
   'String','Definitions');
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% text controls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h_status = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'HorizontalAlignment','left', ...
	'Position',[0.05625 0.0275 0.9083 0.075], ...
	'String',' ', ...
	'Style','text', ...
	'Tag','status_txt');
    
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6208 0.91 0.1729 0.0425], ...
	'String','frame length', ...
	'Style','text', ...
	'Tag','StaticText4');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6167 0.8525 0.1708 0.0425], ...
	'String','crank length', ...
	'Style','text', ...
	'Tag','StaticText2');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.625 0.795 0.1833 0.0425], ...
	'String','coupler length', ...
	'Style','text', ...
	'Tag','StaticText2');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.61875 0.7375 0.18125 0.0425], ...
	'String','rocker length', ...
	'Style','text', ...
	'Tag','StaticText3');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6208 0.6325 0.1729 0.0425], ...
	'String','frame angle', ...
	'Style','text', ...
	'Tag','StaticText1');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6208 0.5775 0.1729 0.0425], ...
	'String','crank angle', ...
	'Style','text', ...
	'Tag','StaticText1');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6208 0.5225 0.1729 0.0425], ...
	'String','arc angle', ...
	'Style','text', ...
	'Tag','StaticText1');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6333 0.4525 0.2312 0.0425], ...
	'String','point coordinates', ...
	'Style','text', ...
	'Tag','StaticText1');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.7312 0.43 0.0396 0.035], ...
	'String','x', ...
	'Style','text', ...
	'Tag','StaticText1');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.8792 0.4275 0.0479 0.0425], ...
	'String','y', ...
	'Style','text', ...
	'Tag','StaticText1');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6062 0.3725 0.0729 0.0475], ...
	'String','A', ...
	'Style','text', ...
	'Tag','StaticText1');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6065 0.3275 0.0724 0.0475], ...
	'String','Astar', ...
	'Style','text', ...
	'Tag','StaticText1');
   
h_txt(1) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.6833 0.3255 0.1375 0.0425], ...
	'String','-5.1812', ...
	'Style','text', ...
	'Tag','Astarx');
   
h_txt(2) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'Position',[0.8250 0.3255 0.1375 0.0425], ...
	'String','22.4883', ...
	'Style','text', ...
	'Tag','Astary');
   
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',bgtext, ...
   'Position',[0.6021 0.255 0.2188 0.0425], ...
	'String','assembly mode', ...
	'Style','text', ...
	'Tag','StaticText4');
drawnow;   
hdls=[ h_Edit h_ASradio h_status h_txt];
%hdls(22) = 1;
a = findobj('Tag','inflection4bar_dsgn');
set(a,'userdata',hdls );	
     
% Set up the vectors needed to draw the linkage

joint1=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
	6, 'erasemode', 'xor', 'color', 'k');
joint2=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
	6, 'erasemode', 'xor', 'color',  'k');
coupler=line('xdata', [], 'ydata' ,[], 'linewidth' ,2, 'erasemode', ...
	'xor','color',  'k');
rocker=line('xdata', [], 'ydata' ,[], 'linewidth',2,...
	'erasemode', 'xor','color',  'k');
bushy1=line('xdata', [], 'ydata', [], 'linestyle', '-',...
	'color', 'r');
bushy2=line('xdata', [], 'ydata', [], 'linestyle', '-', ...
	'color', 'r');
circ1=line('xdata', [], 'ydata', [], 'linestyle', '-',...
	'color','r');
circ2=line('xdata', [], 'ydata', [], 'linestyle', '-', ...
	'color','r');

gridpt=line('xdata', [], 'ydata', [], 'linestyle', '-',...
   'markersize', 6,'color',  'k');
Icircle=line('xdata', [], 'ydata' ,[], 'linewidth',1,'erasemode',...
   'normal','color', 'r');
Icpoint=line('xdata', [], 'ydata',[], 'marker', '+', 'markersize', 6,...
   'erasemode', 'normal','color', 'r');
Jpoint=line('xdata', [], 'ydata',[], 'marker', '+', 'markersize', 6,...
   'erasemode', 'normal','color', 'r');
Poletangent=line('xdata', [], 'ydata' ,[], 'linewidth',1,'erasemode',...
   'normal','color', 'r');
Aline=line('xdata', [], 'ydata', [],'markersize', ...
   10,'erasemode', 'xor', 'color', 'k');
Astarpt=line('xdata', [], 'ydata', [], 'marker', '+','markersize', ...
   10, 'erasemode', 'xor', 'color', 'r');
JApoint=line('xdata', [], 'ydata', [], 'marker', '+','markersize', ...
   10, 'erasemode', 'xor', 'color', 'k');
crank=line('xdata', [], 'ydata' ,[], 'linewidth' ,2, 'erasemode', ...
	'xor','color',  'g');
Aarc=line('xdata', [], 'ydata', [],'markersize', ...
   10,'erasemode', 'xor', 'color', 'g');
Apoint=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
   6, 'erasemode', 'xor', 'color', 'g', 'linewidth',1);
   
hdls=[ joint1 joint2 crank coupler rocker ...
       bushy1 bushy2 circ1 circ2 gridpt ...
 		 Icircle Icpoint Jpoint Poletangent ...
		 Aline Aarc Apoint Astarpt JApoint ];
a = findobj('Tag','inflection4bar_axe');
set(a,'userdata',hdls );	

function val=check_val(oldval,newval)
% Check if the user input is number input
% if not, retrieve the previous value in userdata
val=zeros(1);
if ~isequal(length(oldval),length(str2num(newval))),
  	val=oldval;
%	set(findobj(gcf,'Tag','status_txt'),'String', ...
%   ['Warning: An invalid property value has been entered.']);
else
  	val=str2num(newval);
end
