function [Values] = centerpoint (ax1,ay1,theta1,ax2,ay2,theta2,ax3,ay3,theta3,XC,YC)

% This function determines the coordinates of the center point given 
% the coordinates of the circle point.  The input values are:

%ax1     = x coordinate of coupler coordinate system in position 1
%ay1     = y coordinate of coupler coordinate system in position 1
%ax2     = x coordinate of coupler coordinate system in position 2
%ay2     = y coordinate of coupler coordinate system in position 2
%ax3     = x coordinate of coupler coordinate system in position 3
%ay3     = y coordinate of coupler coordinate system in position 3
%theta1  = angle from frame x axis to coupler x axis in position 1 (degrees)
%theta2  = angle from frame x axis to coupler x axis in position 2 (degrees)
%theta3  = angle from frame x axis to coupler x axis in position 3 (degrees)
%XC      = x coordinate of circle point relative to coupler coordinate system
%YC      = y coordinate of circle point relative to coupler coordinate system

% The center point coordinates are returned in the vector "values".  The 
% coordinates are stored in values according to the following:

%Values(1)   = center point x coordinate relative to frame coordinate system
%Values(2)   = center point y coordinate relative to frame coordinate system
%Values(3)   = circle point x in position 1 relative to frame system
%Values(4)   = circle point y in position 1 relative to frame system
%Values(5)   = circle point x in position 2 relative to frame system
%Values(6)   = circle point y in position 2 relative to frame system
%Values(7)   = circle point x in position 3 relative to frame system
%Values(8)   = circle point y in position 3 relative to frame system


% compute sine and cosine of angles.

fact=pi/180;
theta1r=theta1*fact;
theta2r=theta2*fact;
theta3r=theta3*fact;
st1=sin(theta1r);
st2=sin(theta2r);
st3=sin(theta3r);
ct1=cos(theta1r);
ct2=cos(theta2r);
ct3=cos(theta3r);

% Transform the circle point to the frame coordinate system

xc1= XC*ct1-YC*st1+ax1;
yc1= XC*st1+YC*ct1+ay1;
xc2= XC*ct2-YC*st2+ax2;
yc2= XC*st2+YC*ct2+ay2;
xc3= XC*ct3-YC*st3+ax3;
yc3= XC*st3+YC*ct3+ay3;
	
% Compute the center point.

Values=pole([xc1;yc1],[xc2;yc2],[xc2;yc2],[xc3;yc3]);
Values(3)=xc1;
Values(4)=yc1;
Values(5)=xc2;
Values(6)=yc2;
Values(7)=xc3;
Values(8)=yc3;	
