function coords = cosline(p12,p13,p23,p23prime)

% This m-file determines coordinates on the circle of sliders when the
% radius of the circle is infinite.

% pij is a three component vector giving the x,y coordinates of the pole and
%    a flag indicating if the pole is at infinity.  If 
%    pij(3) = 0, the pole is not at infinity.  If pij(3) = 1, the pole 
%    is at infinity.
% p23prime is a two component vector giving the x, y coordinates of the 
% image pole for P23.
%
% The results are returned in the vector coords.  The x components of 
% the point j on the line are stored in coords(j,1), and the y components are
% stored in coords(j,2).

pflag12=p12(3);
pflag13=p13(3);
pflag23=p23(3);

% Find the pole which is at infinity.

if pflag12 == 1

% find extreme points for line passing through p13 and p23prime

	dist=sqrt((p13(1)-p23prime(1))^2+(p13(2)-p23prime(2))^2)
	theta=atan2((p13(2)-p23prime(2)),(p13(1)-p23prime(1)))
	stot=9*dist;
	ds=stot/31;
	s=-4*dist-ds;
	for i=1:1:31
		s=s+ds;
		coords(i,1)=p23prime(1)+s*cos(theta);
		coords(i,2)=p23prime(2)+s*sin(theta);
	end
end

if pflag13 == 1

% find extreme points for line passing through p12 and p23prime

	dist=sqrt((p12(1)-p23prime(1))^2+(p12(2)-p23prime(2))^2);
	theta=atan2((p12(2)-p23prime(2)), (p12(1)-p23prime(1)));
	stot=9*dist;
	ds=stot/31;
	s=-4*dist-ds;
	for i=1:1:31
		s=s+ds;
		coords(i,1)=p23prime(1)+s*cos(theta);
		coords(i,2)=p23prime(2)+s*sin(theta);
	end
end

if pflag23 == 1

% find extreme points for line passing through p12 and p13

	dist=sqrt((p13(1)-p12(1))^2+(p13(2)-p12(2))^2);
	theta=atan2((p13(2)-p12(2)), (p13(1)-p12(1)));
	stot=9*dist;
	ds=stot/31;
	s=-4*dist-ds;
	for i=1:1:31
		s=s+ds;
		coords(i,1)=p12(1)+s*cos(theta);
		coords(i,2)=p12(2)+s*sin(theta);
	end
end
