function [Qstart, Qstop]=fb_angle_limits_co(r1,r2,r3,r4,Q1)

% Function file that calculates the initial and final angle for four-bar
% linkage when the coupler is the driver.

% Variables
%   r1=frame length (cm)
%   r2=crank length (cm)
%   r3=coupler length (cm)
%   r4=rocker length (cm)
%   Q1start=initial crank angle (deg)
%   Q1stop=final crank angle (deg)

%Program

r=[r1,r2,r3,r4];
rmin=min(r);
rmax=max(r);
rtotal=r1+r2+r3+r4;

if (r1+r3)>(r2+r4)&abs(r1-r3)<abs(r2-r4)
	Qstart=acos((-(r4-r2)^2+r3^2+r1^2)/(2*r1*r3));
	Qstop=acos((r3^2-(r4+r2)^2+r1^2)/(2*r1*r3));
end
if (r1+r3)>(r2+r4)&abs(r1-r3)>=abs(r2-r4)
	Qstart=acos((r3^2-(r4+r2)^2+r1^2)/(2*r1*r3));
	Qstop=-Qstart;
end
if (r1+r3)<=(r2+r4)&abs(r1-r3)>=abs(r2-r4)
	Qstart=0;
	Qstop=2*pi;
end
if (r1+r3)<=(r2+r4)&abs(r1-r3)<abs(r2-r4)
	Qstart=acos((r3^2-(r4-r2)^2+r1^3)/(2*r1*r3));
	Qstop=2*pi-Qstart;
end
range=Qstop-Qstart;	
Qstart=Q1+(Qstart+0.000001*range)*180/pi;
Qstop=Q1+(Qstop-0.000001*range)*180/pi;

