function [f]= follower(tt,rise)

% This function determines the follower displacement and derivatives
% for a full rotation cam.  The routine is set up for the displacement
% schedule in Example 6.8

% The input values are:

%theta   = cam angle (deg)
%rise    = maximum follower displacement

% The results are returned in the variable f where f(1) is the 
% displacement, f(2) is the derivative of the displacement with
% respect to theta, and f(3) is the second derivative with respect 
% to theta.  

% find the correct interval.

fact=pi/180;
theta=tt*fact;
if theta < pi/2
	f(1)=0;
	f(2)=0;
	f(3)=0;
end
if theta >= pi/2 & theta < pi
	f(1)=(rise/(pi/2))*((theta-pi/2)-(sin(4*(theta-pi/2)))/4);
	f(2)=(rise/(pi/2))*(1-cos(4*(theta-pi/2)));
	f(3)=(8*rise/pi)*sin(4*(theta-pi/2));
end
if theta>=pi & theta< 4*pi/3
	f(1)=rise;
	f(2)=0;
	f(3)=0;
end
if theta >= 4*pi/3
	f(1)=(rise/2)*(1+cos(1.5*(theta-4*pi/3)));
	f(2)=-(3*rise/4)*(sin(1.5*(theta-4*pi/3)));
	f(3)=-(9*rise/8)*(cos(1.5*(theta-4*pi/3)));
end
