function [f]= follower_poly(tt,Hs,He,type,start,ending)

% This function determines the follower displacement and derivatives
% for a full rotation cam.  The routine is set up for the displacement
% schedule in Example 6.8

% The input values are:

%theta   = cam angle (deg)
%rise    = maximum follower displacement

% The results are returned in the variable f where f(1) is the 
% displacement, f(2) is the derivative of the displacement with
% respect to theta, and f(3) is the second derivative with respect 
% to theta.  

% find the correct interval.

fact=pi/180;
theta=tt*fact;
startd = start*fact;
endingd = ending*fact;
theta = theta-startd;
beta = endingd-startd;
rise = abs(He - Hs);
if type == 1
	f(1)=Hs;
	f(2)=0;
	f(3)=0;
end
if type == 2
	f(1) = Hs+rise*(10*(theta/beta)^3 - 15*(theta/beta)^4 + 6*(theta/beta)^5);
	f(2) = 30*(rise/beta)*((theta/beta)^2 - 2*(theta/beta)^3 + (theta/beta)^4);
	f(3) = 60*(rise/(beta^2))*((theta/beta) - 3*(theta/beta)^2 + 2*(theta/beta)^3);
end
if type == 3
	f(1) = Hs - rise*(10*(theta/beta)^3 - 15*(theta/beta)^4 + 6*(theta/beta)^5);
	f(2) = -30*(rise/beta)*((theta/beta)^2 - 2*(theta/beta)^3 + (theta/beta)^4);
	f(3) = -60*(rise/(beta^2))*((theta/beta) - 3*(theta/beta)^2 + 2*(theta/beta)^3);
end
