function coords = lineintersect(a1,a2,b1,b2)

% This function computes the coordinates of the intersection of 
% two lines given two points on each line 

% a1 is a two component vector giving the x,y coordinates of the 
%    first point on first line.
% a2 is a two component vector giving the x,y coordinates of the 
%    second point on first line.
% b1 is a two component vector giving the x,y coordinates of the 
%    first point on second line.
% b2 is a two component vector giving the x,y coordinates of the 
%     second point on second line.
% coords is a three component vector.  The first two components are
%     the x,y coordinates of the intersection of the two lines.  The
%     third component is a flag.  The flag is 0 if the lines are not
%     parallel and 1 if the lines are parallel.

A=[(a2(2)-a1(2)) -(a2(1)-a1(1)); (b2(2)-b1(2)) -(b2(1)-b1(1))];

% Determine if A is singular

determinant=abs(det(A));

% Locate the intersection when the matrix is not singular

if determinant > 10^(-10)
	B=[(a2(2)-a1(2))*a1(1)-(a2(1)-a1(1))*a1(2);...
		   (b2(2)-b1(2))*b1(1)-(b2(1)-b1(1))*b1(2)];
	s=A\B;
	coords(1)=s(1);
	coords(2)=s(2);
	coords(3)=0;
end

% Locate the intersection when the matrix is singular

if determinant <= 10^(-10)
	coords(1)= 10^10;
	angle = atan2((a2(2)-a1(2)),(a2(1)-a1(1)));
	coords(2)=coords(1)*tan(angle);
	coords(3)=1;
end
