function [f]= o_follower2(tt,rise)

% This function determines the follower displacement and derivatives
% for a full rotation cam.  The routine is set up for the displacement
% schedule in Example 6.10

% The input values are:

%theta   = cam angle (deg)
%rise    = maximum follower displacement

% The results are returned in the variable f where f(1) is the 
% displacement, f(2) is the derivative of the displacement with
% respect to theta, and f(3) is the second derivative with respect 
% to theta.  

% find the correct interval.

fact=pi/180;
theta=tt*fact;
if theta < pi/4
	f(1)=0;
	f(2)=0;
	f(3)=0;
end
if theta >= pi/4 & theta < pi
	tmp2=(theta-pi/4);
	f(1)=(rise/2)*(1-cos(4/3*tmp2));
	f(2)=(3*rise/4)*(sin(2*tmp2));
	f(3)=(9*rise/8)*(cos(2*tmp2));
end
if theta>=pi & theta<3*pi/2
	f(1)=rise;
end
if theta >= 3*pi/2
	tmp2=theta-3*pi/2;
	f(1)=(rise/2)*(1+cos(2*tmp2));
	f(2)=-(3*rise/4)*(sin(2*tmp2));
	f(3)=-(9*rise/8)*(cos(2*tmp2));
end
