function sixbar_ana(Action,r, beta, Q1, Gx, Gy,w2, dmode)

% the contents of the userdata of Analysis Window 
% handles(1) = handle of fig number
% handles(2) = handle of fig1 popupmenu
% handles(3) = handle of fig2 popupmenu
% handles(4) = handle of fig3 popupmenu
% handles(5) = handle of fig4 popupmenu
% handles(6) = handle of axe1
% handles(7) = handle of axe2
% handles(8) = handle of axe3
% handles(9) = handle of axe4
% handles(10) = flag for deciding to start or stop animation
% handles(11) = handle of bead(1)
% handles(12) = handle of bead(2)
% handles(13) = handle of bead(3)
% handles(14) = handle of bead(4)
% handles(15) = Previous Start Index
% handles(16) = timesink
% handles(17) = handle of reference axe for axe1
% handles(18) = handle of reference axe for axe2
% handles(19) = handle of reference axe for axe3
% handles(20) = handle of reference axe for axe4
% handles(21) = handle of submenu 'Load'
% handles(22) = handle of submenu 'Save'
% handles(23) = handle of return button;
% handles(24) = handle of speed plus button;
% each mechanism axes has the its own userdata storing its 
% unique graphic handle [joint1 joint2 crank coupler rocker];      

global strFigType 
global nAnimationFlag
global g_AnaRes
global nChangeSpeed

% Define the axes for the first graph (input/output angle graph)

if nargin==0 & isempty(findobj('Tag','Sixbar Analysis Window')),  % cogana is being initialized
   Action='initialize';
elseif nargin== 0 & findobj('Tag','Sixbar Analysis Window'),      % cogana is already open
   Action='None';
elseif nargin== 1 & findobj('Tag','Sixbar Analysis Window') & strcmp( Action, 'initialize'), % cogana is already open
	% Recalculate the value, and then redraw
	Action='None';
end
switch Action
case 'initialize'
   if  isempty(findobj('Tag','Sixbar Analysis Window'))   
      LocalOpenFig;
      nAnimationFlag = 0;
   else
  		sixbar_ana('None');
   end
   
  if nargin < 7 
		r1 = 4;
		r2 = 1;
		r3 = 3;
		r4 = 4;
		r5 = 1.576;
		r6 = 2.544;
		Gx = 1.075;
		Gy = 3.615;
		cr = 1.0936;
		beta = 170.7749;
		Q1 = 0;
		w2 = 1;
		dmode = 1;
   	r =[r1 r2 r3 r4 r5 r6 cr];
   end
   if exist('nAnimationFlag') 
      if nAnimationFlag == 1
      	sixbar_ana('Stop');
         return;
      end
   end
   
   Q11=Q1*pi/180;
   
   g_AnaRes = CalcResult( r, beta, Q1, Gx, Gy,w2, dmode );
   DrawAnalysisWindow;
   sixbar_ana('ShowFigure');
   sixbar_ana('Start');
   
 	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	%	Change Figure Call Back Function
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
case 'ChangeFigure'
   DrawAnalysisWindow;
   sixbar_ana('ShowFigure');
   sixbar_ana('Start');
   
case 'SetSpeed'
   nChangeSpeed = r(1);
   
case 'ChangeFigureNo'
   DrawAnalysisWindow;
   sixbar_ana('ShowFigure');
   sixbar_ana('Start');
   
case 'Animation'
   a = findobj('Tag','Sixbar Analysis Window');   
   handles = get(a,'userdata');
   
   [ m, n ] = size( g_AnaRes);
   itotal = n;
   timesink = handles(16);
   i = handles(15);
   dt = 5;
   
   nFigNum  = get( handles(1),'value');
   nType(1) = get( handles(2),'value');
   nType(2) = get( handles(3),'value');
   nType(3) = get( handles(4),'value');
   nType(4) = get( handles(5),'value');
   
   bead  = zeros(1,4);
   links = zeros(4,10);
   bead(1) = handles(11);
   bead(2) = handles(12);
   bead(3) = handles(13);
   bead(4) = handles(14);
   
   h_plus = handles(24);
   
   itotal = g_AnaRes(15,15);
   Bx = g_AnaRes(7,1:itotal);
   By = g_AnaRes(8,1:itotal);
   Cx = g_AnaRes(9,1:itotal);
   Cy = g_AnaRes(10,1:itotal);
   Dx = g_AnaRes(15,1);
   Dy = g_AnaRes(15,2);
   Ex = g_AnaRes(11,1:itotal);
   Ey = g_AnaRes(12,1:itotal);
   Fx = g_AnaRes(13,:);
   Fy = g_AnaRes(14,:);
   Gx = g_AnaRes(15,3);
   Gy = g_AnaRes(15,4);
   
   for j = 1:nFigNum
      if nType(j) == 4
      	links(j,:) = get(handles(j+5),'userdata');
   	end
   end   
   
   % set timer
   tic;
   
	while nAnimationFlag      
          
      cycle=fix((i-0.0000001)/(360/dt)); %determine the cycle as an integer
      if i ==1
         drawnow;
      end
      if nFigNum > 0
         if nType(1) == 4
				SetMechanismPosition( links(1,:),i,Bx,By,Cx,Cy,Dx,Dy,Ex,Ey,Fx,Fy,Gx,Gy);
         else   
            	j = nType(1) * 2 -1;
				set(bead(1), 'xdata', g_AnaRes(j,i), 'ydata', g_AnaRes(j+1,i));        
			end
      end 
        
		if nFigNum > 1
         if nType(2) == 4
				SetMechanismPosition( links(2,:),i,Bx,By,Cx,Cy,Dx,Dy,Ex,Ey,Fx,Fy,Gx,Gy);
         else   
            	j = nType(2) * 2 -1;
         	set(bead(2), 'xdata', g_AnaRes(j,i), 'ydata', g_AnaRes(j+1,i));
         end  
      end
      
		if nFigNum > 2
         if nType(3) == 4
				SetMechanismPosition( links(3,:),i,Bx,By,Cx,Cy,Dx,Dy,Ex,Ey,Fx,Fy,Gx,Gy);
         else   
            	j = nType(3) * 2 -1;
   	   	set(bead(3), 'xdata', g_AnaRes(j,i), 'ydata', g_AnaRes(j+1,i));
         end
      end
         
     	if nFigNum > 3
         if nType(4) == 4
				SetMechanismPosition( links(4,:),i,Bx,By,Cx,Cy,Dx,Dy,Ex,Ey,Fx,Fy,Gx,Gy);
        else   
            	j = nType(4) * 2 -1;
	     		set(bead(4), 'xdata', g_AnaRes(j,i), 'ydata', g_AnaRes(j+1,i));
         end  
      end
        
		drawnow;   %flush the draw buffer
      i= i+1;
      if i == itotal
         i = 1;
      end
      if nChangeSpeed ~= 0
         timesink = timesink * nChangeSpeed;
         nChangeSpeed = 0;
      end
      while toc < timesink
      end   
      tic;
   end
   nAnimationFlag = 0;
   handles(15) = i;
   handles(16) = timesink;
   set(a,'Userdata',handles);
   
case 'ShowFigure'
   a = findobj('Tag','Sixbar Analysis Window');
   handles = get( a,'userdata');
   nFigNum = get(handles(1),'value');
   [ m, n ] = size( g_AnaRes);
   Dx = g_AnaRes(15,1);
   Dy = g_AnaRes(15,2);
   itotal = g_AnaRes(15,15);
   Ex = g_AnaRes(11,1:itotal);
   Ey = g_AnaRes(12,1:itotal);
   Gx = g_AnaRes(15,3);
   Gy = g_AnaRes(15,4);
   xmin = g_AnaRes(15,11);
   xmax = g_AnaRes(15,12);
   ymin = g_AnaRes(15,13);
   ymax = g_AnaRes(15,14);
   r1 = g_AnaRes(15,5);
   qstart = 0;
   qstop = 360;

   if nFigNum > 0
      nType = get(handles(2),'value');
      axes(handles(6));
      if nType == 4
         CreateMechanismHandles( handles(6),r1,Dx,Dy,Ex,Ey,Gx,Gy,xmin,xmax,ymin,ymax);
      else   
         i = nType * 2 -1;
      	line1 = line( 'xdata', g_AnaRes(i,:), 'ydata', g_AnaRes(i+1,:),'tag','line1','color', 'r');
			b1 = line('xdata', [], 'ydata', [],'marker','o','markersize', 6, 'erasemode','xor','tag','b1');
      	handles(11) = b1;
      	labels = GetFigLabel( nType );
      	xlabel(labels(1));
         ylabel(labels(2));
         axis([qstart qstop min(g_AnaRes(i+1,:)) max(g_AnaRes(i+1,:)) ]);
      end
   end      
   if nFigNum > 1
      nType = get(handles(3),'value');
      axes(handles(7));
      if nType == 4
         CreateMechanismHandles( handles(7),r1,Dx,Dy,Ex,Ey,Gx,Gy,xmin,xmax,ymin,ymax);
      else   
         i = nType * 2 -1;
      	line2 = line( 'xdata', g_AnaRes(i,:), 'ydata', g_AnaRes(i+1,:),'tag','line2','color', 'r');
			b2 = line('xdata', [], 'ydata', [],'marker','o','markersize', 6, 'erasemode','xor','tag','b2');
      	handles(12) = b2;
			labels = GetFigLabel( nType );
      	xlabel(labels(1));
      	ylabel(labels(2));
         axis([qstart qstop min(g_AnaRes(i+1,:)) max(g_AnaRes(i+1,:)) ]);
      end
	end      
   
   if nFigNum > 2
      nType = get(handles(4),'value');
      axes(handles(8));
      if nType == 4
         CreateMechanismHandles( handles(8),r1,Dx,Dy,Ex,Ey,Gx,Gy,xmin,xmax,ymin,ymax);
      else   
         i = nType * 2 -1;
      	line3 = line( 'xdata', g_AnaRes(i,:), 'ydata', g_AnaRes(i+1,:),'tag','line3','color', 'r');
			b3 = line('xdata', [], 'ydata', [],'marker','o','markersize', 6, 'erasemode','xor','tag','b3');
      	handles(13) = b3;
			labels = GetFigLabel( nType );
      	xlabel(labels(1));
      	ylabel(labels(2));
         axis([qstart qstop min(g_AnaRes(i+1,:)) max(g_AnaRes(i+1,:)) ]);
      end
	end      
   
   if nFigNum > 3
      nType = get(handles(5),'value');
      axes(handles(9));
      if nType == 4
         CreateMechanismHandles( handles(9),r1,Dx,Dy,Ex,Ey,Gx,Gy,xmin,xmax,ymin,ymax);
   	else  
         i = nType * 2 -1;
      	line4 = line( 'xdata', g_AnaRes(i,:), 'ydata', g_AnaRes(i+1,:),'tag','line4','color', 'r');
			b4 = line('xdata', [], 'ydata', [],'marker','o','markersize', 6, 'erasemode','xor','tag','b4');
      	handles(14) = b4;
			labels = GetFigLabel( nType );
      	xlabel(labels(1));
         ylabel(labels(2));
         axis([ qstart qstop min(g_AnaRes(i+1,:)) max(g_AnaRes(i+1,:)) ]);
      end
   end
   drawnow;
   a = findobj('Tag','Sixbar Analysis Window');   
   set(a,'Userdata',handles);
   
case 'None'
	figure( findobj('Tag','Sixbar Analysis Window'));
	% Bring the figure to front, if it already exists

case 'Close'
   sixbar_ana('Stop');
   a = findobj('Tag','Sixbar Analysis Window');   
   close(a);

case 'Start'
   if exist('nAnimationFlag')
      if nAnimationFlag == 1
         return;
      end
   end
   
   a = findobj('Tag','Sixbar Analysis Window');   
   handles = get(a,'userdata');
   set(handles(1),'Enable','off');
   set(handles(2),'Enable','off');
   set(handles(3),'Enable','off');
   set(handles(4),'Enable','off');
   set(handles(5),'Enable','off');
   set(handles(21),'Enable','off');
   set(handles(22),'Enable','off');
   set(handles(23),'Enable','off');
   
   nAnimationFlag = 1;
   nChangeSpeed = 0;
   handles(10) = nAnimationFlag;
   set(a,'userdata',handles);
   sixbar_ana('Animation');
   
case 'Stop'
   if  ~findobj('Tag','Sixbar Analysis Window')   
   	return;   
   end
   a = findobj('Tag','Sixbar Analysis Window');   
   handles = get(a,'userdata');
   nAnimationFlag = 0;
   handles(10) = nAnimationFlag;
   set(a,'userdata',handles);
   set(handles(1),'Enable','on');
   set(handles(21),'Enable','on');
   set(handles(22),'Enable','on');
   set(handles(23),'Enable','on');
   nFigNum = get(handles(1),'value');
   for i = 1:nFigNum,
   	set(handles(i+1),'Enable','on');
   end   
case 'Return'
   sixbar_ana('Stop');
   if ~isempty(findobj('Tag','sixbar_dsgn'))   
  		b = findobj('Tag','sixbar_dsgn');
      figure(b);
   	b = findobj('Tag','Sixbar Analysis Window');   
	  	close(b);
   else
   	return;      
   end
case 'GetFile'
   % Get the file name using the UIGETFILE
   [sFileName sFilePath] = uigetfile('*.dat','Load File');
   
   if sFileName == 0 & sFilePath == 0
      return;
   end   
   
   % Combine the path and file name together
   sTemp = strcat( sFilePath, sFileName );
	% get the size to erase the '.dat' extension   
   sz  = size(sFileName);
	% load the data file   
   load(sTemp);
	% assign the parameter to a variable
   Parameter = eval(sFileName(1:(sz(2)-4)));
   
   a = findobj('Tag','Sixbar Analysis Window');   
   handles = get(a,'userdata');
   
   if length(Parameter) == 5
	   nFigNum  = Parameter(1);
   	nType1 = Parameter(2);
	   nType2 = Parameter(3);
   	nType3 = Parameter(4);
      nType4 = Parameter(5);
      
   	set(handles(1),'Value',nFigNum);
   	set(handles(2),'Value',nType1);
   	set(handles(3),'Value',nType2);
   	set(handles(4),'Value',nType3);
      set(handles(5),'Value',nType4);
      
      set(a,'userdata',handles);
   	DrawAnalysisWindow;
      sixbar_ana('ShowFigure');
      sixbar_ana('Start');
   else
      return;
   end          
   
case 'PutFile'
   [sFileName sFilePath] = uiputfile('*.dat','Save As');
   
   a = findobj('Tag','Sixbar Analysis Window');   
   handles = get(a,'userdata');
   
   nFigNum  = get(handles(1),'Value');
   nType1 = get(handles(2),'Value');
	nType2 = get(handles(3),'Value');
   nType3 = get(handles(4),'Value');
   nType4 = get(handles(5),'Value');
   ParameterData = [nFigNum; nType1; nType2; nType3; nType4];
   
%   sTemp = strcat( sFilePath, sFileName)
   [sTemp , errMsg] = sprintf('%s%s', sFilePath, sFileName);
   [strCmd, errMsg] = sprintf('%s %s %s', 'save', sTemp, ' -ascii ParameterData');
   eval(strCmd);   
   
end % switch

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	Show UI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DrawAnalysisWindow();
a = findobj('Tag','Sixbar Analysis Window');
handles = get(a,'userdata');
h_fignum = handles(1);
h_fig1 = handles(2);
h_fig2 = handles(3);
h_fig3 = handles(4);
h_fig4 = handles(5);
nFigNum=get(h_fignum,'Value');
position = zeros( 4, 4, 4);
position(1,1,:) = [0.08 0.25 0.87 0.73];
position(2,1,:) = [0.25 0.63 0.5 0.36];
position(2,2,:) = [0.25 0.198 0.5 0.36];
position(3,1,:) = [0.1 0.42 0.38 0.31];
position(3,2,:) = [0.58 0.65 0.38 0.31];
position(3,3,:) = [0.58 0.22 0.38 0.31];
position(4,1,:) = [0.1 0.65 0.38 0.31];
position(4,2,:) = [0.58 0.65 0.38 0.31];
position(4,3,:) = [0.1 0.22 0.38 0.31];
position(4,4,:) = [0.58 0.22 0.38 0.31]; 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Clearup previous axes first
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for i = 6:9,
	if handles(i) ~= 0
		delete(handles(i));
		handles(i) = 0;
	end
end
for i = 17:20,
	if handles(i) ~= 0
		delete(handles(i));
		handles(i) = 0;
	end
end


for i = 1:nFigNum,
	set(handles(i+1),'Enable','on');
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Axis 1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

if nFigNum == 1
	b = axes('Parent',a, ...
	'Box','on', ...
	'Color',[1 1 1], ...
	'Position',position(1,1,:), ...
	'XColor',[0 0 0], ...
	'XGrid','off', ...
	'XTick',[],...
	'YColor',[0 0 0], ...
	'YGrid','off', ...
	'YTick',[], ...
	'ZColor',[0 0 0], ...
	'ZGrid','off', ...
	'ZTick',[]);
handles(17) = b;

h_1 = axes('Parent',a, ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Color',[1 1 1], ...
	'Position',position(1,1,:), ...
	'Tag','Axes1', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);
handles(6) = h_1;

end	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Axis 2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if nFigNum == 2

	b = axes('Parent',a, ...
	'Box','on', ...
	'Color',[1 1 1], ...
	'Position',position(2,1,:), ...
	'XColor',[0 0 0], ...
	'XGrid','off', ...
	'XTick',[],...
	'YColor',[0 0 0], ...
	'YGrid','off', ...
	'YTick',[], ...
	'ZColor',[0 0 0], ...
	'ZGrid','off', ...
	'ZTick',[]);
handles(17) = b;

h_1 = axes('Parent',a, ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Color',[1 1 1], ...
	'Position',position(2,1,:), ...
	'Tag','Axes1', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
   'ZColor',[0 0 0]);

b = axes('Parent',a, ...
	'Box','on', ...
	'Color',[1 1 1], ...
	'Position',position(2,2,:), ...
	'XColor',[0 0 0], ...
	'XGrid','off', ...
	'XTick',[],...
	'YColor',[0 0 0], ...
	'YGrid','off', ...
	'YTick',[], ...
	'ZColor',[0 0 0], ...
	'ZGrid','off', ...
	'ZTick',[]);
handles(18) = b;
h_2 = axes('Parent',a, ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Color',[1 1 1], ...
	'Position',position(2,2,:), ...
	'Tag','Axes2', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);
handles(6) = h_1;
handles(7) = h_2;

end	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Axis 3
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if nFigNum == 3
	b = axes('Parent',a, ...
	'Box','on', ...
	'Color',[1 1 1], ...
	'Position',position(3,1,:), ...
	'XColor',[0 0 0], ...
	'XGrid','off', ...
	'XTick',[],...
	'YColor',[0 0 0], ...
	'YGrid','off', ...
	'YTick',[], ...
	'ZColor',[0 0 0], ...
	'ZGrid','off', ...
	'ZTick',[]);
handles(17) = b;

h_1 = axes('Parent',a, ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Color',[1 1 1], ...
	'Position',position(3,1,:), ...
	'Tag','Axes1', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);

b = axes('Parent',a, ...
	'Box','on', ...
	'Color',[1 1 1], ...
	'Position',position(3,2,:), ...
	'XColor',[0 0 0], ...
	'XGrid','off', ...
	'XTick',[],...
	'YColor',[0 0 0], ...
	'YGrid','off', ...
	'YTick',[], ...
	'ZColor',[0 0 0], ...
	'ZGrid','off', ...
	'ZTick',[]);
handles(18) = b;

h_2 = axes('Parent',a, ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Color',[1 1 1], ...
	'Position',position(3,2,:), ...
	'Tag','Axes2', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);

b = axes('Parent',a, ...
	'Box','on', ...
	'Color',[1 1 1], ...
	'Position',position(3,3,:), ...
	'XColor',[0 0 0], ...
	'XGrid','off', ...
	'XTick',[],...
	'YColor',[0 0 0], ...
	'YGrid','off', ...
	'YTick',[], ...
	'ZColor',[0 0 0], ...
	'ZGrid','off', ...
	'ZTick',[]);
handles(19) = b;

h_3 = axes('Parent',a, ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Color',[1 1 1], ...
	'Position',position(3,3,:), ...
	'Tag','Axes3', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);
handles(6) = h_1;
handles(7) = h_2;
handles(8) = h_3;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Axis 4
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if nFigNum == 4
	b = axes('Parent',a, ...
	'Box','on', ...
	'Color',[1 1 1], ...
	'Position',position(4,1,:), ...
	'XColor',[0 0 0], ...
	'XGrid','off', ...
	'XTick',[],...
	'YColor',[0 0 0], ...
	'YGrid','off', ...
	'YTick',[], ...
	'ZColor',[0 0 0], ...
	'ZGrid','off', ...
	'ZTick',[]);
handles(17) = b;

h_1 = axes('Parent',a, ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Color',[1 1 1], ...
	'Position',position(4,1,:), ...
	'Tag','Axes1', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);

b = axes('Parent',a, ...
	'Box','on', ...
   'Color',[1 1 1], ...
	'Position',position(4,2,:), ...
	'XColor',[0 0 0], ...
	'XGrid','off', ...
	'XTick',[],...
	'YColor',[0 0 0], ...
	'YGrid','off', ...
	'YTick',[], ...
	'ZColor',[0 0 0], ...
	'ZGrid','off', ...
	'ZTick',[]);
handles(18) = b;

h_2 = axes('Parent',a, ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Color',[1 1 1], ...
	'Position',position(4,2,:), ...
	'Tag','Axes2', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);

b = axes('Parent',a, ...
	'Box','on', ...
	'Color',[1 1 1], ...
	'Position',position(4,3,:), ...
	'XColor',[0 0 0], ...
	'XGrid','off', ...
	'XTick',[],...
	'YColor',[0 0 0], ...
	'YGrid','off', ...
	'YTick',[], ...
	'ZColor',[0 0 0], ...
	'ZGrid','off', ...
	'ZTick',[]);
handles(19) = b;
h_3 = axes('Parent',a, ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Color',[1 1 1], ...
	'Position',position(4,3,:), ...
	'Tag','Axes3', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);
b = axes('Parent',a, ...
	'Box','on', ...
	'Color',[1 1 1], ...
	'Position',position(4,4,:), ...
	'XColor',[0 0 0], ...
	'XGrid','off', ...
	'XTick',[],...
	'YColor',[0 0 0], ...
	'YGrid','off', ...
	'YTick',[], ...
	'ZColor',[0 0 0], ...
	'ZGrid','off', ...
	'ZTick',[]);
handles(20) = b;

h_4 = axes('Parent',a, ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Color',[1 1 1], ...
	'Position',position(4,4,:), ...
	'Tag','Axes4', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);
handles(6) = h_1;
handles(7) = h_2;
handles(8) = h_3;
handles(9) = h_4;
end

	set( a, 'Userdata', handles);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	Show UI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function LocalOpenFig();
strFigType = [ ...
      '4-bar rocker ang';...
      'dwell rocker ang';...
      'dwell rocker vel';...
      'mechanism       '];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	Main Figure
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ScreenSize = get(0,'ScreenSize');
sx = 520;
sy = 440;
FigPos = [ ScreenSize(3)-sx-10 ScreenSize(4)-sy-40 sx sy ] ;
a = figure('Units','Pixels', ...
		'Color',[0.8 0.8 0.8], ...
      'Name','Six Bar Analysis Window', ... 
      'NumberTitle','off', ...
		'Position',FigPos, ...
	 	'Tag','Sixbar Analysis Window');
	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Draw the frame for Figure Selection
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'BackgroundColor',[0.752941 0.752941 0.752941], ...
   'Position',[0.01731 0.020 0.77 0.1117], ...
   'Style','frame', ...
	'Tag','Frame2');
	
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'Position',[0.7808 0.020 0.2038 0.1117], ...
   'Style','frame', ...
   'Tag','Frame1');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Menu uicontrols
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
b = uimenu('Parent',a, ...
	'Label','Parameter', ...
	'Tag','menu_parameter');

h_load = uimenu('Parent',b, ...
	'Callback','sixbar_ana(''GetFile'')', ...
	'Label','Load', ...
	'Tag','submenu_load');

h_save = uimenu('Parent',b, ...
	'Callback','sixbar_ana(''PutFile'')', ...
	'Label','Save', ...
	'Tag','submenu_save');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Setup number of figures
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
b = uicontrol('Parent',a, ...
   'Units','normalized', ...
	'Position',[0.03 0.07 0.095 0.03911], ... 
	'String','No. of figs ', ...
	'Style','text', ...
	'Tag','StaticText2');

h_fignum = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'Callback','sixbar_ana(''ChangeFigureNo'');', ...
   'Position',[0.135 0.0837 0.10 0.03538], ...
   'String',['1';'2';'3';'4'], ...
   'Style','popupmenu', ...
	'Tag','FigNumber', ...
 	'Value',4);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Speed Control
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'Position',[0.03 0.02793 0.08 0.03910], ...
   'String','Speed ', ...
	'Style','text', ...
 	'Tag','StaticText2');
	
h_plus = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'Callback','sixbar_ana(''SetSpeed'',0.707);', ...
   'Position',[0.1327 0.02955 0.04038 0.03182], ... 
   'String','+', ...
	'Enable','on', ...
	'Tag','Plus_button');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'Callback','sixbar_ana(''SetSpeed'',1.414);', ...
   'Position',[0.2 0.02955 0.04038 0.03182], ...
   'String','-', ...
 	'Tag','Minus_button');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Put label in front of the popup menu item 	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'Position',[0.2442 0.07821 0.06262 0.03724], ...
   'String','Fig 1', ...
	'Style','text', ...
 	'Tag','StaticText1');
 
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'Position',[0.5019 0.08007 0.06262 0.03724], ...
   'String','Fig 2', ...
	'Style','text', ...
	'Tag','StaticText1');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'Position',[0.2442 0.03352 0.06262 0.03724], ...
   'String','Fig 3', ...
   'Style','text', ...
	'Tag','StaticText1');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'Position',[0.5019 0.03724 0.06262 0.03724], ...
   'String','Fig 4', ...
	'Style','text', ...
	'Tag','StaticText1');
	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Setup the Popup menu contents for Figure Type Selection 	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h_fig1 = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'Callback','sixbar_ana(''ChangeFigure'',1);', ...
   'Position',[0.3077 0.0837 0.19256 0.03538], ...
   'String',strFigType, ...
 	'Style','popupmenu', ...
	'Tag','Fig1', ...
	'Value',4);

h_fig2 = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'Callback','sixbar_ana(''ChangeFigure'',2);', ...
   'Position',[0.5692 0.0837 0.19256 0.03538], ...
   'String',strFigType, ...
	'Style','popupmenu', ...
	'Tag','Fig2', ...
	'Value',1);

h_fig3 = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'Callback','sixbar_ana(''ChangeFigure'',3);', ...
   'Position',[0.3077 0.04024 0.1926 0.03538], ...
   'String',strFigType, ...
	'Style','popupmenu', ...
	'Tag','Fig3', ...
	'Value',2);

h_fig4 = uicontrol('Parent',a, ...
	'Units','normalized', ...
   'Callback','sixbar_ana(''ChangeFigure'',4);', ...
   'Position',[0.5692 0.04024 0.1926 0.03538], ...
   'String',strFigType, ...
   'Style','popupmenu', ...
	'Tag','Fig4', ...
	 'Value',3);
	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Start/Stop/Return
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h_start = uicontrol('Parent',a, ...
   'Units','normalized', ...
	'CallBack','sixbar_ana(''Start'')', ...
   'Position',[0.7942 0.07727 0.08577 0.04318], ...
   'String','Start', ...
	'Tag','start_button');

h_stop = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'CallBack','sixbar_ana(''Stop'')', ...
	'Position',[0.8854 0.07727 0.08577 0.04318], ... 
   'String','Stop', ...
   'Userdata',1,...
	'Tag','stop_button');

h_return = uicontrol('Parent',a, ...
   'Units','normalized', ...
	'CallBack','sixbar_ana(''Return'')', ...
	'Position',[0.7942 0.02891 0.1773 0.04318], ... 
   'String','Return', ...
   'Tag','return_button');
drawnow;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Assign Initial value
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
nAnimationFlag = 0;
handles = zeros( 1, 24);
handles(1) = h_fignum;
handles(2) = h_fig1;
handles(3) = h_fig2;
handles(4) = h_fig3;
handles(5) = h_fig4;
handles(10) = nAnimationFlag;
handles(15) = 1;
% initial animation starting index
handles(16) = 0.1;
% initial timesink value
handles(21) = h_load;
handles(22) = h_save;
handles(23) = h_return;
handles(24) = h_plus;
set( a, 'Userdata', handles);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	String Table
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [ labels ] = GetFigLabel( nFigType )
	strTable = cell( 3, 3 );
   strTable( 1,:) = {'crank angle (degree)';'4-bar rocker angle (deg)';'4-bar rocker angle graph';};
   strTable( 2,:) = {'crank angle (degree)';'dwell rocker angle (deg)';'dwell rocker angle graph';};
   strTable( 3,:) = {'crank angle (degree)';'dwell rocker omega (deg/s)';'dwell rocker amgular velocity graph';};
   labels = strTable( nFigType, : );

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	Calculate the result
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [res] = CalcResult( r, beta, Q1, Gx, Gy, w2, dmode );
r1 = r(1);
r2 = r(2);
r3 = r(3);
r4 = r(4);
r5 = r(5);
r6 = r(6);
cr = r(7);
Q11=Q1*pi/180;

% Define constants

i=0;
d2r=pi/180;
r2d=180/pi;
mode=-1;
dt=5;
 
% Loop to analyze the linkage

for Q21 = 0:dt:360;
	i=i+1;
	Q2 = Q21*d2r;

% Call function to compute the fourbar position

	para = fourbar(r1,r2,r3,r4,Q21,w2,0,mode,Q1,2);
	Q3=para(7);
	Q33(i)=Q3;
	Q4=para(8);
	Q44(i)=Q4;
	w33(i)=para(11);
	w44(i)=para(12);
	assem=para(29);
	cang=(Q3+beta)*d2r;

% Store position information in matrices.

	Bx(i)= para(17);
	By(i)= para(18);
	Cx(i)= para(19);
	Cy(i)= para(20);
	Ex(i)=Bx(i)+cr*cos(cang);
	Ey(i)=By(i)+cr*sin(cang);
	Q22(i) = Q21;
	w22(i) = w2; 

% Analyze the rigid body

	value = rbody1(cr,beta, para(17),para(18),para(19),para(20), ...
		para(21),para(22),para(23),para(24),para(25),para(26),...
		para(27),para(28),2);

% Analyze the dyad

	values = dyad(r5,r6,Ex(i),Ey(i),value(3),value(4),value(5),value(6),Gx,...
		         Gy,0,0,0,0,dmode,2,0);
	Fx(i)= values(1);
	Fy(i)= values(2);
	Q6(i)=values(4);
	w66(i)=values(8);
	if values(13)==0;i=i-1;end
end
itotal=i;
% Check that the output dyad for the linkage can be assembled.

if itotal == 0
   return;
end	

if itotal > 0

% Compute the angle change for the output link
	
   Q6min=min(Q6);
   Dsize = length(Q22);
	for k=1:Dsize
		Q66(k)=Q6(k)-Q6min;
	end		
	Ax= 0;
	Ay= 0;
	Dx= r1*cos(Q1*pi/180);
	Dy= r1*sin(Q1*pi/180);

% Get the bushing points

	bush1=bushing((r1/50),0,0,20,0);
	cir1=circle2((r1/60),0,0,20);
	bush2=bushing((r1/50),Dx,Dy,20,0);
	cir2=circle2((r1/60),Dx,Dy,20);
	bush3=bushing((r1/50),Gx,Gy,20,0);
	cir3=circle2((r1/60),Gx,Gy,20);

% Define the axes for the graph showing the dwell linages

	height=0.8;
	width=0.8;
	xmina=min([min(Ex),min(Fx),min(Bx),min(Cx),Dx, Gx, ...
	    min(bush1(:,1)), min(bush2(:,1)), min(bush3(:,1))]);
	xmaxa=max([max(Ex),max(Fx),max(Bx),max(Cx),Dx, Gx, ...
	    max(bush1(:,1)), max(bush2(:,1)), max(bush3(:,1))]);
	ymina=min([min(Ey),min(Fy),min(By),min(Cy),Dy, Gy, ...
	    min(bush1(:,2)), min(bush2(:,2)), min(bush3(:,2))]);
	ymaxa=max([max(Ey),max(Fy),max(By),max(Cy),Dy, Gy, ...
	    max(bush1(:,2)), max(bush2(:,2)), max(bush3(:,2))]);
	rangex=xmaxa-xmina;
	rangey=ymaxa-ymina;
	xmin=xmina-0.05*rangex;
	xmax=xmaxa+0.05*rangex;
	ymin=ymina-0.05*rangey;
	ymax=ymaxa+0.05*rangey;
	values=axisadjust(xmin, xmax, ymin, ymax, width, height);
	xmin=values(1);
	xmax=values(2);
	ymin=values(3);
	ymax=values(4);
end 
res = zeros( 15, Dsize);
i = 0;
i = i+1; res( i,: ) = Q22;
i = i+1; res( i,: ) = Q44;

i = i+1; res( i,: ) = Q22;
i = i+1; res( i,: ) = Q66;

i = i+1; res( i,: ) = Q22;
i = i+1; res( i,: ) = w66;

i = i+1; res( i,: ) = Bx;
i = i+1; res( i,: ) = By;

i = i+1; res( i,: ) = Cx;
i = i+1; res( i,: ) = Cy;

i = i+1; res( i,: ) = Ex;
i = i+1; res( i,: ) = Ey;

i = i+1; res( i,: ) = Fx;
i = i+1; res( i,: ) = Fy;

i = i+1;
res( i,1:4 ) = [ Dx Dy Gx Gy ];
res( i,5:11 ) = r;
res(i,11:14) = [xmin,xmax,ymin,ymax];
res(i,15) = Dsize;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fig Setting for Special Case
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [] = CreateMechanismHandles( handle,r1,Dx,Dy,Ex,Ey,Gx,Gy,xmin,xmax,ymin,ymax) 

axes(handle);
%setup the aspect ratio of the mechanism to 1 
set(handle, 'DataAspectRatio',[1 1 1],'Color','none','box','off');
axis off;
% Set up coordinates of bushings and pins.
width=0.95;
height=0.95;
axis([xmin xmax ymin ymax]);
bush1=bushing((r1/50),0,0,20,0);
cir1=circle2((r1/60),0,0,20);
bush2=bushing((r1/50),Dx,Dy,20,0);
cir2=circle2((r1/60),Dx,Dy,20);
bush3=bushing((r1/50),Gx,Gy,20,0);
cir3=circle2((r1/60),Gx,Gy,20);
joint1=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
      6, 'erasemode', 'xor', 'color', 'k');
joint2=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
      6, 'erasemode', 'xor', 'color', 'k');
joint3=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
      6, 'erasemode', 'xor', 'color', 'k');
joint4=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
      6, 'erasemode', 'xor', 'color', 'k');
crank=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
      'xor','color', 'k');
r5link=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
      'xor','color', 'k');
r6link=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
      'xor','color', 'k');
coupler=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
      'xor','color', 'k');
couplerptr=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
      'xor','color', 'k');
	  
couplerpt1=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
      'none','color', 'r', 'linestyle', '-');


[n,m]=size(Ex);
itotal=m;

for ipoints =1:itotal	   
	gridline1(ipoints)=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
       'none','color', 'r', 'linestyle', '-');	
end	   
	  
	  
rocker=line('xdata', [], 'ydata' ,[], 'linewidth',1,...
      'erasemode', 'xor','color', 'k');
bushy1=line('xdata', [], 'ydata',[], 'linestyle', '-', ...
       'color', 'r');
bushy2=line('xdata', [], 'ydata',[], 'linestyle', '-', ...
       'color', 'r');
bushy3=line('xdata', [], 'ydata',[], 'linestyle', '-', ...
       'color', 'r');
circ1=line('xdata', [], 'ydata',[], 'linestyle', '-',...
       'color', 'r');
circ2=line('xdata', [], 'ydata',[], 'linestyle', '-', ...
        'color', 'r');
circ3=line('xdata', [], 'ydata',[], 'linestyle', '-', ...
        'color', 'r');
		
% Draw the fixed curves first.

set(bushy1,'xdata', bush1(:,1), 'ydata',bush1(:,2));
set(bushy2,'xdata', bush2(:,1), 'ydata',bush2(:,2));
set(bushy3,'xdata', bush3(:,1), 'ydata',bush3(:,2));
set(circ1,'xdata', cir1(:,1), 'ydata',cir1(:,2));
set(circ2,'xdata', cir2(:,1), 'ydata',cir2(:,2));
set(circ3,'xdata', cir3(:,1), 'ydata',cir3(:,2));

%set(couplerpt1,'xdata', Ex, 'ydata' ,Ey);

for ipoints = 1:itotal
	if ipoints <itotal
		msdx=Ex(ipoints);
		midx=Ex(ipoints)+(Ex(ipoints+1)-Ex(ipoints))/2;
		msdy=Ey(ipoints);
		midy=Ey(ipoints)+(Ey(ipoints+1)-Ey(ipoints))/2;
	end
	if ipoints ==itotal&itotal==72
		msdx=Ex(ipoints);
		midx=Ex(ipoints)+(Ex(1)-Ex(ipoints))/2;
		msdy=Ey(ipoints);
		midy=Ey(ipoints)+(Ey(1)-Ey(ipoints))/2;
	end				
	set(gridline1(ipoints),'xdata', [msdx midx],'ydata',[msdy midy]);
end

hdls=[ joint1 joint2 joint3 joint4 crank coupler ...
     	 rocker couplerptr r5link r6link ];
set(handle,'userdata',hdls);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Set the mechanism position
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [] = SetMechanismPosition( links,i,Bx,By,Cx,Cy,Dx,Dy,Ex,Ey,Fx,Fy,Gx,Gy)
joint1 = links(1);
joint2 = links(2);
joint3 = links(3);
joint4 = links(4);
crank = links(5);
coupler = links(6);
rocker = links(7);
couplerptr = links(8);
r5link = links(9);
r6link = links(10);
set(joint1,'xdata', Bx(i), 'ydata',By(i));
set(joint2,'xdata', Cx(i), 'ydata',Cy(i));
set(joint3,'xdata', Ex(i), 'ydata',Ey(i));
set(joint4,'xdata', Fx(i), 'ydata',Fy(i));
set(crank,'xdata',[0 Bx(i)],'ydata', [0 By(i)]);
set(coupler,'xdata', [Bx(i) Cx(i)],'ydata', [By(i) Cy(i)]);
set(rocker,'xdata', [Dx Cx(i)],'ydata', [Dy Cy(i)]);
set(couplerptr,'xdata', [Bx(i) Ex(i) Cx(i)],...
	'ydata' ,[By(i) Ey(i) Cy(i)]);
set(r5link,'xdata',[Ex(i) Fx(i)],'ydata', [Ey(i) Fy(i)]);
set(r6link,'xdata',[Gx Fx(i)],'ydata', [Gy Fy(i)]);



