function [] = tutorial_dial(Action,Argument2)
global nBetaflag
% nBetaflag is the flag for deciding the beta input from the keyboard or from the mouse input
% nBetaflag = 0 is for the mouse input; nBetaflag = 1 is for the keyboard input
global nR1flag
% nCradiusflag is the flag for deciding the coupler radius input
% nCradiusflag = 0 is for the mouse input; nCradiusflag = 1 is for the keyboard input
global d2r
d2r=pi/180;

if nargin == 0 & isempty(findobj('Tag','tutorial_dsgn'))
	Action = 'initialize';
elseif nargin == 0 & findobj('Tag','tutorial_dsgn')
   Action = 'None';
end

if ~strcmp(Action,'initialize')
   a = findobj('Tag','tutorial_dsgn');
   b = findobj('Tag','tutorial_axes');
% To retrieve handles for uicontrols   
   handles = get(a,'UserData');
   h_r1 = handles(1);
   h_beta = handles(2);
   h_Lradio = handles(3:4);
% To retrieve graphics handles   
   r1 = get(h_r1,'userdata');
   beta = get(h_beta,'userdata');
   
   handles =get(b,'UserData');
   joint1 = handles(1);
   r1link = handles(2);
   r2link = handles(3);
   pin1 = handles(4); 
   pin2 = handles(5); 
end

switch Action
case 'None' 
   findobj('Tag','tutorial_dsgn');

case 'initialize'
   LocalOpenFig;
   nBetaflag = 0;
   nR1flag = 0;
   tutorial_dial('DrawAxe');

case 'DrawAxe'
   Ax = 0;
   Ay = 0;
   Cx = 4;
   Cy = 0;
   betar = beta *pi/180;
   Bx = r1*cos(betar)+Ax;
   By = r1*sin(betar)+Ay;
   width=0.95;
   height=0.95;
% find the axis limit;
   xmina=min([Ax Bx Cx]);
   xmaxa=max([Ax Bx Cx]);
   ymina=min([Ay By Cy]);
   ymaxa=max([Ay By Cy]);
   rangex=xmaxa-xmina;
   rangey=ymaxa-ymina;
   xmin=xmina-0.1*rangex;
   xmax=xmaxa+0.1*rangex;
   ymin=ymina-0.1*rangey;
   ymax=ymaxa+0.1*rangey;
   values = axisadjust(xmin, xmax, ymin, ymax, width, height);   
   xmin=values(1);
   xmax=values(2);
   ymin=values(3);
   ymax=values(4);
   axis([xmin xmax ymin ymax]);

   cir1=circle2(((ymax-ymin)/60),Ax,Ay,20);
   cir2=circle2(((ymax-ymin)/60),Cx,Cy,20);
   set(pin1,'xdata', cir1(:,1), 'ydata', cir1(:,2));
   set(pin2,'xdata', cir2(:,1), 'ydata', cir2(:,2));
   set(joint1,'xdata', Bx, 'ydata',By);
   set(r1link,'xdata', [Bx Ax],'ydata', [By Ay]);
   set(r2link,'xdata', [Bx Cx],'ydata', [By Cy]);

   set(h_r1,'userdata',r1,'string',num2str(r1));
   set(h_beta,'userdata',beta,'string',num2str(beta));
   set([joint1 r1link],...
   	'buttondownfcn','tutorial_dial(''Set Calls'');tutorial_dial(''Rotate'')');
  
case 'Set Calls'
 
% get the handle of the objects used to control
% the mouse input 
   a = findobj('Tag','tutorial_dsgn');
   nBetaflag = 0;
   nR1flag = 0;
   set(a,'windowbuttonupfcn', 'a = findobj(''Tag'',''tutorial_dsgn'');set(a,''windowbuttonmotion'','''');refresh;');
   set(a,'windowbuttonmotionfcn','tutorial_dial(''Rotate'')');
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The Callbacks When The User Moves the Mouse Button.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
case 'Rotate'
% Find out where the mouse pointer is located.
   a = findobj('Tag','tutorial_dsgn');
   b = findobj('Tag','tutorial_axes');
   Ax = 0;
   Ay = 0;
   Cx = 4;
   Cy = 0;
   if nBetaflag == 1 | nR1flag == 1
      % Check the validness of the r1 input and the beta input.
      a = get(h_beta,'userdata');
      b = get(h_beta,'string');
      beta = check_val(a,b);
      a = get(h_r1,'userdata');
      b = get(h_r1,'string');
      r1 = check_val(a,b);
   else   
      pt = get(b,'currentpoint');
      pt = pt(1,1:2);
     
      beta = atan2(pt(2)-Ay,pt(1)-Ax)*180/pi;
      r1 = sqrt((pt(2) -Ay)^2 + (pt(1) -Ax)^2);
   end
   
% Set beta angle range between 180 and -180 degree
% When beta exceeds 180, its value will be converted into minus value, and vise versa  
   if beta > 180
      beta = beta -180;
   elseif beta < -180
      beta = beta + 360;
   end   
   betar = beta *pi/180;
   Bx = r1*cos(betar)+Ax;
   By = r1*sin(betar)+Ay;
% Store the value in the current axes UserData
% where it can be retrieved by an application.
   set(joint1,'xdata', Bx, 'ydata',By);
   set(r1link,'xdata', [Bx Ax],'ydata', [By Ay]);
   set(r2link,'xdata', [Bx Cx],'ydata', [By Cy]);
   drawnow;
   set(h_r1,'userdata',r1,'string',num2str(r1));
   set(h_beta,'userdata',beta,'string',num2str(beta));

case 'ChangeBeta'
   nBetaflag = 1;
   % Do not set the beta value from the String property to te UserData of h_beta.
   % In the case 'Rotate', it will check the validness of the beat input because
   % the flag nBetaflag is set to 1 here.
   tutorial_dial('Rotate');

case 'ChangeR1'
   nR1flag = 1;   
   % Do not set the r1 value from the String property to te UserData of h_r1.
   % In the case 'Rotate', it will check the validness of the r1 input because
   % the flag nR1flag is set to 1 here.
   tutorial_dial('Rotate');

case 'ChangeWidth'
   if findobj('Tag','tutorial_axes')
      axes(findobj('Tag','tutorial_axes'));
   end
   
   if Argument2 == 1
      set(r1link,'linewidth',4);   
      set(r2link,'linewidth',4); 
      set(h_Lradio(2),'value',0);
   else
      set(r1link,'linewidth',2);   
      set(r2link,'linewidth',2);   
      set(h_Lradio(1),'value',0);
   end
 
end

function LocalOpenFig()
hdls = zeros(25,0);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Control the color of the UI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
StdColor = get(0,'DefaultUIcontrolBackgroundColor');
%PointsPerPixel = 72/get(0,'ScreenPixelsPerInch');
bgframe = StdColor;
bgedit = [1 1 1];
bgtext = bgframe;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The Main Figure of Crank Rocker Design
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ScreenSize = get(0,'ScreenSize');
sx = 480;
sy = 400;
FigPos = [ 10 ScreenSize(4)-sy-40 sx sy ] ;
a = figure('Units','pixels', ...
	'Color',[0.8 0.8 0.8], ...
	'Name','Tutorial Dial Design', ...
	'NumberTitle','off', ...
	'Position',FigPos, ...
  	'Tag','tutorial_dsgn');
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Create graphics window for design input
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%-------Reference axis
b = axes('Parent',a, ...
  	'Box','on', ...
  	'Color',[1 1 1], ...
   'Position',[0.09464 0.2643 0.7839 0.6690], ...
  	'XColor',[0 0 0], ...
  	'XGrid','off', ...
  	'XTick',[],...
  	'YColor',[0 0 0], ...
  	'YGrid','off', ...
  	'YTick',[], ...
  	'ZColor',[0 0 0], ...
  	'ZGrid','off', ...
   'ZTick',[], ...
   'tag','ref_axes');

%-------Working axis 
b = axes('Parent',a, ...
	'Box','off', ...
  	'DataAspectRatio',[1 1 1],...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
   'Position',[0.09464 0.2643 0.7839 0.6690], ...
   'Tag','tutorial_axes');

b = uicontrol('Parent',a, ...
   'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'ListboxTop',0, ...
	'Position',[0.09464 0.0425 0.7839 0.15], ...
	'Style','frame', ...
	'Tag','Frame1');

b = uicontrol('Parent',a, ...
   'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'ListboxTop',0, ...
	'Position',[0.7 0.058 0.167 0.1175], ...
	'Style','frame', ...
	'Tag','Frame2');

b = uicontrol('Parent',a, ...
   'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'ListboxTop',0, ...
	'Position',[0.405 0.058 0.285 0.1165], ...
	'Style','frame', ...
	'Tag','Frame3');

b = uicontrol('Parent',a, ...
   'Units','normalized', ...
	'BackgroundColor',bgframe, ...
	'ListboxTop',0, ...
	'Position',[0.1075 0.058 0.285 0.1165], ...
	'Style','frame', ...
	'Tag','Frame4');

b = uicontrol('Parent',a, ...
   'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'ListboxTop',0, ...
	'Position',[0.1186 0.1143 0.12 0.0325], ...
	'String','r1 length', ...
	'Style','text', ...
	'Tag','StaticText1');

b = uicontrol('Parent',a, ...
   'Units','normalized', ...
	'BackgroundColor',bgtext, ...
	'ListboxTop',0, ...
	'Position',[0.1186 0.06429 0.12 0.0325], ...
	'String','Beta angle', ...
	'Style','text', ...
	'Tag','StaticText2');

h_r1 = uicontrol('Parent',a, ...
   'Units','normalized', ...
   'BackgroundColor',[1 1 1], ...
   'Callback','tutorial_dial(''ChangeR1'')', ...
	'ListboxTop',0, ...
	'Position',[0.2536 0.1143 0.1304 0.05], ...
	'String','2', ...
   'Style','edit', ...
   'Userdata',2, ...
	'Tag','EditText1');

h_beta = uicontrol('Parent',a, ...
   'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
   'Callback','tutorial_dial(''ChangeBeta'')', ...
	'ListboxTop',0, ...
	'Position',[0.2536 0.06429 0.1304 0.05], ...
	'String','30', ...
	'Style','edit', ...
   'Userdata',30, ...
	'Tag','EditText1');

h_Lradio(1) = uicontrol('Parent',a, ...
   'Units','normalized', ...
	'BackgroundColor',bgtext, ...
   'Callback','tutorial_dial(''ChangeWidth'',1)', ...
	'ListboxTop',0, ...
	'Position',[0.5071 0.1143 0.1446 0.04048], ...
	'String','thick line', ...
   'value',0, ...
	'Style','radiobutton', ...
	'Tag','Radiobutton1');

h_Lradio(2) = uicontrol('Parent',a, ...
   'Units','normalized', ...
	'BackgroundColor',bgtext, ...
   'Callback','tutorial_dial(''ChangeWidth'',2)', ...
	'ListboxTop',0, ...
	'Position',[0.5071 0.06429 0.1446 0.04048], ...
   'value',1, ...
	'String','thin line', ...
   'Style','radiobutton', ...
	'Tag','Radiobutton1');

b = uicontrol('Parent',a, ...
   'Units','normalized', ...
	'ListboxTop',0, ...
	'Position',[0.7107 0.1143 0.1482 0.04762], ...
	'String','Return', ...
	'Tag','Pushbutton1');

b = uicontrol('Parent',a, ...
   'Units','normalized', ...
	'ListboxTop',0, ...
	'Position',[0.7107 0.06429 0.1482 0.04762], ...
	'String','Info', ...
	'Tag','Pushbutton1');

axis off;
hdls = [h_r1 h_beta h_Lradio];   
a = findobj('Tag','tutorial_dsgn');
set(a,'UserData',hdls );	
  
r2link=line('xdata', [], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
    'xor','color', 'r');
pin1=line('xdata',[],'ydata',[], 'erasemode',...
     'none','color', 'g');
pin2=line('xdata',[],'ydata',[], 'erasemode',...
     'none','color', 'g');
joint1=line('xdata', [], 'ydata', [], 'marker', 'o', ...
    'erasemode', 'xor', 'color', 'r');
r1link=line('xdata', [], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
    'xor','color', 'r');
hdls = [ joint1 r1link r2link pin1 pin2];
a = findobj('Tag','tutorial_axes');
set(a,'UserData',hdls );	
drawnow;   

function val=check_val(oldval,newval)
%Check if the user input is number input
%if not, retrieve the previous value in userdata
val=zeros(1);
if~isequal(length(oldval),length(str2num(newval))),
  	val=oldval;
%['Warning:An invalid property value has been entered.']);
else
  	val=str2num(newval);
end
