% Inflection_4bar
% MATLAB program for finding the inflection circle for a crank-rocker mechanism

%Variables
%   r1=frame length (cm)
%   r2=crank length (cm)
%   r3=coupler length (cm)
%   r4=rocker length (cm)
%   Q1=frame angle (deg)
%   Q11=frame angle (rad)
%   Q2=crank angle (rad)
%   Q21=crank angle (deg)
%   Q3=coupler angle (deg)
%   Q4=rocker angle (deg)
%   mode=assembly mode
%   tt=number of cycles to animate
%   dt=number of animation positions per revolution
%   bush1,bush2=x,y coordinates of the bushings
%   cir1,cir2=x,y coordinates of the circles inside the bushings
%   Bx,By=x,y coordinates of the crank pin
%   Cx,Cy=x,y coordinates of the rocker pin
%   Bx2,By2=x,y coordinates of the crank pointer
%   Cx2,Cy2=x,y coordinates of the rocker pointer
%   d2r,r2d=conversion factors between radians and degrees

%Graphics variables
%   xmin,xmax,ymin,ymax=axes limits
%   bushy1=line representing the bushing at the crank hinge
%   bushy2=line representing the bushing at the rocker hinge
%   circ1=line representing the circle inside the bushing at the crank hinge 
%   circ2=line representing the circle inside the bushing at the rocker hinge
%   joint1=line representing the joint at the crank pin 
%   joint2=line representing the joint at the rocker pin
%   crank=line representing the crank 
%   coupler=line representing the coupler
%   rocker=line representing the rocker

%Program  

clf;
clear all;
sizefact=1;
disp('   ')
disp(' Inflection Circle Program for Four-Bar Linkage')
disp('   ')

%Input the linkage variables

readmode=input('Enter 1 for file input and 2 for interactive input [1]: ');
if isempty(readmode); readmode=1; end
inputfile=input('Enter input file name (inflection4bario.dat): ', 's');
if isempty(inputfile); inputfile = 'inflection4bario.dat'; end
if readmode==1
	fid = fopen(inputfile);
end
if readmode==2
	r1=input('Enter the frame length (cm) [6.928]: ');
	if isempty(r1);r1 = 6.928;end
	r2=input('Enter the crank length (cm) [4]: ');
	if isempty(r2);r2 = 4;end
	r3=input('Enter the coupler length (cm) [4]: ');
	if isempty(r3);r3 = 4;end
	r4=input('Enter the rocker length (cm) [4*sqrt(3)]: ');
	if isempty(r4);r4 = 4*sqrt(3);end
	Q1=input('Enter the frame angle (deg) [120]: ');
	if isempty(Q1);Q1 = 120;end
	Q21=input('Enter the crank angle (deg) [90]: ');
	if isempty(Q21);Q21 = 90;end
	theta=input('Enter arc from inflection circle for indicating path (deg) [30]: ');
	if isempty(theta); theta = 30; end
	mode=input('Enter assembly mode [1]: ');
	if isempty(mode); mode=1; end
	
% save the data to the file fileinput.dat
	
	tempio(1)=r1;
	tempio(2)=r2;
	tempio(3)=r3;	
	tempio(4)=r4;
	tempio(5)=Q1;
	tempio(6)=Q21;
	tempio(7)=theta;
	tempio(8)=mode;
	tempiot=tempio(:);  % store the transpose of tempio for ease of reading
	fprintf(inputfile,'%f \n',tempiot)
end

% Read input data from the file inflection4bario.dat

if readmode==1	
	inflection4bario = fscanf(fid,'%f');
	r1=inflection4bario(1);
	r2=inflection4bario(2);
	r3=inflection4bario(3);
	r4=inflection4bario(4);
	Q1=inflection4bario(5);
	Q21=inflection4bario(6);
	theta=inflection4bario(7);
	mode=inflection4bario(8);
end
fclose('all');

Q11=Q1*pi/180;

disp('I am working ...');

% Define constants

d2r=pi/180;
r2d=180/pi;
qstart=0.0;
qstop=360.0;
   
% Check for the Grashof type

r=[r1 r2 r3 r4];
[rnew,Inew]=sort(r);
drock=1;
if (rnew(1)+rnew(4)<rnew(2)+rnew(3))    
	drock=0;
	if r3==rnew(1); drock=1; end		
end
if drock ==1
	qstart=1.00001*r2d*acos(((r2+r3)^2+r1^2-r4^2)/(2*r1*(r2+r3)));
	qstop=0.99999*r2d*acos((r1^2+r2^2-(r3+r4)^2)/(2*r1*r2));
end	

% Analyze the linkage for one position.

range=(qstop+qstart)/2;
Q2=Q21;
if Q21<qstart | Q21>qstop; Q2=qstart+range/2; end

% Call function to compute the position

para = fourbar(r1,r2,r3,r4,Q2,1,0,mode,Q1,1); 
Q3=para(7);
Q4=para(8);
assem=para(29);

% Store position information in matrices.

a2(1)= para(17);
a2(2)= para(18);
b2(1)= para(19);
b2(2)= para(20);
a1(1)=0.0;
a1(2)=0.0;
b1(1)=r1*cos(Q11);
b1(2)=r1*sin(Q11);
coords=lineintersect(a1,a2,b1,b2);
Ix=coords(1);
Iy=coords(2);

% Determine JA and JB.

coordA = inflection2(a2(1),a2(2),Ix,Iy,a1(1),a1(2),0,0,0,0);
coordB = inflection2(b2(1),b2(2),Ix,Iy,b1(1),b1(2),0,0,0,0);
JAx=coordA(1);
JAy=coordA(2);
JBx=coordB(1);
JBy=coordB(2);
	
% Find the center of the inflection circle.

coordC = pole([JAx, JAy], [JBx, JBy], [JBx, JBy], [Ix, Iy]);
Cx=coordC(1);
Cy=coordC(2);

% Compute radius of inflection circle and location of J.

CdIx=Cx-Ix;
CdIy=Cy-Iy;
CdI=sqrt(CdIx^2+CdIy^2);
angle=atan2(CdIy,CdIx);
R=abs(CdI);
D=2*R;
Jx=Ix+D*cos(angle);
Jy=Iy+D*sin(angle);

% Compute points on the inflection circle.

dalpha=2*pi/30;
for j=1:1:31
	alpha=(j-1)*dalpha;
	Icirx(j)=Cx+(D/2)*cos(alpha);
	Iciry(j)=Cy+(D/2)*sin(alpha);
end

% Draw inflecton circle.

fact=pi/180;
naxx=max(Icirx);
ninx=min(Icirx);
naxy=max(Iciry);
niny=min(Iciry);
dx=(naxx-ninx);
dy=(naxy-niny);
maxx=naxx+sizefact*dx;
minx=ninx-sizefact*dx;
maxy=naxy+sizefact*dy;
miny=niny-sizefact*dy;

Ex = r1*cos(Q11);
Ey = r1*sin(Q11);
xmax=max([maxx, a2(1), b2(1), Ix, Ex]);
if xmax>3*r1; xmax=3*r1; end

ymax=max([maxy, a2(2), b2(2), Iy, Ey]);
if ymax>6*r4; ymax=6*r4; end

xmin=min([minx,a2(1), b2(1), Ix, Ex]);
if xmin<-3*r1; xmin=-3*r1; end

ymin=min([miny, a2(2), b2(2), Iy, Ey]);
if ymin<-2*r4; ymin=-2*r4; end

%get the bushing points

bush1=bushing(((ymax-ymin)/100),0,0,20,0);
cir1=circle(((ymax-ymin)/120),0,0,20);
bush2=bushing(((ymax-ymin)/100), Ex, Ey, 20,0);
cir2=circle(((ymax-ymin)/120), Ex, Ey, 20);
max1=max(bush1(:, 1));
max2=max(bush2(:, 1));
xmax1=max([max1, max2, xmax]);
max1=max(bush1(:, 2));
max2=max(bush2(:, 2));
ymax1=max([max1, max2, ymax]);
min1=min(bush1(:, 1));
min2=min(bush2(:, 1));
xmin1=min([min1, min2, xmin]);
min1=min(bush1(:, 2));
min2=min(bush2(:, 2));
ymin1=min([min1, min2, ymin]);
xmina=xmin1-0.1*abs(xmin1);
xmaxa=xmax1+0.1*abs(xmax1);
ymina=ymin1-0.1*abs(ymin1);
ymaxa=ymax1+0.1*abs(ymax1);

% Set up the vectors needed to draw the linkage and inflection circle

clf;
width=0.95;
height=0.95;
h0=axes('position', [.05 .05 width height],'box', 'on', 'xcolor', 'k',...
         'ycolor','k');
set(gcf,'color', 'w')
joint1=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
	6, 'erasemode', 'xor', 'color', 'k');
joint2=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
	6, 'erasemode', 'xor', 'color',  'k');
crank=line('xdata', [0 0], 'ydata' ,[], 'linewidth' ,3, 'erasemode', ...
	'xor','color',  'k');
coupler=line('xdata', [], 'ydata' ,[], 'linewidth' ,3, 'erasemode', ...
	'xor','color',  'k');
rocker=line('xdata', [], 'ydata' ,[], 'linewidth',3,...
	'erasemode', 'xor','color',  'k');
bushy1=line('xdata', bush1(:,1), 'ydata',bush1(:,2), 'linestyle', '-',...
	'color', 'r');
bushy2=line('xdata', bush2(:,1), 'ydata',bush2(:,2), 'linestyle', '-', ...
	'color', 'r');
circ1=line('xdata', cir1(:,1), 'ydata',cir1(:,2), 'linestyle', '-',...
	'color','r');
circ2=line('xdata', cir2(:,1), 'ydata',cir2(:,2), 'linestyle', '-', ...
	'color','r');

gridpt=line('xdata', cir1(:,1), 'ydata',cir1(:,2), 'linestyle', '-',...
     'markersize', 6,'color',  'k');
Icircle=line('xdata', [], 'ydata' ,[], 'linewidth',1,'erasemode',...
               'normal','color', 'r');
Icpoint=line('xdata', [], 'ydata',[], 'marker', '+', 'markersize', 6,...
        'erasemode', 'normal','color', 'r');
Jpoint=line('xdata', [], 'ydata',[], 'marker', '+', 'markersize', 6,...
        'erasemode', 'normal','color', 'r');
Poletangent=line('xdata', [], 'ydata' ,[], 'linewidth',1,'erasemode',...
            'normal','color', 'r');
for i=1:1:10
	Aline(i)=line('xdata', [], 'ydata', [],'markersize', ...
       10,'erasemode', 'none', 'color', 'k');
	Aarc(i)=line('xdata', [], 'ydata', [],'markersize', ...
       10,'erasemode', 'none', 'color', 'k');
	Apoint(i)=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
       6, 'erasemode', 'none', 'color', 'k');
	Astarpt(i)=line('xdata', [], 'ydata', [], 'marker', '+','markersize', ...
       10, 'erasemode', 'none', 'color', 'r');
	JApoint(i)=line('xdata', [], 'ydata', [], 'marker', '+','markersize', ...
       10, 'erasemode', 'none', 'color', 'k');
end

rangex=xmaxa-xmina;
rangey=ymaxa-ymina;
xmin=xmina-0.05*rangex;
xmax=xmaxa+0.05*rangex;
ymin=ymina-0.05*rangey;
ymax=ymaxa+0.05*rangey;
values=axisadjust(xmin, xmax, ymin, ymax, width, height);
xmin=values(1);
xmax=values(2);
ymin=values(3);
ymax=values(4);
axis equal
axis([xmin xmax ymin ymax]);
set(Icircle, 'xdata', Icirx, 'ydata', Iciry);
set(Jpoint, 'xdata', Jx, 'ydata', Jy);
set(Icpoint, 'xdata', Ix, 'ydata', Iy);
text(Ix+0.1*dx,Iy+0.1*dy,'IC','color', 'r');
text(Jx+0.1*dx,Jy-0.1*dy,'J','color', 'r');

% Plot the instant center tangent

Ptanx1=Ix+D*sin(angle);
Ptanx2=Ix-D*sin(angle);
Ptany1=Iy-D*cos(angle);
Ptany2=Iy+D*cos(angle);
set(Poletangent, 'xdata',[Ptanx1, Ptanx2], 'ydata', [Ptany1, Ptany2]);
text(Ptanx2-0.1*dx,Ptany2-0.1*dy,'IC Tangent');

% Plot the linkage.

set(joint1,'xdata', a2(1), 'ydata',a2(2));
set(joint2,'xdata', b2(1), 'ydata',b2(2));
set(crank,'xdata',[a1(1) a2(1)],'ydata', [a1(2) a2(2)]);
set(coupler,'xdata', [a2(1) b2(1)],'ydata', [a2(2) b2(2)]);
set(rocker,'xdata', [b1(1) b2(1)],'ydata', [b1(2) b2(2)]);
set(gridpt,'xdata',Ix, 'ydata' ,Iy);
drawnow;   %flush the draw buffer

% While loop for point input.  Start by checking if the input
% is to be through the mouse or keyboard.
	
disp('   ')
disp('Possible modes of inputting data: ')
disp('  1 - mouse ')
disp('  2 - keyboard ')
disp('   ')
typei=input('Designate mode of input [1] ');
if isempty(typei)
	typei = 1;
end

% Input the point coordinates

ans2='y';
i=0;
while ans2=='y'
	i=i+1;
	if typei == 1
		disp('   ')
		disp('  Use mouse to locate point')
		[Ax,Ay]=ginput(1);
	end

% Input point data using the keyboard	

	if typei == 2
		Ax=input(' Input x component of point ');
		if isempty(Ax); Ax = 1.26;end				
		Ay=input(' Input y component of point ');
		if isempty(Ay); Ay = 1.99;end
	end
		
% Find the center of curvature.

	Astarx=0;
	Astary=0;
	gamma=60;
	ptflag=0;
	icflag=0;
	coords= inflection3(Ax,Ay,Ix,Iy,Astarx,Astary,Cx,Cy,Jx,Jy,ptflag,icflag);
	JAx=coords(1);
	JAy=coords(2);
	gamma=coords(5);
	Astarx=coords(11);
	Astary=coords(12);
	
% Define arc with radius AA* centered at A*

	r=sqrt((Astarx-Ax)^2+(Astary-Ay)^2);
	astart=atan2((Ay-Astary),(Ax-Astarx));
	thetarad=theta*pi/180;

% Determine angle corresponding to arc length of theta for inflection circle.

	angle=thetarad*D/(2*r);
	dalpha=angle/10;
	alpha=atan2((Ay-Astary),(Ax-Astarx))-angle/2-dalpha;
	for j=1:1:10
		alpha=alpha+dalpha;
		Aarcx(j)=Astarx+r*cos(alpha);
		Aarcy(j)=Astary+r*sin(alpha);
	end

% Plot A, Astar, and JA.

	set(Apoint(i), 'xdata',Ax, 'ydata', Ay);
	text(Ax-0.1*dx,Ay-0.1*dy,'A', 'color', 'k');
	set(Astarpt(i), 'xdata',Astarx, 'ydata', Astary);
	text(Astarx-0.1*dx,Astary-0.1*dy,'A*','color', 'r');
	set(JApoint(i), 'xdata',JAx, 'ydata', JAy);
	set(Aline(i), 'xdata',[Ax, Astarx, JAx,Ix], 'ydata', [Ay, Astary, JAy, Iy]);
	set(Aarc(i), 'xdata',Aarcx, 'ydata', Aarcy);

% Check to see if the user wants to reinput the point

	ans2=input('reenter point? y/n [y]: ', 's');
	if isempty(ans2);
		ans2='y';
	end	
	if i>9; ans2='n'; end
end
