function ani(r,Bx,By,Cx,Cy,Bx2,By2,Cx2,Cy2,ipos,phil,thetal)

% Function file that animates the linkage.  Start by defining axes.    

% Variables
%   r1=frame length (cm)
%   r2=crank length (cm)
%   r3=coupler length (cm)
%   r4=rocker length (cm)
%   r=[r1 r2 r3 r4]
%   ipos=number of animation positions
%   Bx,By=x,y coordinates of the crank pin
%   Cx,Cy=x,y coordinates of the rocker pin
%   Bx2,By2=x,y coordinates of the crank pointer
%   Cx2,Cy2=x,y coordinates of the rocker pointer
%   circx1,circy1=x,y coordinates of the first circle
%   circx2,circy2=x,y coordinates of the second circle
%   radi=distance based on frame and crank link lengths
%   t1,t2=limiting crank angles (rad)
%   t3,t4=limiting rocker angles (rad)
%   t12=crank pointer angle (rad)
%   t34=rocker pointer angles (rad)
%   arcx1,arcy1=x,y coordinates of arc (crank pointer scale)
%   arcx2,arcy2=x,y coordinates of arc (rocker pointer scale)
%   dist=tick length
%   ta12=crank pointer angle at which ticks occur
%   ta34=rocker pointer angle at which ticks occur
%   tangl=[ta12 ta34]
%   bill=counting variable
%   rr1=horizontal displacemant for ticks
%   tickx,ticky=x,y coordinates of the ticks
%   rtot=sum of the link lengths
%   bushx1,bushy1=x,y coordinates of the first bushing
%   bushx2,bushy2=x,y coordinates of the second bushing
%   ydatx,ydaty=x,y coordinates of the y label 
%   cir1=handle on first circle
%   cir2=handle on second circle
%   arc1=lines representing the arc of the x scale
%   arc2=lines representing the arc of the y scale
%   bush1,bush2=lines representing the bushings
%   XXX,YYY=lines representing the x and y labels
%   tick=lines representing the ticks for the x and y scales
%   precpto=precision points on the Chebychev error curve
%   joint1=line representing the joint at the crank pin
%   joint2=line representing the joint at the rocker pin
%   crank=line representing the crank
%   coupler=line representing the coupler
%   rocker=line representing the rocker
%   ipointer=line representing the crank pointer
%   opointer=line representing the rocker pointer
%   ans=repitition variable
%   xmin,xmax,ymin,ymax=window limits
%   h=handle on the axes in th window

%Program

% Define position axes

width=0.9;
height=0.9;
h=axes('position', [.1 .1 width height],'box', 'on', 'xcolor','k','ycolor',...
   'k');
set(gcf,'color', 'w');
r1=r(1);
r2=r(2);
r3=r(3);
r4=r(4);

% X,Y Scale Calculations.  Start with arcs.

rad1=1.1*(r2);
rad2=1.1*(r4);
t1=(thetal(1))*(pi/180);
t2=(thetal(2))*(pi/180);
   t3=phil(1);
t4=phil(2);
t12=t1:(t2-t1)/50:t2;
t34=t3:(t4-t3)/50:t4;
tt12=(t1+t2)*0.5;
tt34=(t3+t4)*0.5;
arcx1=rad1*cos(t12);
arcy1=rad1*sin(t12);
arcx2=(rad2*cos(t34))+r1;
arcy2=rad2*sin(t34);

% Scale ticks marks

tickdist=0.05*(rad1+rad2);
dist1=[rad1 rad1+tickdist];
dist2=[rad2 rad2+tickdist];  
ta12=t1:(t2-t1)/4:t2;
ta34=t3:(t4-t3)/4:t4;
letdist1=rad1+2*tickdist;
letdist2=rad2+2*tickdist;
tangl=[ta12 ta34];
for bill=1:length(tangl)
   if bill>5
   rr1=r1;
      dist=dist2;
   else
      rr1=0;
      dist=dist1;
   end
   tickx(bill,:)=((cos(tangl(bill)))*dist)+rr1;
   ticky(bill,:)=((sin(tangl(bill)))*dist);
end

% Draw bushings

rtot=sum(r);
coor=bushing((rtot/100),0,0,20,0);
bushx1=coor(:,1);
bushy1=coor(:,2);
coor=bushing((rtot/100),r1,0,20,0);
bushx2=coor(:,1);
bushy2=coor(:,2);

% Draw circles inside the bushings 

coor=circle2((rtot/100),0,0,20);
circx1=coor(:,1);
circy1=coor(:,2);
coor=circle2((rtot/100),r1,0,20);
circx2=coor(:,1);
circy2=coor(:,2);

% Size window

xmin=min([Bx, Bx2, Cx, r1, Cx2, min(bushx1), min(bushx2), arcx1, arcx2]) ;
xmax=max([Bx, Bx2, Cx, r1, Cx2, max(bushx1), max(bushx2), arcx1, arcx2]) ;
ymin=min([By, By2, Cy,  min(bushy1), min(bushy2), arcy1,arcy2]) ;
ymax=max([By, By2, Cy,  max(bushy1), max(bushy2), arcy1,arcy2]) ;
if (r2>r4); ymin=-1.05*r2; end
ymax=-ymin;
rangex=xmax-xmin;
rangey=ymax-ymin;
xmina=xmin-0.1*rangex;
xmaxa=xmax+0.1*rangex;
ymina=ymin-0.1*rangey;
ymaxa=ymax+0.1*rangey;
values=axisadjust(xmina, xmaxa, ymina, ymaxa, width, height);
xmin=values(1);
xmax=values(2);
ymin=values(3);
ymax=values(4);
axis equal
axis([xmin xmax ymin ymax]);

% Set up vector chains to be drawn

joint1=line('xdata', [],'ydata', [], 'marker', 'o','markersize', ...
6,'erasemode', 'xor', 'color', 'k');
joint2=line('xdata', [], 'ydata', [], 'marker','o','markersize', ...
6, 'erasemode', 'xor', 'color','k');
crank=line('xdata', [], 'ydata' ,[], 'linewidth' ,2, 'erasemode',...
'xor','color', 'k');
coupler=line('xdata', [], 'ydata' ,[], 'linewidth' ,2, 'erasemode',...
'xor','color', 'k');
rocker=line('xdata', [], 'ydata' ,[], 'linewidth',2,...
'erasemode', 'xor','color', 'k');
opointer=line('xdata', [], 'ydata' ,[], 'linewidth',2,...
'erasemode', 'xor','color', 'k');
ipointer=line('xdata', [], 'ydata' ,[], 'linewidth',2,...
'erasemode', 'xor','color', 'k');
bush1=line('xdata',bushx1,'ydata',bushy1, 'color','r');
bush2=line('xdata',bushx2,'ydata',bushy2, 'color','r');
text(cos(tt12)*letdist1, sin(tt12)*letdist1,'X','color','k',...
   'fontsize',10)
text(r1+cos(tt34)*letdist2, sin(tt34)*letdist2,'Y','color','k',...
   'fontsize',10)

arc1=line('xdata',arcx1,'ydata',arcy1,'linestyle','-','markersize',...
   6,'erasemode','none', 'color','r');
arc2=line('xdata',arcx2,'ydata',arcy2,'linestyle','-', 'markersize',...
   6,'erasemode','none', 'color','r');

for bill=1:length(tangl)
   tick(bill)=line('xdata',tickx(bill,:),'ydata',ticky(bill,:),...
   'linestyle','-','markersize',6,'erasemode','none', 'color','r');
end
cir1=line('xdata',circx1,'ydata',circy1,'linestyle','-', 'markersize',...
   6,'erasemode','none','color','r');
cir2=line('xdata',circx2,'ydata',circy2,'linestyle','-', 'markersize',...
   6,'erasemode','none','color','r');

% Plot the results for one cycle

ans='y';
timesink=1;
while ans=='y' 
	for k=1:1:3
		for i=1:ipos+1   
			set(joint1,'xdata', Bx(i),'ydata',By(i));
			set(joint2,'xdata', Cx(i), 'ydata',Cy(i));
			set(crank,'xdata',[0 Bx(i)],'ydata', [0 By(i)]);
			set(ipointer,'xdata',[0 Bx2(i)],'ydata', [0 By2(i)]);
			set(coupler,'xdata', [Bx(i) Cx(i)],'ydata', [By(i) Cy(i)]);
			set(rocker,'xdata', [r1 Cx(i)],'ydata', [0 Cy(i)]);
			set(opointer,'xdata',[r1 Cx2(i)],'ydata', [0 Cy2(i)]);
		
% Do meaningless calculation to slow down the linkage

			for k=1:1:timesink
				zzz=log10(k);
			end
		end 
   end

% Ask if animation should be repeated

	ans=input('Repeat animation? y/n [y]: ','s');
	if isempty(ans);ans='y';end
	if ans=='y'
		rep=input('Change animation speed? (+/-/0) [-]:','s');
		if isempty(rep);rep='-';end
		if rep=='+'; timesink=timesink/10; end
		if rep=='-'; timesink=timesink*10; end
		if timesink<1; timesink=1; end
	end
end
