function [Q22,Q44,Bx,Cx,By,Cy,Bx2,Cx2,By2,Cy2]=animat(thetal,phil, r, mode,...
   r20,r40,ipos)

% Function file that calculates the output angle corresponding to input angles 
% at equal intervals.  Vary the input angle between the two extremes for theta

%Variables
%   r1=frame length (cm)
%   r2=crank length (cm)
%   r3=coupler length (cm)
%   r4=rocker length (cm)
%   r=[r1 r2 r3 r4]
%   r20=length and direction of the crank
%   r40=length and direction of the rocker
%   thetal=crank angle limits (deg)
%   Q12start=initial crank angle (deg)
%   Q12stop=final crank angle (deg)
%   dQ12=crank angle increment (deg)
%   Q21=crank angle (deg)
%   Q2=crank angle (rad)
%   Q4=rocker angl (rad)
%   Bx,By=x,y coordinates of the crank pin
%   Cx,Cy=x,y coordinates of the rocker pin
%   Bx2,By2=x,y coordinates of the crank pointer
%   Cx2,Cy2=x,y coordinates of the rocker pointer
%   A,B,C,arg=algerbraic simplifying variables
%   i,j,k=counting variables
%   mode=assembly mode
%   Q22=vector of crank angles - accounting for link direction
%   Q44=vector of rocker angles - accounting for link direction
%   Q2new=Q22 sorted in acsending order

%Program
r1=r(1);
r2=r(2);
r3=r(3);
r4=r(4);
Q12start=(thetal(1));
Q12stop=(thetal(2));
i=0;
dQ12=(Q12stop-Q12start)/ipos;
for Q21 = Q12start:dQ12:Q12stop;
   Q2 = Q21*pi/180;
   i=i+1;
   v=fourbar(r1,r2,r3,r4,Q21,0,0,mode,0,1);
   Q4=v(8)*pi/180;
   Bx(i)=v(17);
   By(i)=v(18);
   Cx(i)=v(19);
   Cy(i)=v(20);
   if Q4 < 0  
      Q4=Q4+2*pi;
   end 
   Q41 = Q4*180/pi;
   
%convert rad-deg% Store the values in a matrix.  

   Bx2(i)=0;
   By2(i)=0;
   Cx2(i)=r1;
   Cy2(i)=0;
   if r20<0       
      Bx2(i)=-0.5*(r1/r2)*Bx(i);
      By2(i)=-0.5*(r1/r2)*By(i);
   end  
   if r40<0       
      Cx2(i)=r1-0.5*r1*cos(Q4);
      Cy2(i)=-0.5*(r1/r4)*Cy(i);
   end            
   Q22(i) = Q21;
   Q44(i) = Q41;
   if r20<0;
      Q22(i)=Q22(i)+180;
   end 
   if r40<0;
      Q44(i)=Q44(i)-180;
   end
   if i<2;
      if Q44(i)>phil(2)
         Q44(i)=Q44(i)-360;
      end
   end
end   
itotal=i;

% Make sure that Q22 is not always negative

[Q2new,Inew]=sort(Q22);
if Q2new(itotal)<0  
   for j=1:1:itotal         
      Q22(j)=Q22(j)+360;
   end
end
if Q2new(1)>360    
   for k=1:1:itotal         
      Q22(k)=Q22(k)-360;
   end
end
