% Matlab program to draw a gear conjugate to a straight gear.

%Some of the important variables used are:

%r2      = Pitch radius of gear 2
%N2      = Number of teeth on gear 2
%N3      = Number of teeth on gear 3
%a3      = Addendum constant for gear 3

clear all;
clf;
ans='y';
disp('   ')
disp('         Conjugate Gear Tooth Generation Program')

% Input values for linkage variables

readmode=input('Enter 1 for file input and 2 for interactive input [1]: ');
if isempty(readmode); readmode=1; end
inputfile=input('Enter input file name (arb2th.dat): ', 's');
if isempty(inputfile); inputfile = 'arb2th.dat'; end
if readmode==1
	fid = fopen(inputfile);
end
if readmode==2
	Dp=input('Enter value of diametral pitch [5]: ');
	if isempty(Dp)
		Dp = 5; 
	end

	N2=input('Enter number of teeth on gear 1 [100]: ');
	if isempty(N2)
		N2 = 100; 
	end

	N3=input('Enter number of teeth on gear 2 [30]: ');
	if isempty(N3)
		N3 = 30; 
	end

	a3=input('Enter addendum constant for gear 2 [1.0]: ');
	if isempty(a3)
		a3 = 1.0;
	end

	npoints=input('Enter number of points in gear 1 tooth [200]: ');
	if isempty(npoints)
		npoints = 200;
	end

	a1=input('Enter value of addendum constant for gear2 [1.0]: ');
	if isempty(a1)
		a1 = 1.0;
	end

	b1=input('Enter value of dedendum constant for gear2[1.2]: ');
	if isempty(b1)
		b1 = 1.2;
	end

	gamma=input('Enter value of flank angle for gear 1, degrees [25]: ');
	if isempty(gamma)
		gamma = 25;	
	end

	sign=input('Enter factor for external or internal gear (1 ext; -1 int) [1]: ');
	if isempty(sign)
		sign = 1;	
	end
	
% save the data to the file arb2thio.dat
	
	temp1(1)=Dp;
	temp1(2)=N2;
	temp1(3)=N3;
	temp1(4)=a3;
	temp1(5)=npoints;
	temp1(6)=a1;
	temp1(7)=b1; 
	temp1(8)=gamma; 
	temp1(9)=sign; 
	temp1t=temp1(:);  % store the transpose of temp1 for ease of reading	
	fprintf(inputfile,'%f \n',temp1t)
end

% Read input data from the file arb2thio.dat

if readmode==1	
	arb2thio = fscanf(fid,'%f');
	Dp=arb2thio(1);
	N2=arb2thio(2);
	N3=arb2thio(3);
	a3=arb2thio(4);
	npoints=arb2thio(5);
	a1=arb2thio(6);
	b1=arb2thio(7);
	gamma=arb2thio(8);
	sign=arb2thio(9);
end

A1=a1/Dp;
B1=b1/Dp;
p=pi/Dp;
r2=p*N2/(pi*2);
fact=180/(4*atan(1.0));
gammar=gamma/fact;
lt=pi/(2*Dp)-2*A1*tan(gammar);
lb=pi/(2*Dp)+2*B1*tan(gammar);
r3=r2*N3/N2;
Cd=r2+sign*r3;
A3=sign*a3/Dp;
B3=sign*B1;
t0=pi*(1-1/N3);
r2d=r2-B1;
r2a=r2+A1;
g2angle=pi/N2;
g2baseangle=atan((lb/2)/(r2d));
g3angle=pi/N3;

% Check for negative values for lt.  If it is negative,
% set the value to zero and compute the corresponding addendum.

if lt < 0
	lt=0;
	A1=(pi/(2*Dp)/2*tan(gammar))
end
			
% Determine points on dedendum circle

nbpoints=2;
dang=(g2angle-g2baseangle)/(nbpoints-1);
ang=g2angle+dang;
for i=1:1:nbpoints
	ang=ang-dang;
	gear2x(i)=r2d*cos(ang);
	gear2y(i)=r2d*sin(ang);
	g2x(i)=gear2x(i);
	g2y(i)=gear2y(i);
end
	
% Determine a set of points for flank region

dx=(r2a-r2d)/npoints;
x=-dx+r2d;
i=nbpoints;
for j=1:1:npoints
	i=i+1;
	x=x+dx;
	gear2x(i)=x;
	gear2y(i)=lb/2-(x-r2d)*tan(gammar);
	n(i)=1/tan(gammar); 
end

% Identify the minimum set of points which must be plotted.  For
% a straight toothed gear, this is only 3.  Store these points 
% in g2x and g2y.

nptotal=1+nbpoints;
g2x(nptotal)=gear2x(i);
g2y(nptotal)=gear2y(i);

% Reflect the line about the x axis to determine the other side of the gear.

for i=1:1:nptotal
	g2x(nptotal+i)=g2x(nptotal+1-i);
	g2y(nptotal+i)=-g2y(nptotal+1-i);
end

ntotal=2*nptotal; 
		
% Determine points on the pitch circle radius for gear 1.

theta0=-g2angle;
theta1=-theta0;
dtheta=(theta1-theta0)/20;
th=-dtheta+theta0;
for j=1:1:20
	th=th+dtheta;
	pc2x(j)=r2*cos(th);
	pc2y(j)=r2*sin(th);
end
		
% Draw the generating gear.  Start by defining the plots

height=0.8;
width=0.8;
axes('position',[.05 .05 width height],'box','on','xcolor','k','ycolor','k');
set(gcf,'color', 'w')
gear2line=line('xdata', [], 'ydata' ,[], 'linewidth',2,'erasemode', 'xor','color', [1,0,0]);
gear2_pitch_line=line('xdata', [], 'ydata' ,[], 'linewidth',0.4,'erasemode', 'xor','color', 'k', 'linestyle', '-.');
xmax=max([g2x, pc2x]);
xmin=min([g2x, pc2x]);
ymax=max([g2y, pc2y]);
ymin=min([g2y, pc2y]);
xrange=xmax-xmin;
yrange=ymax-ymin;

% Define ranges for plotting whole gear

xmax1=xmax+0.6*xrange;
xmin1=xmin-0.6*xrange;
ymax1=ymax+0.6*yrange;
ymin1=ymin-0.6*yrange;

% Define range for a single tooth

xmaxt=xmax+0.05*xrange;
xmint=xmin-0.05*xrange;
ymaxt=ymax+0.05*yrange;
ymint=ymin-0.05*yrange;
xrange=xmaxt-xmint;
yrange=ymaxt-ymint;
xmin=xmint-0.05*xrange;
xmax=xmaxt+0.05*xrange; 
ymin=ymint-0.05*yrange; 
ymax=ymaxt+0.05*yrange;
values=axisadjust(xmin, xmax, ymin, ymax, width, height);
xmin=values(1);
xmax=values(2);
ymin=values(3);
ymax=values(4);
axis equal
axis([xmin xmax ymin ymax]);

% Plot the positions

set(gear2line, 'xdata', g2x, 'ydata', g2y);
set(gear2_pitch_line, 'xdata',pc2x, 'ydata', pc2y);
text(pc2x(10), pc2y(2),'Pitch line');
title('tooth for gear 1');
pause;

% Print the results to the screen

disp('   ')
fprintf('                   Gear parameters '); 
disp('   ')
fprintf('      r2      r3       a3        N2         N3 '); 
disp('   ')
fprintf('%8.3f %8.3f  %8.3f  %8.3f  %8.3f \n', r2, r3, a3, N2, N3);
disp('   ') 
fprintf('      Cd     t0       A3         '); 
disp('   ')
fprintf('%8.3f %8.3f  %8.3f \n', Cd, t0, A3);
% pause

% Define the driven gear profile

j=0; 
r3d=r3-B3;
r3a=r3+A3;
for i=nbpoints+1:1:npoints+nbpoints
	A=gear2y(i)-gear2x(i)*n(i);
	B=r2;
	C=r2*n(i);
	arg=B*B-A*A+C*C;
	if arg >=0
		t=(-B+sqrt(arg))/(A-C);
		phi=2*atan(t);
		the=-sign*phi*r2/r3+t0;
		thed=the*fact;
		tempx=-Cd*cos(the)+cos(the-phi)*gear2x(i)+sin(the-phi)*gear2y(i);
		tempy=Cd*sin(the)-sin(the-phi)*gear2x(i)+cos(the-phi)*gear2y(i);
		rad=sqrt(tempx^2+tempy^2);
		if rad<=(r3a) & rad>= (r3d)
			j=j+1;
			gear3x(j)=tempx;
			gear3y(j)=tempy;			
			ang(j)=atan2(gear3y(j), gear3x(j));	
		end
	end
end
jtotal=j;

% Reorder the points to include the base as the first points.

for j=1:1:jtotal
	xtemp(j)=gear3x(jtotal-j+1);
	ytemp(j)=gear3y(jtotal-j+1);
end

% Determine points on dedendum circle

nbpoints=2;
nptotal=jtotal+nbpoints;
r3dtemp=sqrt(ytemp(1)^2+xtemp(1)^2);
ang2=atan2(ytemp(1),xtemp(1));

% If the gear tooth does not extend to the dedendum circle, extrapolate
% from the first point to the dedendum circle.

if r3dtemp>r3d
	ang3=atan2(ytemp(2)-ytemp(1),xtemp(2)-xtemp(1));
	ang2m2=ang2-ang3;
	rdif=r3dtemp-r3d;
	dc=rdif/cos(ang2-ang3);
	xc=xtemp(1)-dc*cos(ang3);
	yc=ytemp(1)-dc*sin(ang3);
	ang2=atan2(yc, xc);
end
dang=(g3angle-ang2)/(nbpoints-1);
ang=g3angle+dang;
for i=1:1:nbpoints
	ang=ang-dang;
	g3x(i)=r3d*cos(ang);
	g3y(i)=r3d*sin(ang);
	gear3x(i)=g3x(i);
	gear3y(i)=g3y(i);
end

% re-store the original points

i=nbpoints;
for j=1:1:jtotal
	i=i+1;
	gear3x(i)=xtemp(j);
	gear3y(i)=ytemp(j);	
end

% Reduce the number of points to make drawing the whole gear easier.
% Store the results in g3x and g3y.

i=nbpoints;
k=nbpoints;
for j=1:1:jtotal
	m=20*j;
	i=i+1;
	gear3x(i)=xtemp(j);
	gear3y(i)=ytemp(j);	
	if (m<=jtotal | j==nbpoints+1 | j==jtotal) & m<jtotal
		if j==jtotal; m=jtotal; end
		k=k+1;
		g3x(k)=xtemp(m);
		g3y(k)=ytemp(m);
	end	
end
ktotal=k;
	
% Reflect the points to draw the rest of the gear tooth

itotal=nbpoints+jtotal;
j=itotal;
for i=1:1:itotal
	j=j+1;
	gear3x(j)=gear3x(itotal-i+1);
	gear3y(j)=-gear3y(itotal-i+1);
end	
itotal=j;

j=ktotal;
for i=1:1:ktotal
	j=j+1;
	g3x(j)=g3x(ktotal-i+1);
	g3y(j)=-g3y(ktotal-i+1);
end	
ktotal=j;
	
% Define the pitch circle arc of the generated gear

maxang=max(ang);
minang=-maxang;
dk=(maxang-minang)/20;
i=0;
for k=minang:dk:maxang
	i=i+1;
	pc3y(i)=r3*sin(k);
	pc3x(i)=r3*cos(k);
end

% Draw the generated gear tooth.  Start by defining the plots

gear3line=line('xdata', [], 'ydata' ,[], 'linewidth',1,'erasemode',...
         'xor','color', [1,0,0]);
gear3_pitch_line=line('xdata', [], 'ydata' ,[], 'linewidth',0.4,...
         'erasemode', 'xor','color', 'k', 'linestyle', '-.');
		 
xmax=max([gear3x, pc3x]);
xmin=min([gear3x, pc3x]);
ymax=max([gear3y, pc3y]);
ymin=min([gear3y, pc3y]);
xrange=xmax-xmin;
yrange=ymax-ymin;
axis equal
axis([xmin-0.1*xrange xmax+0.1*xrange ymin-0.1*yrange ymax+0.1*yrange]);

% Plot the positions

set(gear3line, 'xdata', gear3x, 'ydata', gear3y);
set(gear3_pitch_line, 'xdata',pc3x, 'ydata', pc3y);
text(pc3x(10), pc3y(2),'Pitch line');
title('Conjugate Gear Tooth');
pause;

% Find the coordinates of the teeth on the entire generating gear.

dtheta=2*pi/N2;
j=ntotal;
for i=1:1:N2-1
	theta = -i*dtheta;
	sth = sin(theta);
	cth = cos(theta);
	for k=1:1:ntotal
		j=j+1;
		g2x(j)=g2x(k)*cth-g2y(k)*sth;
		g2y(j)=g2x(k)*sth+g2y(k)*cth;
	end
end
ntotal=j;

% Compute the pitch circle for the whole gear

q=0;
dq=-pi/90;
for i=1:1:180
	q=q+dq;
	pc2x(i)=r2*sin(q);
	pc2y(i)=r2*cos(q);
end

clf;
height=0.8;
width=0.8;
axes('position', [.05 .05 width height],'box', 'on', 'xcolor', 'k','ycolor',...
       'k');
set(gcf,'color', 'w')
gearline=line('xdata', [], 'ydata' ,[], 'linewidth',1,'erasemode',...
         'xor','color', [1,0,0]);
gearpitchline=line('xdata', [], 'ydata' ,[], 'linewidth',0.4,...
         'erasemode', 'xor','color', 'k', 'linestyle', '-.');
xmax=max(g2x);
xmin=min(g2x);
ymax=max(g2y);
ymin=min(g2y);
xrange=xmax-xmin;
yrange=ymax-ymin;
axis equal
axis([xmin-0.1*xrange xmax+0.1*xrange ymin-0.1*yrange ymax+0.1*yrange]);

% Plot the positions

set(gearline, 'xdata', g2x, 'ydata', g2y);
set(gearpitchline, 'xdata',pc2x, 'ydata', pc2y);
title('Generating Gear');

% Put a "+" at the center of the gear

text(0.0, 0.0,'+');
pause;
	
% Find the coordinates of the teeth on the entire conjugate gear.

dtheta=2*pi/N3;
j=ktotal;
for i=1:1:N3-1
	theta = -i*dtheta;
	sth = sin(theta);
	cth = cos(theta);
	for k=1:1:ktotal
		j=j+1;
		g3x(j)=g3x(k)*cth-g3y(k)*sth;
		g3y(j)=g3x(k)*sth+g3y(k)*cth;
	end
end
itotal=j;

% Compute the pitch circle for the whole gear

q=0;
dq=-pi/90;
for i=1:1:180
	q=q+dq;
	pc3x(i)=r3*sin(q);
	pc3y(i)=r3*cos(q);
end

clf;
height=0.8;
width=0.8;
axes('position', [.05 .05 width height],'box', 'on', 'xcolor', 'k','ycolor',...
       'k');
set(gcf,'color', 'w')
gearline=line('xdata', [], 'ydata' ,[], 'linewidth',1,'erasemode',...
         'xor','color', [1,0,0]);
gearpitchline=line('xdata', [], 'ydata' ,[], 'linewidth',0.4,...
         'erasemode', 'xor','color', 'k', 'linestyle', '-.');
		 
xmax=max(g3x);
xmin=min(g3x);
ymax=max(g3y);
ymin=min(g3y);
xrange=xmax-xmin;
yrange=ymax-ymin;
xmin=xmin-0.05*xrange;
xmax=xmax+0.05*xrange; 
ymin=ymin-0.05*yrange; 
ymax=ymax+0.05*yrange;
values=axisadjust(xmin, xmax, ymin, ymax, width, height);
xmin=values(1);
xmax=values(2);
ymin=values(3);
ymax=values(4);
axis equal
axis([xmin xmax ymin ymax]);

% Plot the positions

set(gearline, 'xdata', g3x, 'ydata', g3y);
set(gearpitchline, 'xdata',pc3x, 'ydata', pc3y);
title('Conjugate Gear');

% Put a "+" at the center of the gear

text(0.0, 0.0,'+');
pause;

% Show the gear in mesh.  For this, we must show both gears 
% relative to the frame coordinate system.

phi0=0;
theta0=t0;

% Determine the coordinates of gear 1 relative to the frame
% as gear 1 rotates by phi through 2*g2angle.

gearline1=line('xdata', [], 'ydata' ,[], 'linewidth',1,'erasemode',...
         'xor','color', [1,0,0]);
gearpitchline1=line('xdata', [], 'ydata' ,[], 'linewidth',0.4,...
         'erasemode', 'xor','color', 'k', 'linestyle', '-.');
gearline2=line('xdata', [], 'ydata' ,[], 'linewidth',1,'erasemode',...
         'xor','color', [1,0,0]);
gearpitchline2=line('xdata', [], 'ydata' ,[], 'linewidth',0.4,...
         'erasemode', 'xor','color', 'k', 'linestyle', '-.');
		 
axis equal
axis([xmin1 xmax1 ymin1 ymax1]);

% Determine the position of the gears in a rotated position

nposn=20;
dph=g2angle/(nposn/2);
dth=g3angle/(nposn/2);
th=t0-dth;
ph=0+dph;
title('meshing gears');
set(gearpitchline1, 'xdata',pc2x, 'ydata', pc2y);
set(gearpitchline2, 'xdata',pc3x+Cd, 'ydata', pc3y);

% Increment the gear rotations for nposn positions.  Press
% return for each succeeding position.

for i=1:1:nposn
	ph=ph+dph;
	th=th-dth;
	g2xm=g2x*cos(ph)-g2y*sin(ph);
	g2ym=g2x*sin(ph)+g2y*cos(ph);
	g3xm=Cd+g3x*cos(th)-g3y*sin(th);
	g3ym=g3x*sin(th)+g3y*cos(th);
	
% Plot the meshing gears

	set(gearline1, 'xdata', g2xm, 'ydata', g2ym);
	set(gearline2, 'xdata', g3xm, 'ydata', g3ym);
	pause
end







