function mode = assemblymode(r1,r2,r3,r4,Q1,theta, phi)

% Function to determine the linkage mode of a four-bar linkage by 
% checking the first position.

% r1, r2, r3, r4 are the link lengths numbered in the standard fashion
% (r1=frame, r2=driver, r3=coupler, r4=output).
% Q1 is the frame angle in radians
% theta is the driver angle in radians
% phi is the output angle in radians
% mode is the mode (+1 or -1)

% Transform the angles to the frame system.
 
Q2=theta-Q1;
phi1=phi-Q1;
A = r2^2 + r1^2 - r3^2 +r4^2- 2*r1*r2*cos(Q2);
B = -2*r2*r4*sin(Q2);
C = -2*r2*r4*cos(Q2) + 2*r1*r4;
arg=B^2 - A^2 +C^2;
if arg >=0 & (A-C) ~=0
	Q41 = 2 * atan((-B+arg^.5) / (A-C));
	if Q41 < 0
		Q41=Q41+2*pi;
	end
	Q42 = 2 * atan((-B-arg^.5) / (A-C));
	if Q42 < 0
		Q42=Q42+2*pi;
	end
end
mode=1;
if (abs(Q42-phi1)<abs(Q41-phi1)); 
	mode=-1; 
end;
