function mode = assemblymode_sc(r2,r3,bx,by,Q1,Q2)

% Function to determine the linkage mode of a four-bar linkage by 
% checking the first position.

% r2, r3 = link lengths numbered in the standard fashion
%          (r2=driver, r3=coupler).
% bx     = slider x coordinate relative to frame
% by     = slider y coordinate relative to frame
% Q1     = slide angle in degrees
% Q2     = driver angle in degrees
% mode   = assembly mode (+1 or -1)

% Determine slider distance and slide offset.

fact=pi/180;
Q1r=Q1*fact;
Q2r=Q2*fact;
r1=bx*cos(Q1r)+by*sin(Q1r);
r4=-bx*sin(Q1r)+by*cos(Q1r);

%convert input data

r(1)=r1;
r(2)=r2;
r(3)=r3;
r(4)=r4;
theta(1)=Q1;
theta(2)=Q2;
theta(4)=Q1+90;
t1=theta(1)*fact;
t2=theta(2)*fact;
t4=theta(4)*fact;
s2=sin(t2);
c2=cos(t2);
s1=sin(t1);
c1=cos(t1);
s4=sin(t4);
c4=cos(t4);

% position calculations

A=2*r(4)*(c1*c4+s1*s4)-2*r(2)*(c1*c2+s1*s2);
B=r(2)*r(2)+r(4)*r(4)-r(3)*r(3)-2*r(2)*r(4)*(c2*c4+s2*s4);
arg=A*A-4*B;

% Compute the slider displacement when the mode is + and -1

r11=(-A+sqrt(arg))/2;
r12=(-A-sqrt(arg))/2;

% Determine the distance that corresponds to r(1).

test1 = abs(r11-r(1));
test2 = abs(r12-r(1));

mode = 1;
if (test2 < test1); mode=-1; end
