function mode = assemblymode_sc(r2,r3,bx,by,Q1,Q2)

% Function to determine the linkage mode of a four-bar linkage by 
% checking the first position.

% r2, r3 = link lengths numbered in the standard fashion
%          (r2=driver, r3=coupler).
% bx     = slider x coordinate relative to frame
% by     = slider y coordinate relative to frame
% Q1     = slide angle in degrees
% Q2  = driver angle in degrees
% mode   = assembly mode (+1 or -1)

% Determine slider distance and slide offset.

fact=pi/180;
Q1r=Q1*fact;
Q2r=Q2*fact;
r1=bx*cos(Q1r)+by*sin(Q1r);
r4=-bx*sin(Q1r)+by*cos(Q1r);

%convert input data

r(1)=r1;
r(2)=r2;
r(3)=r3;
r(4)=r4;
theta(1)=Q1;
theta(4)=Q1+90;
t1=theta(1)*fact;
t4=theta(4)*fact;
s1=sin(t1);
c1=cos(t1);
s4=sin(t4);
c4=cos(t4);

% position calculations

A=-2*r(1)*r(2)*c1-2*r(2)*r(4)*c4;
B=-2*r(1)*r(2)*s1-2*r(2)*r(4)*s4;
C=r(1)*r(1)+r(2)*r(2)+r(4)*r(4)-r(3)*r(3)+2*r(1)*r(4)*(c1*c4+s1*s4);
arg=B*B-C*C+A*A;

% Compute the driver angle when the mode is + and -1

t21=2*atan((-B+sqrt(arg))/(C-A));
t22=2*atan((-B-sqrt(arg))/(C-A));

% Determine the angle that corresponds to Q2.

test1 = abs(t21-Q2r);
test2 = abs(t22-Q2r);

mode = 1;
if (test2 < test1); mode=-1; end
