% cognates.m

% MATLAB program for finding cognates of crank-rocker mechanism

%Variables
%   r1=frame length (cm)
%   r2=crank length (cm)
%   r3=coupler length (cm)
%   r4=rocker length (cm)
%   r5=coupler radius (cm) (to point C from the crank pin)
%   beta=coupler angle (deg) (to point C from the coupler line)
%   Q1=frame angle (deg)
%   Q11=frame angle (rad)
%   Q2=crank angle (rad)
%   Q21=crank angle (deg)
%   Q22=crank angle (deg) (vector)
%   Q3,Q33=coupler angle (deg)
%   Q4,Q44=rocker angle (deg)
%   cang=angle from the line connecting the coupler point one and the crank pin (rad)
%   mode,assem=assembly mode
%   tt=number of cycles to animate
%   dt=number of animation positions per revolution
%   itotal=number of animation positions
%   cycle=number of cycles as an integer
%   bush1,bush2=x,y coordinates of the bushings
%   cir1,cir2=x,y coordinates of the circles inside the bushings
%   Ax,Ay=x,y coordinates of the crank pin
%   Bx,By=x,y coordinates of the rocker pin
%   Ax2,Ayx2=x,y coordinates of the crank pointer
%   Bx2,By2=x,y coordinates of the rocker pointer
%   d2r,r2d=conversion factors between radians and degrees
%   i=counting variable
%   ans=repetition variable

%Graphics variables
%   xmin,xmax,ymin,ymax=axes limits
%   h1=handle on the first axes in the window (basic linkage)
%   h2=handle on the second axes in the window (cognates)
%   displ=line representing the crank angle vs. rocker angle
%   gridpt = point which follows coupler point
%   bushy1=line representing the bushing at the crank hinge
%   bushy2=line representing the bushing at the rocker hinge
%   circ1=line representing the circle inside the bushing at the crank hinge 
%   circ2=line representing the circle inside the bushing at the rocker hinge
%   joint1=line representing the joint at the crank pin 
%   joint2=line representing the joint at the rocker pin
%   crank=line representing the crank 
%   coupler=line representing the coupler
%   rocker=line representing the rocker
%   couplerptr=line representing the coupler point
%   couplerpt1=line from the crank pin to the coupler point one

%Program  
clf;
clear all;
ans='y';
disp('   ')
disp('         Cognate Linkage Analysis Program')

%Input the linkage variables

readmode=input('Enter 1 for file input and 2 for interactive input [1]: ');
if isempty(readmode); readmode=1; end
inputfile=input('Enter input file name (cognate.dat): ', 's');
if isempty(inputfile); inputfile = 'cognate.dat'; end
if readmode==1
	fid = fopen(inputfile);
end
if readmode==2
	tt=input('Enter number of cycles (rev) [3]: ');
	if isempty(tt);tt = 3;end
	r1=input('Enter the frame length [2.75]: ');
	if isempty(r1);r1 = 2.75;end
	r2=input('Enter the crank length [0.9]: ');
	if isempty(r2);r2 = 0.9;end
	r3=input('Enter the coupler length [2.4]: ');
	if isempty(r3);r3 = 2.4;end
	r4=input('Enter the rocker length [1.3]: ');
	if isempty(r4);r4 = 1.3;end
	r5=input('Enter coupler point radius [4.85]: ');
	if isempty(r5);r5=4.85;end
	beta=input('Enter angle from coupler line to coupler point (deg) [-4]: ');
	if isempty(beta);beta=-4;end
	Q1=input('Enter the frame angle (deg) [57]: ');
	if isempty(Q1);Q1 = 57;end
	mode=input('Enter the assembly mode [+1 or -1] [-1]: ');
	if isempty(mode);mode = -1;end

% save the data to the file sliderio.dat
	
	temp1(1)=tt;
	temp1(2)=r1;
	temp1(3)=r2;
	temp1(4)=r3;
	temp1(5)=r4;
	temp1(6)=r5;
	temp1(7)=beta; 
	temp1(8)=Q1; 
	temp1(9)=mode; 
	temp1t=temp1(:);  % store the transpose of tempio for ease of reading	
	fprintf(inputfile,'%f \n',temp1t)
end

% Read input data from the file fourbario.dat

if readmode==1	
	cognateio = fscanf(fid,'%f');
	tt=cognateio(1);
	r1=cognateio(2);
	r2=cognateio(3);
	r3=cognateio(4);
	r4=cognateio(5);
	r5=cognateio(6);
	beta=cognateio(7);
	Q1=cognateio(8);
	mode=cognateio(9);
end
fclose('all');
disp('I am working ...');

% Define constants

i=0;
w2=1;
d2r=pi/180;
Q11=Q1*d2r;
r2d=180/pi;
dt=10;
 
% Loop to analyze the linkage for tt full cycles

for Q21 = 0:dt:360*tt;
	i=i+1;
	Q2 = Q21*d2r;

% Call function to compute the position

	para = fourbar(r1,r2,r3,r4,Q21,w2,0,mode,Q1,0); 
	Q3=para(7);
	Q33(i)=Q3;
	Q4=para(8);
	Q44(i)=Q4;
	w33(i)=para(11);
	w44(i)=para(12);
	assem=para(29);
	cang=(Q3+beta)*d2r;

% Store position information in matrices.

	Ax(i)= para(17);
	Ay(i)= para(18);
	Bx(i)= para(19);
	By(i)= para(20);
	Cx(i)=Ax(i)+r5*cos(cang);
	Cy(i)=Ay(i)+r5*sin(cang);
	Q22(i) = Q21;
	w22(i) = w2; 
end	

% Define the location of the cognate linkages.	
	
itotal=i;
Mx=0.0;
My=0.0;
Qx=Mx+r1*cos(Q11);
Qy=My+r1*sin(Q11);
angO=(beta+Q1)*d2r;
betar=beta*d2r;
r6=r2*r5/r3;
r7=r4*r5/r3;
r8=r1*r5/r3;
Ox=Mx+r8*cos(angO);
Oy=My+r8*sin(angO);
for k=1:1:itotal	
	Gx(k)=Cx(k)-Ax(k);
	Gy(k)=Cy(k)-Ay(k);	
	Dx(k)=Cx(k)+(Qx-Bx(k));
	Dy(k)=Cy(k)+(Qy-By(k));
	phi=atan2((Dy(k)-Cy(k)), (Dx(k)-Cx(k)));
	lamda=atan2((Cy(k)-Gy(k)), (Cx(k)-Gx(k)));
	Ex(k)=Cx(k)+r7*cos(betar+phi);
	Ey(k)=Cy(k)+r7*sin(betar+phi);
	Fx(k)=Gx(k)+r6*cos(betar+lamda);
	Fy(k)=Gy(k)+r6*sin(betar+lamda);
end
r9=sqrt((Ex(1)-Ox)^2+(Ey(1)-Oy)^2);
r10=sqrt((Ex(1)-Dx(1))^2+(Ey(1)-Dy(1))^2);

% Print out a table of r's

disp('   ')
disp('           Program results')
disp('     r1       r2       r3       r4       r5')
fprintf('%8.2f %8.2f %8.2f %8.2f %8.2f %8.2f\n', r1, r2, r3, r4, r5)
disp('   ')
disp('   ')
disp('     r6       r7       r8      r9      r10')
fprintf('%8.2f %8.2f %8.2f %8.2f %8.2f %8.2f\n', r6, r7, r8, r9, r10)
disp('   ')
disp('   ')

% Draw original linkage and Coupler Curve

clf;
left=0.05;
bottom=0.05;
width=0.95;
height=0.95;

h0=axes('position',[left, bottom, width, height],'box','on','xcolor', 'k',...
        'ycolor','k','fontname', 'times', 'fontsize', 8);
set(gcf,'color', 'w')
   
xmint=min([Mx Qx min(Ax) min(Bx) min(Cx)]);
xmaxt=max([Mx Qx max(Ax) max(Bx) max(Cx)]);
ymint=min([My Qy min(Ay) min(By) min(Cy)]);
ymaxt=max([My Qy max(Ay) max(By) max(Cy)]);
xmin=xmint-0.1*(xmaxt-xmint);
xmax=xmaxt+0.1*(xmaxt-xmint);
ymin=ymint-0.1*(ymaxt-ymint);
ymax=ymaxt+0.1*(ymaxt-ymint);
values=axisadjust(xmin, xmax, ymin, ymax, width, height);
xmin=values(1);
xmax=values(2);
ymin=values(3);
ymax=values(4);
axis equal
axis ([xmin, xmax, ymin, ymax])
   
% Get the bushing points

bush1=bushing(((ymax-ymin)/50),0,0,20,0);
cir1=circle2(((ymax-ymin)/60),0,0,20);
bush2=bushing(((ymax-ymin)/50),Qx,Qy,20,0);
cir2=circle2(((ymax-ymin)/60),Qx,Qy,20);
  
% Set up the vectors needed to draw the linkage

joint1=line('xdata', [], 'ydata', [], 'marker', 'o', ...
    'erasemode', 'xor', 'color', 'r');
joint2=line('xdata', [], 'ydata', [], 'marker', 'o',...
    'erasemode', 'xor', 'color', 'r');
crank=line('xdata', [0 0], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
    'xor','color', 'r');
coupler=line('xdata', [], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
    'xor','color', 'r');
couplerptr1=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
    'xor','color', 'r');	   
couplerpt1=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
    'none','color', 'k', 'linestyle', '--');	
gridpt=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
    'xor','color', 'k', 'marker', 'o');	
rocker=line('xdata', [Qx 0], 'ydata' ,[Qy 0], 'linewidth',2,...
    'erasemode', 'xor','color', 'r');
bushy1=line('xdata', bush1(:,1), 'ydata',bush1(:,2), 'linestyle', '-',...
    'color', 'g');
bushy2=line('xdata', bush2(:,1), 'ydata',bush2(:,2), 'linestyle', '-', ...
     'color', 'g');
circ1=line('xdata', cir1(:,1), 'ydata',cir1(:,2), 'linestyle', '-',...
    'color', 'g');
circ2=line('xdata', cir2(:,1), 'ydata',cir2(:,2), 'linestyle', '-', ...
     'color', 'g');

% Plot the of the MQ linkage

ans='y';

% Draw the coupler curve first.

set(couplerpt1,'xdata', Cx, 'ydata' ,Cy);

% Label the pivots

xdelta=xmax-xmin;
ydelta=ymax-ymin;
text(Mx-0.07*xdelta,My,'M','color', 'k','fontname', 'times', 'fontsize', 8);
text(Qx+0.04*xdelta,Qy,'Q','color', 'k','fontname', 'times', 'fontsize', 8);
text(xmin+0.05*xdelta,ymax-0.1*ydelta,'Original Linkage','color', 'k',...
      'fontname', 'times', 'fontsize', 8);
% Animate the linkage as long as ans = 'y'
	
timesink=1;
while ans=='y'
	for i=1:1:itotal
		cycle=fix((i-0.0000001)/(360/dt)); %determine the cycle as an integer
		set(joint1,'xdata', Ax(i), 'ydata',Ay(i));
      	set(joint2,'xdata', Bx(i), 'ydata',By(i));
      	set(crank,'xdata',[Mx Ax(i)],'ydata', [Mx Ay(i)]);
     	set(coupler,'xdata', [Ax(i) Bx(i)],'ydata', [Ay(i) By(i)]);
     	set(rocker,'xdata', [Qx Bx(i)],'ydata', [Qy By(i)]);
		set(gridpt,'xdata',Cx(i), 'ydata' ,Cy(i));
      	set(couplerptr1,'xdata', [Ax(i) Cx(i) Bx(i)], ...
         'ydata' ,[Ay(i) Cy(i) By(i)]);
		drawnow;   %flush the draw buffer

% Do meaningless calculation to slow down the linkage

		for k=1:1:timesink
			zzz=log10(k);
		end
	end

% Plot linkage in fixed position.

	i = 6;
	set(joint1,'xdata', Ax(i), 'ydata',Ay(i));
	set(joint2,'xdata', Bx(i), 'ydata',By(i));
	set(crank,'xdata',[0 Ax(i)],'ydata', [0 Ay(i)]);
	set(coupler,'xdata', [Ax(i) Bx(i)],'ydata', [Ay(i) By(i)]);
	set(rocker,'xdata', [Qx Bx(i)],'ydata', [Qy By(i)]);
	set(gridpt,'xdata',Cx(i), 'ydata' ,Cy(i));
	set(couplerptr1,'xdata', [Ax(i) Cx(i) Bx(i)], ...
		'ydata' ,[Ay(i) Cy(i) By(i)]);
   
%flush the draw buffer

	drawnow; 
		
% Ask if animation should be repeated

	ans=input('Repeat animation? y/n [y]: ','s');
	if isempty(ans);ans='y';end
	if ans=='y'
		rep=input('Change animation speed? (+/-/0) [-]:','s');
		if isempty(rep);rep='-';end
		if rep=='+'; timesink=timesink/10; end
		if rep=='-'; timesink=timesink*10; end
		if timesink<1; timesink=1; end
	end
end

% Define the axes for the graph showing the cognate linages

clf;
h0=axes('position', [.05 .05 .45 .45],'box', 'on',...
        'xcolor', 'k','ycolor','k','fontname', 'times', 'fontsize', 8);
set(gcf,'color', 'w')
   
xmint=min([Mx Qx Ox min(Ax) min(Bx) min(Cx) min(Dx) min(Ex) min(Fx) min(Gx)]);
xmaxt=max([Mx Qx Ox max(Ax) max(Bx) max(Cx) max(Dx) max(Ex) max(Fx) max(Gx)]);
ymint=min([My Qy Oy min(Ay) min(By) min(Cy) min(Dy) min(Ey) min(Fy) min(Gy)]);
ymaxt=max([My Qy Oy max(Ay) max(By) max(Cy) max(Dy) max(Ey) max(Fy) max(Gy)]);
xmin=xmint-0.05*(xmaxt-xmint);
xmax=xmaxt+0.05*(xmaxt-xmint);
ymin=ymint-0.05*(ymaxt-ymint);
ymax=ymaxt+0.05*(ymaxt-ymint);

% axes(h0);

values=axisadjust(xmin, xmax, ymin, ymax, width, height);
xmin=values(1);
xmax=values(2);
ymin=values(3);
ymax=values(4);
axis equal
axis ([xmin, xmax, ymin, ymax])
   
% Get the bushing points

bush1=bushing(((ymax-ymin)/50),Mx,My,20,0);
cir1=circle2(((ymax-ymin)/60),Mx,My,20);
bush2=bushing(((ymax-ymin)/50),Qx,Qy,20,0);
cir2=circle2(((ymax-ymin)/60),Qx,Qy,20);
bush3=bushing(((ymax-ymin)/50),Ox,Oy,20,0);
cir3=circle2(((ymax-ymin)/60),Ox,Oy,20);
  
% Set up the vectors needed to draw the linkage

joint1=line('xdata', [], 'ydata', [], 'marker', 'o', ...
    'erasemode', 'xor', 'markersize', 4, 'color', 'r');
joint2=line('xdata', [], 'ydata', [], 'marker', 'o', ...
    'erasemode', 'xor','markersize', 4, 'color', 'r');
joint3=line('xdata', [], 'ydata', [], 'marker', 'o', ...
    'erasemode', 'xor','markersize', 4, 'color', 'g');
joint4=line('xdata', [], 'ydata', [], 'marker', 'o', ...
    'erasemode', 'xor', 'markersize', 4,'color', 'g');
joint5=line('xdata', [], 'ydata', [], 'marker', 'o', ...
    'erasemode', 'xor', 'markersize', 4,'color', 'k');
joint6=line('xdata', [], 'ydata', [], 'marker', 'o', ...
    'erasemode', 'xor','markersize', 4, 'color', 'k');
crank=line('xdata', [0 0], 'ydata' ,[], 'linewidth',1, 'erasemode', ...
    'xor','color', 'r');
crank2=line('xdata', [0 0], 'ydata' ,[], 'linewidth',1, 'erasemode', ...
    'xor','color', 'g');
crank3=line('xdata', [0 0], 'ydata' ,[], 'linewidth',1, 'erasemode', ...
    'xor','color', 'k');
coupler=line('xdata', [], 'ydata' ,[], 'linewidth',1, 'erasemode', ...
    'xor','color', 'r');
coupler2=line('xdata', [], 'ydata' ,[], 'linewidth',1, 'erasemode', ...
    'xor','color', 'g');
coupler3=line('xdata', [], 'ydata' ,[], 'linewidth',1, 'erasemode', ...
    'xor','color', 'k');
couplerptr1=line('xdata', [], 'ydata' ,[], 'linewidth' ,.5, 'erasemode', ...
    'xor','color', 'r');	   
couplerptr2=line('xdata', [], 'ydata' ,[], 'linewidth' ,.5, 'erasemode', ...
    'xor','color', 'g');	   
couplerptr3=line('xdata', [], 'ydata' ,[], 'linewidth' ,.5, 'erasemode', ...
    'xor','color', 'k');	   
couplerpt1=line('xdata', [], 'ydata' ,[], 'linewidth' ,.5, 'erasemode', ...
    'none','color', 'k', 'linestyle', '--');	
gridpt=line('xdata', [], 'ydata' ,[], 'linewidth' ,.5, 'erasemode', ...
    'xor','color', 'k', 'marker', 'o','markersize', 4 );	
rocker=line('xdata', [Qx 0], 'ydata' ,[Qy 0], 'linewidth',1,...
    'erasemode', 'xor','color', 'r');
rocker2=line('xdata', [Ox 0], 'ydata' ,[Oy 0], 'linewidth',1,...
    'erasemode', 'xor','color', 'g');
rocker3=line('xdata', [Qx 0], 'ydata' ,[Qy 0], 'linewidth',1,...
    'erasemode', 'xor','color','k');
bushy1=line('xdata', bush1(:,1), 'ydata',bush1(:,2), 'linestyle', '-', ...
    'color', 'g');
bushy2=line('xdata', bush2(:,1), 'ydata',bush2(:,2), 'linestyle', '-', ...
     'color', 'g');
bushy3=line('xdata', bush3(:,1), 'ydata',bush3(:,2), 'linestyle', '-', ...
    'color', 'g');
circ1=line('xdata', cir1(:,1), 'ydata',cir1(:,2), 'linestyle', '-', ...
     'color', 'g');
circ2=line('xdata', cir2(:,1), 'ydata',cir2(:,2), 'linestyle', '-', ...
     'color', 'g');
circ3=line('xdata', cir3(:,1), 'ydata',cir3(:,2), 'linestyle', '-', ...
     'color', 'g');

% Plot the of the cognate linakges

ans='y';

% Draw the coupler curve first.

set(couplerpt1,'xdata', Cx, 'ydata' ,Cy);

% Label the pivots

text(Mx-0.15*r1,My,'M','color', 'k','fontname', 'times', 'fontsize', 8);
text(Qx-0.15*r1,Qy,'Q','color', 'k','fontname', 'times', 'fontsize', 8);
text(Ox+0.085*r1,Oy-0.05*r1,'O','color', 'k','fontname', 'times', 'fontsize', 8);

% Animate the linkage as long as ans = 'y'
	
timesink=1;
while ans=='y'
	for i=1:1:itotal
	%	cycle=fix((i-0.0000001)/(360/dt)); %determine the cycle as an integer
		set(joint1,'xdata', Ax(i), 'ydata',Ay(i));
      	set(joint2,'xdata', Bx(i), 'ydata',By(i));
      	set(joint3,'xdata', Gx(i), 'ydata',Gy(i));
     	set(joint4,'xdata', Fx(i), 'ydata',Fy(i));
     	set(joint5,'xdata', Dx(i), 'ydata',Dy(i));
      	set(joint6,'xdata', Ex(i), 'ydata',Ey(i));
      	set(crank,'xdata',[Mx Ax(i)],'ydata', [Mx Ay(i)]);
      	set(crank2,'xdata',[Ox Fx(i)],'ydata', [Oy Fy(i)]);
      	set(crank3,'xdata',[Qx Dx(i)],'ydata', [Qy Dy(i)]);
      	set(coupler,'xdata', [Ax(i) Bx(i)],'ydata', [Ay(i) By(i)]);
      	set(coupler2,'xdata', [Fx(i) Gx(i)],'ydata', [Fy(i) Gy(i)]);
      	set(coupler3,'xdata', [Dx(i) Ex(i)],'ydata', [Dy(i) Ey(i)]);
      	set(rocker,'xdata', [Qx Bx(i)],'ydata', [Qy By(i)]);
      	set(rocker2,'xdata', [Mx Gx(i)],'ydata', [My Gy(i)]);
      	set(rocker3,'xdata', [Ox Ex(i)],'ydata', [Oy Ey(i)]);
		set(gridpt,'xdata',Cx(i), 'ydata' ,Cy(i));
      	set(couplerptr1,'xdata', [Ax(i) Cx(i) Bx(i)], ...
         'ydata' ,[Ay(i) Cy(i) By(i)]);
      	set(couplerptr2,'xdata', [Fx(i) Cx(i) Gx(i)], ...
         'ydata' ,[Fy(i) Cy(i) Gy(i)]);
      	set(couplerptr3,'xdata', [Dx(i) Cx(i) Ex(i)], ...
         'ydata' ,[Dy(i) Cy(i) Ey(i)]);
		drawnow;   %flush the draw buffer

% Do meaningless calculation to slow down the linkage

		for k=1:1:timesink
			zzz=log10(k);
		end
	end

% Plot linkage in fixed position.

	i = 6;
	set(joint1,'xdata', Ax(i), 'ydata',Ay(i));
	set(joint2,'xdata', Bx(i), 'ydata',By(i));
	set(joint3,'xdata', Gx(i), 'ydata',Gy(i));
	set(joint4,'xdata', Fx(i), 'ydata',Fy(i));
	set(joint5,'xdata', Dx(i), 'ydata',Dy(i));
	set(joint6,'xdata', Ex(i), 'ydata',Ey(i));
	set(crank,'xdata',[0 Ax(i)],'ydata', [0 Ay(i)]);
	set(crank2,'xdata',[Ox Fx(i)],'ydata', [Oy Fy(i)]);
	set(crank3,'xdata',[Qx Dx(i)],'ydata', [Qy Dy(i)]);
	set(coupler,'xdata', [Ax(i) Bx(i)],'ydata', [Ay(i) By(i)]);
	set(coupler2,'xdata', [Fx(i) Gx(i)],'ydata', [Fy(i) Gy(i)]);
	set(coupler3,'xdata', [Dx(i) Ex(i)],'ydata', [Dy(i) Ey(i)]);
	set(rocker,'xdata', [Qx Bx(i)],'ydata', [Qy By(i)]);
	set(rocker2,'xdata', [Mx Gx(i)],'ydata', [My Gy(i)]);
	set(rocker3,'xdata', [Ox Ex(i)],'ydata', [Oy Ey(i)]);
	set(gridpt,'xdata',Cx(i), 'ydata' ,Cy(i));
	set(couplerptr1,'xdata', [Ax(i) Cx(i) Bx(i)], ...
		'ydata' ,[Ay(i) Cy(i) By(i)]);
	set(couplerptr2,'xdata', [Fx(i) Cx(i) Gx(i)], ...
		'ydata' ,[Fy(i) Cy(i) Gy(i)]);
	set(couplerptr3,'xdata', [Dx(i) Cx(i) Ex(i)], ...
		'ydata' ,[Dy(i) Cy(i) Ey(i)]);
   
%flush the draw buffer

	drawnow; 
		
% Ask if animation should be repeated

	ans=input('Repeat animation? y/n [y]: ','s');
	if isempty(ans);ans='y';end
	if ans=='y'
		rep=input('Change animation speed? (+/-/0) [-]:','s');
		if isempty(rep);rep='-';end
		if rep=='+'; timesink=timesink/10; end
		if rep=='-'; timesink=timesink*10; end
		if timesink<1; timesink=1; end
	end
end
clf;

% Define the axes for the first graph (MQ linkage)

width = 0.45;
height = 0.35;
h1=axes('position', [0.1 .55 width height],'box', 'on',...
        'xcolor', 'k','ycolor','k','fontname', 'times', 'fontsize', 8);
set(gcf,'color', 'w')
joint1=line('xdata', [], 'ydata', [], 'marker', 'o',...
   'erasemode', 'xor', 'color', 'r');
joint2=line('xdata', [], 'ydata', [], 'marker', 'o',...
    'erasemode', 'xor', 'color', 'r');
crank=line('xdata', [0 0], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
    'xor','color', 'r');
coupler=line('xdata', [], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
    'xor','color', 'r');
couplerptr1=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
    'xor','color', 'r');	   
couplerpt1=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
    'none','color', 'k', 'linestyle', '--');	
gridpt1=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
    'xor','color', 'k', 'marker', 'o');	
rocker=line('xdata', [Qx 0], 'ydata' ,[Qy 0], 'linewidth',2,...
    'erasemode', 'xor','color', 'r');
bushy1=line('xdata', bush1(:,1), 'ydata',bush1(:,2), 'linestyle', '-',  ...
    'color', 'g');
bushy2=line('xdata', bush2(:,1), 'ydata',bush2(:,2), 'linestyle', '-', ...
    'color', 'g');
circ1=line('xdata', cir1(:,1), 'ydata',cir1(:,2), 'linestyle', '-',  ...
     'color', 'g');
circ2=line('xdata', cir2(:,1), 'ydata',cir2(:,2), 'linestyle', '-', ...
     'color', 'g');

% Define the axes for the second graph (MO linkage).  Start with axis location

h2=axes('position', [0.5 .55 width height],'box', 'on',...
        'xcolor', 'k','ycolor','k','fontname', 'times', 'fontsize', 8); 
set(gcf,'color', 'w')
joint3=line('xdata', [], 'ydata', [], 'marker', 'o',...
    'erasemode', 'xor', 'color', 'g');
joint4=line('xdata', [], 'ydata', [], 'marker', 'o',...
    'erasemode', 'xor', 'color', 'g');
crank2=line('xdata', [0 0], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
    'xor','color', 'g');
coupler2=line('xdata', [], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
    'xor','color', 'g');
couplerptr2=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
    'xor','color', 'g');	   
couplerpt2=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
    'none','color', 'k', 'linestyle', '--');	
gridpt2=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
    'xor','color', 'k', 'marker', 'o');	
rocker2=line('xdata', [Ox 0], 'ydata' ,[Oy 0], 'linewidth',2,...
    'erasemode', 'xor','color', 'g');
bushy1=line('xdata', bush1(:,1), 'ydata',bush1(:,2), 'linestyle', '-', ...
    'color', 'g');
bushy3=line('xdata', bush3(:,1), 'ydata',bush3(:,2), 'linestyle', '-', ...
     'color', 'g');
circ1=line('xdata', cir1(:,1), 'ydata',cir1(:,2), 'linestyle', '-', ...
    'color', 'g');
circ3=line('xdata', cir3(:,1), 'ydata',cir3(:,2), 'linestyle', '-', ...
     'color', 'g');

% Set up axes for third plot (QO linkage)

h3=axes('position', [0.5 .1  width  height],'box', 'on',...
        'xcolor', 'k','ycolor','k','fontname', 'times', 'fontsize', 10); 
set(gcf,'color', 'w')
joint5=line('xdata', [], 'ydata', [], 'marker', 'o',...
    'erasemode', 'xor', 'color', 'k');
joint6=line('xdata', [], 'ydata', [], 'marker', 'o',...
    'erasemode', 'xor', 'color', 'k');
crank3=line('xdata', [0 0], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
    'xor','color', 'k');
coupler3=line('xdata', [], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
    'xor','color', 'k');
couplerptr3=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
    'xor','color', 'k');	   
couplerpt3=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
    'none','color','k', 'linestyle', '--');	
gridpt3=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
    'xor','color', 'k', 'marker', 'o');	
rocker3=line('xdata', [Qx 0], 'ydata' ,[Qy 0], 'linewidth',2,...
    'erasemode', 'xor','color', 'k');
bushy2=line('xdata', bush2(:,1), 'ydata',bush2(:,2), 'linestyle', '-', ...
     'color', 'g');
bushy3=line('xdata', bush3(:,1), 'ydata',bush3(:,2), 'linestyle', '-', ...
     'color', 'g');
circ2=line('xdata', cir2(:,1), 'ydata',cir2(:,2), 'linestyle', '-', ...
     'color', 'g');
circ3=line('xdata', cir3(:,1), 'ydata',cir3(:,2), 'linestyle', '-', ...
     'color', 'g');

% Set the axis limits for the graphs

xdelta=xmax-xmin;
ydelta=ymax-ymin;
axes(h1);
values=axisadjust(xmin, xmax, ymin, ymax, width, height);
xmin=values(1);
xmax=values(2);
ymin=values(3);
ymax=values(4);
axis equal
axis ([xmin, xmax, ymin, ymax])
set(couplerpt1,'xdata', Cx, 'ydata' ,Cy);
text(xmin+0.13*xdelta,ymax-0.1*ydelta,'MQ Cognate','color', 'k',...
           'fontname', 'times', 'fontsize', 8);

axes(h2);
axis equal
axis ([xmin, xmax, ymin, ymax]);
set(couplerpt2,'xdata', Cx, 'ydata' ,Cy);
text(xmin+0.13*xdelta,ymax-0.1*ydelta,'MO Cognate','color', 'k',...
           'fontname', 'times', 'fontsize', 8);

axes(h3);
axis equal
axis ([xmin, xmax, ymin, ymax]);
set(couplerpt3,'xdata', Cx, 'ydata' ,Cy);
text(xmin+0.13*xdelta,ymax-0.1*ydelta,'OQ Cognate','color', 'k',...
           'fontname', 'times', 'fontsize', 8);

% Plot the results.

ans='y';

% Animate the results as long as ans = 'y'

while ans=='y'
	for i=1:1:itotal

% Draw MQ linkage

		set(joint1,'xdata', Ax(i), 'ydata',Ay(i));
		set(joint2,'xdata', Bx(i), 'ydata',By(i));
		set(crank,'xdata',[Mx Ax(i)],'ydata', [Mx Ay(i)]);
		set(coupler,'xdata', [Ax(i) Bx(i)],'ydata', [Ay(i) By(i)]);
		set(rocker,'xdata', [Qx Bx(i)],'ydata', [Qy By(i)]);
		set(gridpt1,'xdata',Cx(i), 'ydata' ,Cy(i));
		set(couplerptr1,'xdata', [Ax(i) Cx(i) Bx(i)], ...
         'ydata' ,[Ay(i) Cy(i) By(i)]);

% Draw MO linkage
	
		set(joint3,'xdata', Gx(i), 'ydata',Gy(i));
		set(joint4,'xdata', Fx(i), 'ydata',Fy(i));
		set(crank2,'xdata',[Ox Fx(i)],'ydata', [Oy Fy(i)]);
		set(coupler2,'xdata', [Fx(i) Gx(i)],'ydata', [Fy(i) Gy(i)]);
		set(rocker2,'xdata', [Mx Gx(i)],'ydata', [My Gy(i)]);
		set(gridpt2,'xdata',Cx(i), 'ydata' ,Cy(i));
		set(couplerptr2,'xdata', [Fx(i) Cx(i) Gx(i)], ...
         'ydata' ,[Fy(i) Cy(i) Gy(i)]);

% Draw QO linkage
			
		set(joint5,'xdata', Dx(i), 'ydata',Dy(i));
		set(joint6,'xdata', Ex(i), 'ydata',Ey(i));
		set(crank3,'xdata',[Qx Dx(i)],'ydata', [Qy Dy(i)]);
		set(coupler3,'xdata', [Dx(i) Ex(i)],'ydata', [Dy(i) Ey(i)]);
		set(rocker3,'xdata', [Ox Ex(i)],'ydata', [Oy Ey(i)]);
		set(gridpt3,'xdata',Cx(i), 'ydata' ,Cy(i));
		set(couplerptr3,'xdata', [Dx(i) Cx(i) Ex(i)], ...
         'ydata' ,[Dy(i) Cy(i) Ey(i)]);

		drawnow;   %flush the draw buffer
	end

% Plot figures in final position.

	i = 6;

% Plot MQ linkage first

	set(joint1,'xdata', Ax(i), 'ydata',Ay(i));
	set(joint2,'xdata', Bx(i), 'ydata',By(i));
	set(crank,'xdata',[Mx Ax(i)],'ydata', [Mx Ay(i)]);
	set(coupler,'xdata', [Ax(i) Bx(i)],'ydata', [Ay(i) By(i)]);
	set(rocker,'xdata', [Qx Bx(i)],'ydata', [Qy By(i)]);
	set(gridpt1,'xdata',Cx(i), 'ydata' ,Cy(i));
	set(couplerptr1,'xdata', [Ax(i) Cx(i) Bx(i)], ...
         'ydata' ,[Ay(i) Cy(i) By(i)]);

% Draw MO linkage
	
	set(joint3,'xdata', Gx(i), 'ydata',Gy(i));
	set(joint4,'xdata', Fx(i), 'ydata',Fy(i));
	set(crank2,'xdata',[Ox Fx(i)],'ydata', [Oy Fy(i)]);
	set(coupler2,'xdata', [Fx(i) Gx(i)],'ydata', [Fy(i) Gy(i)]);
	set(rocker2,'xdata', [Mx Gx(i)],'ydata', [My Gy(i)]);
	set(gridpt2,'xdata',Cx(i), 'ydata' ,Cy(i));
	set(couplerptr2,'xdata', [Fx(i) Cx(i) Gx(i)], ...
		'ydata' ,[Fy(i) Cy(i) Gy(i)]);

% Draw QO linkage
			
	set(joint5,'xdata', Dx(i), 'ydata',Dy(i));
	set(joint6,'xdata', Ex(i), 'ydata',Ey(i));
	set(crank3,'xdata',[Qx Dx(i)],'ydata', [Qy Dy(i)]);
	set(coupler3,'xdata', [Dx(i) Ex(i)],'ydata', [Dy(i) Ey(i)]);
	set(rocker3,'xdata', [Ox Ex(i)],'ydata', [Oy Ey(i)]);
	set(gridpt3,'xdata',Cx(i), 'ydata' ,Cy(i));
	set(couplerptr3,'xdata', [Dx(i) Cx(i) Ex(i)], ...
		'ydata' ,[Dy(i) Cy(i) Ey(i)]);

%flush the draw buffer

	drawnow; 

% Ask if the animation should be repeated

	ans=input('Repeat animation? y/n [y]: ', 's');
	if isempty(ans);
		ans='y';
	end
end



