function [values] = crank(r2,theta2,td2,tdd2,flag)

% This function analyzes a crank when it is the driving link.  
% The input values are:

%r2     = length of vector 2 (crank)
%theta2 = crank angle (degrees)
%td2    = crank angular velocity (rad/sec)
%tdd2   = crank angular acceleration (rad/sec^2)
%flag    = analysis flag.  If flag = 1, only a position analysis is conducted. 
%          If flag = 2, both a position and velocity analysis is conducted. 
%		     If flag = 3, a position, velocity, and acceleration analysis
%		               is conducted.

% The results are returned in the vector "values".  The answers are 
% stored in values according to the following:

%values (1:2) = x,y components of position of crank pin
%values (3:4) = x,y components of velocity of crank pin
%values (5:6) = x,y components of acceleration of crank pin

%convert input data

fact=pi/180;
t2=theta2*fact;
s2=sin(t2);
c2=cos(t2);
	
% coordinates of crank pin
	
values(1)=r2*c2;
values(2)=r2*s2;
	
% velocity of crank pin

if flag>1
	values(3)=-r2*td2*s2;
	values(4)=r2*td2*c2;
end
	
% acceleration of crank pin

if flag>2
	values(5)=-r2*tdd2*s2-r2*td2*td2*c2;
	values(6)=r2*tdd2*c2-r2*td2*td2*s2;
end
