% Solution to Example 3.9 with coupler driving.  This routine calls rpprc in a 
% for loop for 1-deg increments of theta3.


clear all;
r3=10;
rqr=20;
theta2=0;
beta=90;
td3=10;
tdd3=0;
flag=3;
fact=pi/180;
i=0;

for th3=0:1:360
	i=i+1;
	theta3(i)=th3;
%
% Solve the problem for 1 degree increments of theta3.
%
	values = prrpc(r3,theta2,theta3(i),td3,tdd3,beta,flag);

	rp(1:2)=values(25:26);
	rq(1:2)=values(27:28);
	rdp(1:2)=values(29:30);
	rddp(1:2)=values(33:34);
	rrx(i)=rq(1)+rqr*cos((theta3(i)+180)*fact);
	rry(i)=rq(2)+rqr*sin((theta3(i)+180)*fact);
	rpx(i)=rp(1);
	rpy(i)=rp(2);
	rqx(i)=rq(1);
	rqy(i)=rq(2);
	drp(i)=rdp(1);
	ddrp(i)=rddp(1);

end
itotal=i;
tt=2;

%plot the results.

clf
ans='y';
disp('   ')
disp('         Elliptic Trammel Mechamism')

% Define velocity axes.

%h2=axes('position',[0.6 .55 .35 .35],'box', 'on','xcolor',...
%         'k','ycolor', 'k','fontname', 'times', 'fontsize', '10');
h2=axes('position',[0.50 .55 .30 .30],'box', 'on','xcolor',...
         'k','ycolor', 'k','fontname', 'times', 'fontsize', 10);
		 		 
set(gcf,'color', 'w');;
xlabel('\theta_{3} (deg)','color', 'k')
ylabel('Velocity of Point P (cm/s)','color', 'k')
VelP=line('xdata', [], 'ydata', [],'erasemode','none','visible', 'on',...
          'color', 'r');
hbead1=line('xdata',[],'ydata',[],'marker','o','erase','xor','markersize',6);

% Define acceleration axes.

h3=axes('Position', [0.50 .12 .30 .30],'box', 'on','xcolor',...
        'k','ycolor','k','fontname','times','fontsize',10);
set(gcf,'color', 'w');;
xlabel('\theta_3 (deg)','color', 'k')
ylabel('Acceleration of Point P (cm/s)','color', 'k')
AccP=line('xdata', [], 'ydata', [],  'erasemode', 'none', 'color', 'r');
hbead2=line('xdata',[],'ydata',[],'marker','o','erase','xor','markersize',6);

% Define position axes.

h1=axes('position', [0.1 .55 .30 .30],'box','on','xcolor','k','ycolor','k',...
        'fontname', 'times', 'fontsize', 10);
set(gcf,'color', 'w');;
coupler=line('xdata', [], 'ydata' ,[], 'linewidth' ,3, 'erasemode', 'xor',...
             'color', 'k');
couplerpoint=line('xdata',[],'ydata',[],'linewidth',1,'linestyle', '--',...
             'erasemode','none','color',[1,0,0]);
blockp=line('xdata', [], 'ydata',[],'erase','xor', 'color', 'k');
blockq=line('xdata', [], 'ydata',[],'erase','xor', 'color', 'k');
framelinep=line('xdata', [], 'ydata', [], 'erasemode', 'none', 'color', 'k');
framelineq=line('xdata', [], 'ydata', [], 'erasemode', 'none', 'color', 'k');

% Identify coordinates for frame line at P.

x0=-1.3*r3;
y0=-(r3/12)*1.05;
length=-2*x0;
angle=0;
ndash=20;
flag=1;
coord=frameline(length,x0,y0,ndash,angle,flag);
npoints=3*ndash;
for j=1:1:npoints
	xfp(j)=coord(j,1);
	yfp(j)=coord(j,2);
end

% Identify coordinates for frame line at Q.

y0=-1.3*r3;
x0=-(r3/12)*1.05;
length=-2*y0;
angle=90;
flag=-1;
coord=frameline(length,x0,y0,ndash,angle,flag);
for j=1:1:npoints
	xfq(j)=coord(j,1);
	yfq(j)=coord(j,2);
end

% Identify box for slider at point P.

length=r3/4;
width=r3/6;

% Set the axis limits.

	axes(h2);
%set axis limits for velocity of P

	axis([min(theta3) max(theta3) (1.05)*min(drp) (1.05)*max(drp)]);
	
%set axis limits for acceleration of P
	axes(h3);
	axis([min(theta3) max(theta3) (1.05)*min(ddrp) (1.05)*max(ddrp)]);

%set axis limits for the geometry
	axes(h1);
	axis([(1.05)*min(rrx) (1.05)*max(rrx) (0.9)*min(rry) (1.05)*max(rry)]);
	axis('equal')

% Draw curves for each plot.

	set(VelP,'xdata', theta3,'ydata', drp);
	set(AccP,'xdata', theta3,'ydata', ddrp);	
	set(couplerpoint,'xdata', rrx,'ydata',rry);
	set(framelinep,'xdata', xfp,'ydata',yfp);
	set(framelineq,'xdata', xfq,'ydata',yfq);

% Animate the results.

length=r3/4;
width=r3/6;
r=r3/10;
ninc=20;
npoints=ninc+1;
while ans=='y'
	for j=1:1:tt;
		for i=1:1:itotal;
		
			% Draw block at P
			
			set(framelinep,'xdata', xfp,'ydata',yfp);
			set(framelineq,'xdata', xfq,'ydata',yfq);
			flag=0;
			angle=0;
			x0=rpx(i);
			y0=rpy(i);
			coord=rect(length,width,x0,y0,angle,flag);
			for j=1:1:5
				xcoord(j)=coord(j,1);
				ycoord(j)=coord(j,2);
			end
			set(blockp,'xdata',xcoord,'ydata',ycoord);

			% Draw block at Q
			
			flag=0;
			x0=rqx(i);
			y0=rqy(i);
			angle=90;
			coord=rect(length,width,x0,y0,angle,flag);
			for j=1:1:5
				xcoord(j)=coord(j,1);
				ycoord(j)=coord(j,2);
			end
			set(blockq,'xdata',xcoord,'ydata',ycoord);
			
			% Draw coupler line
			
			set(coupler,'xdata',[rqx(i) rrx(i)],'ydata',[rqy(i) rry(i)]);		
			set(hbead1,'xdata',theta3(i),'ydata',drp(i));
			set(hbead2,'xdata',theta3(i),'ydata',ddrp(i));	
			drawnow;   %flush the draw buffer
		end
		i=i+1;	%increments for loop
	end		%ends while loop

% Draw in final position
i=13;

	% Draw block at P
			
	flag=0;
	angle=0;
	x0=rpx(i);
	y0=rpy(i);
	coord=rect(length,width,x0,y0,angle,flag);
	for j=1:1:5
		xcoord(j)=coord(j,1);
		ycoord(j)=coord(j,2);
	end
	set(blockp,'xdata',xcoord,'ydata',ycoord);

	% Draw block at Q
			
	flag=0;
	x0=rqx(i);
	y0=rqy(i);
	angle=90;
	coord=rect(length,width,x0,y0,angle,flag);
	for j=1:1:5
		xcoord(j)=coord(j,1);
		ycoord(j)=coord(j,2);
	end
	set(blockq,'xdata',xcoord,'ydata',ycoord);
			
	% Draw coupler line
			
	set(coupler,'xdata',[rqx(i) rrx(i)],'ydata',[rqy(i) rry(i)]);		
	set(hbead1,'xdata',theta3(i),'ydata',drp(i));
	set(hbead2,'xdata',theta3(i),'ydata',ddrp(i));	
	drawnow;   %flush the draw buffer

%	Ask if the animation should be repeated
	ans=input('Repeat animation? y/n [y]: ', 's');
	if isempty(ans);
		ans='y';
	end
end

% Computer the results for one position.

r3=10;
sigma=1;
beta=-90;
theta2=90;
flag=3;
beta=-90;
td3=10;
tdd3=0;
flag=3;
fact=pi/180;
theta3(1)=-30;

values = prrpc(r3,theta2,theta3(1),td3,tdd3,beta,flag);

r(1:4)=values(1:4)
th(1:4)=values(5:8)
rd(1:4)=values(9:12)
thd(1:4)=values(13:16)
rdd(1:4)=values(17:20)
thdd(1:4)=values(21:24)
rp(1:2)=values(25:26)
rq(1:2)=values(27:28)
rdp(1:2)=values(29:30)
rdq(1:2)=values(31:32)
rddp(1:2)=values(33:34)
rddq(1:2)=values(35:36)

fprintf('example_3p9.dat','%10.6f %10.6f %10.6f %10.6f \n',values) 









