function [Qstart, Qstop]=fb_angle_limits_cr(r1,r2,r3,r4,Q1)

% Function file that calculates the initial and final angle for four-bar
% linkage when the crank is the driver.

% Variables
%   r1=frame length (cm)
%   r2=crank length (cm)
%   r3=coupler length (cm)
%   r4=rocker length (cm)
%   Qstart=initial crank angle (deg)
%   Qstop=final crank angle (deg)

%Program

r=[r1,r2,r3,r4];
rmin=min(r);
rmax=max(r);
rtotal=r1+r2+r3+r4;

if (r1+r2)>(r3+r4)&abs(r1-r2)<abs(r3-r4)
	Qstart=acos((-(r4-r3)^2+r2^2+r1^2)/(2*r1*r2));
	Qstop=acos((r2^2-(r4+r3)^2+r1^2)/(2*r1*r2));
end
if (r1+r2)>(r3+r4)&abs(r1-r2)>=abs(r3-r4)
	Qstart=acos((r2^2-(r4+r3)^2+r1^2)/(2*r1*r2));
	Qstop=-Qstart;
end
if (r1+r2)<=(r3+r4)&abs(r1-r2)>=abs(r3-r4)
	Qstart=0;
	Qstop=2*pi;
end
if (r1+r2)<=(r3+r4)&abs(r1-r2)<abs(r3-r4)
	Qstart=acos((r2^2-(r4-r3)^2+r1^2)/(2*r1*r2));
	Qstop=2*pi-Qstart;
end
range = Qstop-Qstart;
Qstart=Q1+(Qstart+0.0000001*range)*180/pi;
Qstop=Q1+(Qstop-0.0000001*range)*180/pi;

