% Matlab program to draw a gear generated by a straight flanked hob.
%
%Some of the important variables used are:

%Dp      = Diametral pitch
%ar      = Addendum constant for rack
%br      = Dedendum constant for rack
%phi     = pressure angle in degrees
%rt      = tip radius of rack
%rf      = fillet radius of rack
%r       = pitch radius of gear
%ag      = Addendum constant for gear
%bg      = Dedendum constant for gear
%N       = Number of gear teeth

clf;
clear all;
ans='y';
disp('   ')
disp('         Gear Tooth Generation Program')
width=0.8;
height=0.8;
h=axes('position', [.05 .05 width height],'box', 'on', 'xcolor', 'k',...
       'ycolor','k');
set(gcf,'color', 'w')

Dp=input('Enter value of diametral pitch [10]: ');
if isempty(Dp)
	Dp = 10; 
end

nteeth=input('Enter value of teeth [3]: ');
if isempty(nteeth)
	nteeth = 3; 
end

ar = 1.50;
br = 1.25;
phi = 20;
rt = 0.02;
rf = 0.3/Dp;
N=30;
ag = 1;
ptregion1 = 20;
ptregion2 = 20;
ptregion3 = 20;
ptregion4 = 10;
ptregion5 = 5;

% Compute basic parameter values.
	
A=ar/Dp;
B=br/Dp;
p=pi/Dp;
r=p*N/(pi*2);
ro=r+ag/Dp;
r2d=180/(4*atan(1.0));
d2r=1/r2d;
phir=phi*d2r;
gamma=pi/2-phir;
lt=pi/(2*Dp)-2*A*tan(phir)-2*rt*tan(gamma/2);
lb=pi/(2*Dp)-2*B*tan(phir)-2*rf*tan(gamma/2);

% Check for negative values for lt and lb.  If either is negative,
% set the value to zero and compute the corresponding radius.

if lt < 0
	lt=0;
	rt=(pi/(2*Dp)-2*A*tan(phir))/(2*tan(gamma/2));
end

if lb < 0
	lb=0;
	rf=(pi/(2*Dp)-2*B*tan(phir))/(2*tan(gamma/2));
end
		
% Determine a set of points in region I
	
beta=0.0;
i=0;
dbeta=1/ptregion1;
for j=1:1:ptregion1
	i=i+1;	
	beta=beta+dbeta;
	rack(1,i)=beta*lt/2;
	rack(2,i)=A;
	n(1,i)=0;
	n(2,i)=1.0;
end
	
% Determine a set of points for region II

beta = 0.0;
dbeta=1/ptregion2;
for j=1:1:ptregion2
	i=i+1;
	beta=beta+dbeta;
	rack(1,i)=lt/2+rt*sin(beta*gamma);
	rack(2,i)=A-rt*(1-cos(beta*gamma));
	n(1,i)=sin(beta*gamma);
	n(2,i)=cos(beta*gamma);
end
	
% Determine a set of points for region III

beta = 0.0;
dbeta=1/ptregion3;
for j=1:1:ptregion3
	i=i+1;
	beta=beta+dbeta;
	sgamma=sin(gamma);
	cgamma=cos(gamma);
	rack(1,i)=(1-beta)*(lt/2+rt*sgamma)+beta*(pi/(2*Dp)-lb/2-rf*sgamma);
	rack(2,i)=(1-beta)*(A-rt*(1-cgamma))+beta*(-B+rf*(1-cgamma));
	n(1,i)=cos(phir);
	n(2,i)=sin(phir);
end

% Determine a set of points for region IV

beta = 0.0;
dbeta=1/ptregion4;
for j=1:1:ptregion4
	i=i+1;
	beta=beta+dbeta;
	somb=sin((1-beta)*gamma);
	comb=cos((1-beta)*gamma);
	rack(1,i)=pi/(2*Dp)-lb/2-rf*somb;
	rack(2,i)=-B+rf*(1-comb);
	n(1,i)=somb;
	n(2,i)=comb;
end

% Determine a set of points for region V

beta = 0.0;
dbeta=1/ptregion5;
for j=1:1:ptregion5
	i=i+1;
	beta=beta+dbeta;
	somb=sin((1-beta)*gamma);
	comb=cos((1-beta)*gamma);
	rack(1,i)=pi/(2*Dp)-lb/2*(1-beta);
	rack(2,i)=-B;
	n(1,i)=0;
	n(2,i)=1;
end
itotal = i;
	
% Draw the rack.  Start by defining the plots

rackline=line('xdata',[],'ydata',[],'linewidth',2,'erasemode',...
	         'xor','color', 'k');
rackpitchline=line('xdata', [], 'ydata' ,[], 'linewidth',0.4,...
	         'erasemode', 'xor','color', 'k', 'linestyle', '-.');
xmax=max(rack(1,:));
xmin=min(rack(1,:));
ymax=max(rack(2,:));
ymin=min(rack(2,:));
xrange=xmax-xmin;
yrange=ymax-ymin;
xmin=xmin-0.05*xrange;
xmax=xmax+0.05*xrange;
ymin=ymin-0.05*yrange;
ymax=ymax+0.05*yrange;
axis equal
values=axisadjust(xmin, xmax, ymin, ymax, width, height);
xmin=values(1);
xmax=values(2);
ymin=values(3);
ymax=values(4);
axis([xmin xmax ymin ymax]);

% Plot the positions

set(rackline, 'xdata', rack(1,:), 'ydata', rack(2,:));
set(rackpitchline, 'xdata',[-0.05, 0.2], 'ydata', [0,0]);
text(0.1, 0.01,'Pitch line');
title('Half of hob tooth');
pause;

% Print the results to the screen

disp('   ')
fprintf('                   Gear parameters '); 
disp('   ')
fprintf('      ar      br       ag        p         r '); 
disp('   ')
fprintf('%8.3f %8.3f  %8.3f  %8.3f  %8.3f \n', ar, br, ag, p, r);
disp('   ') 
fprintf('      ro     phi       lt         lb        rt        rf'); 
disp('   ')
fprintf('%8.3f %8.3f  %8.3f  %8.3f  %8.3f  %8.3f \n', ro, phi, lt, lb, rt, rf);
% pause

% Print the rack coordinates to a file (rack.dat)

disp('   ')
fprintf('rack.dat','            Rack Coordinates '); 
disp('   ')
fprintf('rack.dat','   Position    Rackx        Racky'); 
disp('   ')
for j=1:1:itotal;
	fprintf('rack.dat','%7.0f %12.3f %12.3f \n', j, rack(1,j),  rack(2,j));
end

% Define the basic gear profile

for i=1:1:itotal
	theta=(rack(1,i)*n(2,i)-rack(2,i)*n(1,i))/(r*n(2,i));
	geart(1,i)=-cos(theta)*(rack(1,i)-r*theta)+sin(theta)*(rack(2,i)-r);
	geart(2,i)=-sin(theta)*(rack(1,i)-r*theta)-cos(theta)*(rack(2,i)-r);
	ang(i)=theta;
end

% Define the pitch circle arc

maxang=max(ang);
minang=min(ang);
dk=(maxang-minang)/20;
i=0;
for k=minang:dk:maxang
	i=i+1;
	plx(i)=r*sin(k);
	ply(i)=r*cos(k);
end	

% Rotate the coordinate system by -pi/N so that the y axis is along the 
% centerline of the gear tooth instead of the centerline of the gap.

beta=-pi/N;
for i=1:1:itotal
	xx(i)=geart(1,i)*cos(beta)-geart(2,i)*sin(beta);
	yy(i)=geart(1,i)*sin(beta)+geart(2,i)*cos(beta);
end

% Test for the undercut points which cannot be on the gear

jstop=itotal+1;
istop=itotal+1;
for i = 1:1:itotal-2
	for j=i+1:1:itotal-1
		if istop==itotal+1 & jstop==itotal+1
			ra(1)=xx(i);
			ra(2)=yy(i);
			rb(1)=xx(i+1);
			rb(2)=yy(i+1);
			rc(1)=xx(j);
			rc(2)=yy(j);
			rd(1)=xx(j+1);
			rd(2)=yy(j+1);
			rba=rb-ra;
			rca=rc-ra;
			rac=ra-rc;
			rda=rd-ra;
			rdc=rd-rc;
			rbc=rb-rc;
			rbd=rb-rd;
			Aabc=rba(1)*rca(2)-rba(2)*rca(1);
			Aabd=rba(1)*rda(2)-rba(2)*rda(1);
			Acda=rdc(1)*rac(2)-rdc(2)*rac(1);
			Aadb=rda(1)*rba(2)-rda(2)*rba(1);
			Acdb=rdc(1)*rbc(2)-rdc(2)*rbc(1);
			test1=Aabc*Aabd;
			test2=Acda*Acdb;			
	
% Check for the intersection of two line segments
		
			if test1<0 & test2<0 
				istop=i;
				jstop=j+1;
				alpha=abs(Acdb)/(abs(Acda)+abs(Acdb));
				re(1)=alpha*ra(1)+(1-alpha)*rb(1);
				re(2)=alpha*ra(2)+(1-alpha)*rb(2);
				j=itotal;
				i=itotal;
			end	
		end		
	end
end

% If two lines intersect, delete the points in the undercut region.

j=0;
for i=1:1:itotal
	if i<=istop | i >= jstop
		j=j+1;
		geart(1,j)=xx(i);
		geart(2,j)=yy(i);
		if i==istop
			j=j+1;
			geart(1,j)=re(1);
			geart(2,j)=re(2);
		end
	end
end
itotal=j;

% Check that the points do not extend beyond the addendum circle (ro).

j=0;
rtest1=0;
istop='n';
i=0;
for i=1:1:itotal
	if istop=='n'
		rtest2=sqrt(geart(1,i)^2+geart(2,i)^2);
		if rtest2<=ro
			j=j+1;
			gear(1,j)=geart(1,i);
			gear(2,j)=geart(2,i);
			xx(j)=gear(1,j);
			yy(j)=gear(2,j);
		end
		
% If the points extend beyond the addendum circle, discard the 
% points beyond ro and find the intersection of the gear with the 
% ro circle.
		
		if rtest2>ro
			alpha=(ro-rtest1)/(rtest2-rtest1);
			j=j+1;
			gear(1,j)=geart(1,i-1)+alpha*(geart(1,i)-geart(1,i-1));
			gear(2,j)=geart(2,i-1)+alpha*(geart(2,i)-geart(2,i-1));
			xx(j)=gear(1,j);
			yy(j)=gear(2,j);
			istop='y';
		end
		rtest1=rtest2;
	end
end

% if the addendum is reached replace the points beyond the 
% addendum with points on a circle arc.

if j<itotal
	beta = atan2(gear(1,j), gear(2,j));
	dbeta=beta/5;
	betak=beta;
	for k=1:1:5
		j=j+1;
		betak=betak-dbeta;
		sbetak=sin(betak);
		cbetak=cos(betak);
		gear(1,j)=ro*sbetak;
		gear(2,j)=ro*cbetak;
	end
end
jtotal=j;

% Reflect the points to draw the rest of the gear tooth

for i=1:1:jtotal-1
	j=j+1;
	gear(1,j)=-gear(1,jtotal-i);
	gear(2,j)=gear(2,jtotal-i);
end	
itotal=j;
	
% Print the gear tooth coordinates

disp('   ')
fprintf('gear.dat','            gear Coordinates ');
disp('   ')
fprintf('gear.dat','   Position    gearx        geary');
disp('   ')
for j=1:1:itotal;
	fprintf('gear.dat','%7.0f %12.3f %12.3f \n', j, gear(1,j),  gear(2,j));
end

% Draw the gear.  Start by defining the plots

gearline=line('xdata', [], 'ydata' ,[], 'linewidth',1,'erasemode',...
         'xor','color', 'k');
gearpitchline=line('xdata', [], 'ydata' ,[], 'linewidth',0.4,...
         'erasemode', 'xor','color', 'k', 'linestyle', '-.');

for i=1:1:itotal
	xtemp(i)=gear(1,i);
	ytemp(i)=gear(2,i);
end
		 
xmax=max(xtemp);
xmin=min(xtemp);
ymax=max(ytemp);
ymin=min(ytemp);
xrange=xmax-xmin;
yrange=ymax-ymin;
xmin=xmin-0.05*xrange;
xmax=xmax+0.05*xrange;
ymin=ymin-0.05*yrange;
ymax=ymax+0.05*yrange;
axis equal
values=axisadjust(xmin, xmax, ymin, ymax, width, height);
xmin=values(1);
xmax=values(2);
ymin=values(3);
ymax=values(4);
axis([xmin xmax ymin ymax]);

% Plot the positions

set(gearline, 'xdata', xtemp, 'ydata', ytemp);
set(gearpitchline, 'xdata',plx, 'ydata', ply);
title('Gear Teeth');
pause;

% Find the coordinates of the teeth on the rest of the gear.

dtheta=2*pi/N;
j=0;
for i=1:1:nteeth
	theta = (i-(nteeth+1)/2)*dtheta;
	sth = sin(theta);
	cth = cos(theta);
	for k=1:1:itotal
		j=j+1;
		gearx(j)=gear(1,k)*cth-gear(2,k)*sth;
		geary(j)=gear(1,k)*sth+gear(2,k)*cth;
	end
end
itotal=j;

% Compute the pitch circle for the whole gear

q=-nteeth*dtheta;
dq=-nteeth*q/90;
for i=1:1:180
	q=q+dq;
	plx(i)=r*sin(q);
	ply(i)=r*cos(q);
end
		 
xmaxf=max(gearx);
xminf=min(gearx);
ymaxf=max(geary);
yminf=min(geary);
xrangef=xmaxf-xminf;
yrangef=ymaxf-yminf;
xminf=xminf-0.05*xrangef;
yminf=yminf-0.05*yrangef;
xmaxf=xmaxf+0.05*xrangef;
ymaxf=ymaxf+0.05*yrangef;
values=axisadjust(xminf, xmaxf, yminf, ymaxf, width, height);
xminf=values(1);
xmaxf=values(2);
yminf=values(3);
ymaxf=values(4);
axis equal
axis([xminf xmaxf yminf ymaxf]);

% Plot the positions

set(gearline, 'xdata', gearx, 'ydata', geary);
set(gearpitchline, 'xdata',plx, 'ydata', ply);
