% MATLAB FILE FOR ANALYSIS OF FOOTPUMP MECHANISM

clf
clear all
ans='y';
disp('   ')
disp('         Footpump Mechanism Analysis Program')

% THESE ARE THE INPUT VALUES IN THE PROGRAM

r1 = 20;		    % measured (cm)
r2 =8.5;	 	    % measured (cm)
r4 =21.1;		    % measured (cm)
theta1=0; 		    % angle at Link 1 (rad) 
w2 = -2.4;		    % Ang Vel at Link 2 ,rad/s (Assumption)
W = 225;		    % Input Force, N (assumption)
beta=19.64*pi/180;  %fixed angle on link 2
cpr=13.5;		    %coupler point radius (cm)

tt=input('Please enter the number of cycles [3]: ');
if isempty(tt); tt=3; end;

disp('   ')
fprintf('  theta2   theta3    theta4     w2       w3       r3     r3dot      F\n') 

% Define Axes

width = 0.38;
height=0.35;

h1=axes('position', [0.6 .55 width height],'box', 'on','xcolor', 'k','ycolor', 'k');   %axis location
set(gcf,'color', 'w')
xlabel('theta2 (deg)','color', 'k')
ylabel('r3 length (cm)','color', 'k')
Displ=line('xdata', [], 'ydata', [],  'erasemode', 'none','visible', 'on', 'color', 'b');
hbead1=line('xdata',[],'ydata',[],'marker','o','erase','xor','color', 'k',...
       'markersize',6);

h2=axes('position', [0.6 .1  width height],'box', 'on','xcolor', 'k','ycolor', 'k');
set(gcf,'color', 'w')
xlabel('theta2 (deg)','color', 'k')
ylabel('link 3 angular velocity (rad/s)','color', 'k')
Vel=line('xdata', [], 'ydata', [],  'erasemode', 'none', 'color', 'b');
hbead2=line('xdata',[],'ydata',[],'marker','o','erase','xor','color', 'k',...
       'markersize',6);

h3=axes('position', [0.1 .1  width height],'box', 'on','xcolor', 'k','ycolor', 'k');
set(gcf,'color', 'w')
xlabel('theta2 (deg)','color', 'k')
ylabel('Force F32 (N)','color', 'k')
Force=line('xdata', [], 'ydata', [],'erasemode','none', 'color', 'b');
hbead3=line('xdata',[],'ydata',[],'marker','o','erase','xor','color', 'k',...
       'markersize',6);

h4=axes('position', [0.1 .55  width height],'box', 'on', 'xcolor', 'k','ycolor', 'k');
set(gcf,'color', 'w')
axis('equal')
xmin=-2;
xmax = r1+0.1*r4;
ymin=-5;
ymax=1.2*r4;
values=axisadjust(xmin, xmax, ymin, ymax, width, height);
xmin=values(1);
xmax=values(2);
ymin=values(3);
ymax=values(4);
axis equal
axis ([xmin, xmax, ymin, ymax]);


% Set up vectors for cranks

jointB=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', 10, 'erasemode', 'xor', 'color', ...
       'r');
crank=line('xdata', [0 0], 'ydata' ,[], 'linewidth' ,1, 'erasemode', 'xor','color', 'r');
coupler=line('xdata', [], 'ydata' ,[], 'linewidth' ,3, 'erasemode', 'xor','color', 'r');
crankline=line('xdata',[],'ydata',[],'linewidth',1,'erasemode','xor','color','r');
crankpt=line('xdata',[],'ydata',[],'linewidth',1,'linestyle', '--', 'erasemode','none','color','b');
hinge1=line('xdata', [], 'ydata',[],'erasemode', 'none', 'color', 'g');
hinge2=line('xdata', [], 'ydata',[],'erasemode', 'none', 'color', 'g');
joint1=line('xdata', [], 'ydata', [], 'erasemode', 'none', 'color', 'g');
joint2=line('xdata', [], 'ydata', [], 'erasemode', 'none', 'color', 'g');

% Draw the first fixed hinge

r = r2/10;		
x0=0;
y0=0;
ninc=20;
theta=0;    
npoints=ninc+1;
coord=circle2(r,x0,y0,ninc);

% find coordinates of first pin

for i=1:1:npoints
	xcoord(i)=coord(i,1);
	ycoord(i)=coord(i,2);
end

% find coordinates of first bushing

binc=ninc/2;
coord2=bushing(r,x0,y0,binc,theta);

bpoints=ninc/2+16;
for i=1:1:bpoints
	xbush(i)=coord2(i,1);
	ybush(i)=coord2(i,2);
end

% draw the first bushing

set(joint1,'xdata', xcoord,'ydata', ycoord);
set(hinge1,'xdata', xbush,'ydata', ybush);

% locate the second fixed bushing 

x0=r1*cos(theta1);
y0=r1*sin(theta1);
coord=circle2(r,x0,y0,ninc);

% find coordinates of second pin

for i=1:1:npoints
	xcoord(i)=coord(i,1);
	ycoord(i)=coord(i,2);
end

% find coordinates of second bushing

binc=ninc/2;
coord2=bushing(r,x0,y0,binc,theta);

bpoints=ninc/2+16;
for i=1:1:bpoints
	xbush(i)=coord2(i,1);
	ybush(i)=coord2(i,2);
end

% draw the first bushing

set(joint2,'xdata', xcoord,'ydata', ycoord);
set(hinge2,'xdata', xbush,'ydata', ybush);

i=0;

% Vary theta2 over range from 22 deg. < theta2 < 84 deg. 
for theta2 =  84*pi/180 : -2*pi/180 : 22*pi/180; % in radians


	% POSITION ANALYSIS
	
	r3= (r1^2 + r2^2 - 2*r1*r2*(cos(theta1)*cos(theta2) + sin(theta1)*sin(theta2)))^.5;

	% CHECK THE POSITION AND DETERMINE THE QUADRANT
	
	Num = -r1*sin(theta1) + r2*sin(theta2);
	Den = -r1*cos(theta1) + r2*cos(theta2);
	theta3 = atan2(Num,Den);	
	theta4=theta2-beta;
	r4x=r4*cos(theta4);
	r4y=r4*sin(theta4);
	r2x=r2*cos(theta2);
	r2y=r2*sin(theta2);
	
	theta2d=theta2*180/pi;
	theta3d=theta3*180/pi;
	theta4d=theta4*180/pi;

	% VELOCITY AT LINK 3
	
	w3 = (w2*r2/r3)*(cos(theta2)*cos(theta3) + sin(theta2)*sin(theta3));
	r3dot = (r3*w3*sin(theta3) - r2*w2*sin(theta2))/cos(theta3); 

	% FORCE ANALYSIS
	
	F32 = (W*r4*cos(theta4))/(r2*(-cos(theta3)*sin(theta2)+sin(theta3)*cos(theta2))); % resistance force

	% STORE THE VALUES IN MATRIX
	i=i+1;
	Bx(i)= r2*cos(theta2);
	By(i)= r2*sin(theta2);
	Cx(i)= r1*cos(theta1);
	Cy(i)= r1*sin(theta1);	
	Dx(i)=r4*cos(theta4);
	Dy(i)=r4*sin(theta4);
	XC=[Bx(i) Dx(i)];
	YC=[By(i) Dy(i)];
	X=[0 Bx(i) Cx(i) r1];
	Y=[0 By(i) Cy(i) 0];
	r3m(i)=r3;
	r4xm(i)=r4x;
	r4ym(i)=r4y;
	r2xm(i)=r2x;
	r2ym(i)=r2y;
	w3m(i)=w3;
	r3dotm(i)=r3dot;
	F32m(i)=F32;
	theta2dm(i)=theta2d;
	theta3dm(i)=theta3d;
	theta4dm(i)=theta4d;
	fprintf('%8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f \n',...
	theta2d,theta3d,theta4d,w2,w3,r3,r3dot,F32)
end

% Set the axis limits.

	axes(h1);
	axis([(0.9)*min(theta2dm) (1.05)*max(theta2dm) (0.95)*min(r3m) (1.05)*max(r3m)]);  %set axis limits for r3
	axes(h2);
	axis([(0.9)*min(theta2dm) (1.05)*max(theta2dm) (1.2)*min(w3m) (1.05)*max(w3m)]);  %set axis limits for the angular velocity of link 3
	axes(h3);
	axis([(0.9)*min(theta2dm) (1.05)*max(theta2dm) (0.9)*min(F32m) (1.05)*max(F32m)]);  %set axis limits for the pump force

% Draw curves for each plot.

	set(Displ,'xdata', theta2dm,'ydata', r3m);
	set(Vel,'xdata', theta2dm,'ydata', w3m);	
	set(Force,'xdata', theta2dm,'ydata', F32m);
	set(crankpt,'xdata', Dx,'ydata',Dy);

% Animate the results.

itotal=i;
while ans=='y'
	for j=1:1:tt;
		for i=1:1:itotal;
			set(jointB,'xdata',Bx(i),'ydata',By(i));
			set(crank,'xdata',[0 Bx(i)],'ydata',[0 By(i)]);
			set(coupler,'xdata',[Bx(i) Cx(i)],'ydata',[By(i) Cy(i)]);
			set(crankline,'xdata',[Bx(i) Dx(i)],'ydata',[By(i) Dy(i)]);
		
			set(hbead1,'xdata',theta2dm(i),'ydata',r3m(i));
			set(hbead2,'xdata',theta2dm(i),'ydata',w3m(i));	
			set(hbead3,'xdata',theta2dm(i),'ydata',F32m(i));
			drawnow;   % Flush the draw buffer
		end
		i=i+1;	%increments for loop
	end		%ends while loop

% Draw in final position

i=13;

%		Draw linkage first

		set(jointB,'xdata',Bx(i),'ydata',By(i));
		set(crank,'xdata',[0 Bx(i)],'ydata',[0 By(i)]);
		set(coupler,'xdata',[Bx(i) Cx(i)],'ydata',[By(i) Cy(i)]);
		set(crankline,'xdata',[Bx(i) Dx(i)],'ydata',[By(i) Dy(i)]);

%		Draw point on curve		

		set(hbead1,'xdata',theta2dm(i),'ydata',r3m(i));
		set(hbead2,'xdata',theta2dm(i),'ydata',w3m(i));	
		set(hbead3,'xdata',theta2dm(i),'ydata',F32m(i));
		drawnow;   %FLUSH THE DRAW BUFFER

%	Ask if the animation should be repeated

	ans=input('Repeat animation? y/n [y]: ', 's');
	if isempty(ans);
		ans='y';
	end
end




