function [coords] = frameline(length,x0,y0,ndash,theta,flag)

% This function determines the coordinates of a series of points defining 
% the frame line for a mechanism. The number of points stored is 3*ndash.

% The input values are:

%length  = length of frame line
%x0      = x coordinate of left end of line
%y0      = y coordinate of left end of line
%ndash   = number of dashes at -45 degrees to base
%theta 	 = rotation angle relative to the horizontal x axis (degrees)
%flag 	 = slide flag.  If flag = 1, the dashes are drawn on the bottom
%          of the line.  If flag = -1, they are drawn on the top.

% The results are returned in the vector "coords".  The answers are 
% stored in values according to the following:

%values (i,1) = x coordinates of frame line
%values (i,2) = y coordinates of frame line

% make sure that the number of dashes is at least 2.

adash=ndash;
if ndash < 2; adash=2; end
npoints=3*adash;

% find the coordinates of the points.

i=0;
fact=pi/180;
ldash=(length)/(2*(adash-1)+1);
delta=2*ldash;
thetar=fact*theta;

% define the base first

i=i+1;
xtemp(i)=ldash;
ytemp(i)=-ldash*flag;
i=i+1;
xtemp(i)=0;
ytemp(i)=0;

% find the dash coordinates starting from the left end

for j=1:1:adash-1
	i=i+1;
	xtemp(i)=xtemp(i-1)+delta;
	ytemp(i)=ytemp(i-1);
	i=i+1;
	xtemp(i)=xtemp(i-1)+ldash;
	ytemp(i)=-ldash*flag;
	i=i+1;
	xtemp(i)=xtemp(i-2);
	ytemp(i)=ytemp(i-2);
end

% find the coordinates of the end part	

i=i+1;
xtemp(i)=length;
ytemp(i)=0;

% rotate coordinates, translate by (x0, y0) and store coordinates in "coords"

c=cos(thetar);
s=sin(thetar);

for j=1:1:npoints
	coords(j,1)=x0+xtemp(j)*c-ytemp(j)*s;
	coords(j,2)=y0+xtemp(j)*s+ytemp(j)*c;
end
