% functgen.m 
%
% This program computes the link lengths of a 4-bar linkage with will generate
% a function which approximates the function defined by the m-file funct.m.  
% The program will compute the precision points based on Chebychev spacing.  

%Variables
%   Variables for calculation 
%   r1=frame length (cm)
%   r2=crank length (cm)
%   r3=coupler length (cm)
%   r4=rocker length (cm)
%   r = scaled link lengths [r1 r2 r3 r4]
%   R = scaled link lengths with signs preserved (cm)
%   ra = unscaled link lengths with signs preserved (cm)
%   r20=crank length and direction
%   r40=rocker length and direction
%   thetas=initial crank angle (deg)
%   thetaf=final crank angle (deg)
%   thetasr=initial crank angle (rad)
%   thetafr=final crank angle (rad)
%   thetalim=[thetasr thetafr] (rad)
%   thetal=[thetas thetaf] (deg)
%   thetar=crank angles at the precision points (rad)
%   theta1=crank angle at the first precision point for Chebychev
%   spacing (deg)
%   theta2=crank angle at the second precision point for Chebychev spacing (deg)
%   theta3=crank angle at the third precision point for Chebychev spacing (deg)
%   theta1r=crank angle at the first precision point for Chebychev spacing (rad)
%   theta2r=crank angle at the second precision point for Chebychev spacing (rad)
%   theta3r=crank angle at the third precision point for Chebychev spacing (rad)
%   theta1p=crank angle at the first precision point for Chebychev spacing (deg)
%   theta2p=crank angle at the second precision point for Chebychev spacing (deg)
%   theta3p=crank angle at the third precision point for Chebychev spacing (deg)
%   phis=initial rocker angle (deg)
%   phif=final rocker angle (deg)
%   phisr=initial rocker angle (rad)
%   phifr=final rocker angle (rad)
%   phil=[phisr phifr] (rad)
%   phir=rocker angles at the precision points (rad)
%   phi1=rocker angle at the first precision point for Chebychev spacing (deg)
%   phi2=rocker angle at the second precision point for Chebychev spacing (deg)
%   phi3=rocker angle at the third precision point for Chebychev spacing (deg)
%   phi1r=rocker angle at the first precision point for Chebychev spacing (rad)
%   phi2r=rocker angle at the second precision point for Chebychev spacing (rad)
%   phi3r=rocker angle at the third precision point for Chebychev spacing (rad)
%   xs=initial x value - proportional to crank angle
%   xf=final x value - proportional to crank angle
%   xl=[xs xf]
%   x=x value at the precision points
%   x0=precision points on the x scale - Chebychev spacing
%   yl=y scale values at the limiting points - proportional to the rocker angle
%   ygeto=y values achieved by actual linkage, Chebychev spacing
%   y=y value desired to emulate the angular relationship between the input and ouput angles
%   erroryo=error between desired and achieved anglular relationship, Chebychev spacing
%   Bx, By=crank pin location - x and y coordinates
%   Cx, Cy=rocker pin location - x and y coordinates
%   Bx2, By2=crank pointer location - x and y coordinates
%   Cx2, Cy2=rocker pointer location - x and y coordinates
%   Q22=crank angle throughout animation
%   Q44=rocker angle throughout animation
%   mode=assembly mode
%   circx1,circy1=x,y coordinates of the first circle
%   circx2,circy2=x,y coordinates of the second circle
%   radi=distance based on frame and crank link lengths
%   t1,t2=limiting crank angles (rad)
%   t3,t4=limiting rocker angles (rad)
%   t12=crank pointer angle (rad)
%   t34=rocker pointer angles (rad)
%   arcx1,arcy1=x,y coordinates of arc (crank pointer scale)
%   arcx2,arcy2=x,y coordinates of arc (rocker pointer scale)
%   dist=tick length
%   ta12=crank pointer angle at which ticks occur
%   ta34=rocker pointer angle at which ticks occur
%   tangl=[ta12 ta34]
%   bill=counting variable
%   rr1=horizontal displacemant for ticks
%   tickx,ticky=x,y coordinates of the ticks
%   rtot=sum of the link lengths
%   bushx1,bushy1=x,y coordinates of the first bushing
%   bushx2,bushy2=x,y coordinates of the second bushing
%   ydatx,ydaty=x,y coordinates of the y label 
%   ipos=number of linkage positions for the animation
%   fact=conversion factor, from degrees to radians
%   ans=string variable controlling animation repitition
%   lknown = link with the known length
%   rknown = known link length

%   Graphics Variables

%   h1=handle on the first axes in the window (linkage animation)
%   h2=handle on the second axes in the window (input/output angle relationship)
%   h4=handle on the fourth axes in the window (input angle/error relationship - Chebychev spacing)
%   Displ=line representing the input/output angular relationship
%   dbead=bead which follows the angular relationship throughout the animation
%   precisionpt=precision points on the angular relationship plot
%   erroro=line representing the input angle/error relationship for Chebychev spacing
%   ebead=bead which follows input angle/error relationship for Chebychev spacing
%   precpt=precision points on the input angle/ error relationship for Chebychev spacing
%   joint1=line for joint at crank/coupler
%   joint2=line for joint at coupler/rocker
%   crank=line for the crank
%   coupler=line for the coupler
%   rocker=line for the rocker
%   ipointer=line for the pointer on the crank
%   opointer=line for the pointer on the rocker
%   cir1=handle on first circle
%   cir2=handle on second circle
%   arc1=lines representing the arc of the x scale
%   arc2=lines representing the arc of the y scale
%   bush1,bush2=lines representing the bushings
%   tick=lines representing the ticks for the x and y scales
%   xmin, xmax= x limits for the axes
%   ymin, ymax= y limits for the axes

% program 

clf; clear all;
format long
ans='y';
ipos=40;  
disp('   ')
disp('      Function Generation Program')
disp('  ')
yinput=zeros(3,1);

% Input values for linkage variables 

readmode=input('Enter 1 for file input and 2 for interactive input [1]: ');
if isempty(readmode); readmode=1; end
inputfile=input('Enter input file name (functgenio.dat): ', 's');
if isempty(inputfile); inputfile = 'functgenio.dat'; end
if readmode==1
	fid = fopen(inputfile);
end
if readmode==2
	tt=input('Enter number of cycles (rev) [3]: ');
	if isempty(tt);tt = 3;end
	lknown=input('Enter link number corresponding to known length [1]:  ');
	if isempty(lknown); lknown=1; end
	rknown=input('Enter known link length [2]: ');
	if isempty(rknown);rknown = 2; end  
	thetas=input('Enter initial value for theta (deg) [45]: ');
	if isempty(thetas);thetas=45; end  
	thetaf=input('Enter final value for theta (deg) [105]: ');
	if isempty(thetaf);thetaf=105; end
	phis=input('Enter initial rocker angle (deg) [0]: ');
	if isempty(phis);phis=0; end  
	phif=input('Enter final rocker angle (deg) [60]: ');
	if isempty(phif);phif=60; end
	xs=input('Enter lower limit for x [1]: ');
	if isempty(xs);xs=1; end
	xf=input('Enter upper limit for x [2]: ');
	if isempty(xf);xf=2; end  
	anscheb=input('Use Chebychev spacing for precision points? y/n [y]: ', 's');
	if isempty(anscheb);anscheb='y'; end  
	ansfun=input('Input y values directly? y/n [n]: ', 's');
	if isempty(ansfun);ansfun='n'; end  

	if anscheb~= 'y'
		x(1)=input('Enter first x precision point: ');
		if isempty(x(1));x(1)=xl+0.1*(xf-xs); end
		x(2)=input('Enter second x precision point: ');
		if isempty(x(2));x(2)=xl+0.5*(xf-xs); end
		x(3)=input('Enter third x precision point: ');
		if isempty(x(3));x(3)=xl+0.9*(xf-xs); end
	end

	if ansfun~= 'n'
		ys=input('Enter lower limit for y: ');
		if isempty(ys);ys=1; end
		yf=input('Enter upper limit for y: ');
		if isempty(yf);yf=2; end  
		yinput(1)=input('Enter first y precision point: ');
		if isempty(yinput(1));yinput(1)=yl+0.1*(yf-ys); end
		yinput(2)=input('Enter second y precision point: ');
		if isempty(yinput(2));yinput(2)=yl+0.5*(yf-ys); end
		yinput(3)=input('Enter third y precision point: ');
		if isempty(yinput(3));yinput(3)=yl+0.9*(yf-ys); end
	end
	
% save the data to the file fileinput.dat
	
	tempio(1)=tt;
	tempio(2)=lknown;
	tempio(3)=rknown;	
	tempio(4)=thetas;
	tempio(5)=thetaf;
	tempio(6)=phis;
	tempio(7)=phif;
	tempio(8)=xs;
	tempio(9)=xf;
	tempio(10)=anscheb;
	tempio(11)=ansfun;
	if anscheb~= 'y'
		tempio(12)=x(1);
		tempio(13)=x(2);
		tempio(14)=x(3);
	end
	if ansfun~= 'n'
		tempio(15)=ys;
		tempio(16)=yf;
		tempio(17)=yinput(1);
		tempio(18)=yinput(2);
		tempio(19)=yinput(3);
	end
	tempiot=tempio(:);  % store the transpose of tempio for ease of reading
	fprintf(inputfile,'%f \n',tempiot)
end

% Read input data from the file functgenio.dat

if readmode==1	
	functgenio = fscanf(fid,'%f');
	tt=functgenio(1);
	lknown=functgenio(2);
	rknown=functgenio(3);
	thetas=functgenio(4);
	thetaf=functgenio(5);
	phis=functgenio(6);
	phif=functgenio(7);
	xs=functgenio(8);
	xf=functgenio(9);
	anscheb=functgenio(10);
	ansfun=functgenio(11);
	if anscheb~= 'y'
		x(1)=functgenio(12);
		x(2)=functgenio(13);
		x(3)=functgenio(14);
	end
	if ansfun~= 'n'
		ys=functgenio(15);
		yf=functgenio(16);
		yinput(1)=functgenio(17);
		yinput(2)=functgenio(18);
		yinput(3)=functgenio(19);
	end
end
fclose('all');
	
y=yinput;

% Print heading for input angles

disp('   ')
fprintf('    thetas     thetaf       phis       phif') 

% Print the input values.
xs,xf


if ansfun== 'n'; ys=funct(xs); end
if ansfun== 'n'; yf=funct(xf); end



ys, yf
disp('   ')
fprintf('%10.4f %10.4f %10.4f %10.4f\n',thetas, thetaf, phis, phif)
disp('   ')
fprintf('       xs         xf         ys         yf') 
disp('   ')
fprintf('%10.4f %10.4f %10.4f %10.4f\n', xs, xf, ys, yf)

% Convert angles to radians

fact=pi/180;
thetasr=thetas*fact;
thetafr=thetaf*fact;
phisr=phis*fact;
phifr=phif*fact;

% find Chebychev points.  The three values are returned in the vector x.

xl=[xs,xf];
thetalim=[thetasr,thetafr];
phil=[phisr,phifr];
if anscheb =='y'; x=chebychev(xl); end
if ansfun == 'n'; y=funct(x); end

% Calculate theta, phi, and y at the precision points (Chebychev).  The
% values are returned in yl, phir, thetar.

[thetar,phir,yl]= precout(x,xl,thetalim,phil,ansfun,ys, yf, yinput);

% Print out the precision points
disp('   ')
fprintf('         x           y          theta         phi ') 
disp('  ')
for ip=1:1:3
   fprintf('%12.5f %12.5f %12.5f %12.5f\n',x(ip), y(ip), thetar(ip),...
   phir(ip))
end
disp('   ')

% Compute the link lengths

[r,R,ra,mode,r20,r40,thetal]=links(thetar,phir,lknown,rknown,thetalim);

% Compute the position coordinates

[Q22,Q44,Bx,Cx,By,Cy,Bx2,Cx2,By2,Cy2]=animat(thetal,phil,r,mode,r20,...
   r40, ipos);

% Animate the mechanism   
     
ani(r,Bx,By,Cx,Cy,Bx2,By2,Cx2,Cy2,ipos,phil,thetal);

% Print out the link Lengths

disp('   ')
fprintf('     Unscaled values for link lengths ') 
disp('   ')
fprintf('       R1         R2         R3         R4 ') 
disp('  ')
fprintf('%10.5f %10.5f %10.5f %10.5f\n',ra(1),ra(2),ra(3),ra(4))
disp('   ')
fprintf('       Scaled values for link lengths ') 
disp('   ')
fprintf('       r1         r2         r3         r4 ') 
disp('  ')
fprintf('%10.5f %10.5f %10.5f %10.5f\n',r(1),r(2),r(3),r(4))

% Stop the calculations if the precision points are input directly, i.e.,
% if ansfun = y.

if ansfun== 'n'

% Calculate error in emulation

   ygeto=phi2y(Q44,yl,phil);
   err=errors(ygeto,xl);
   x0=x;
   r1=r(1);
   r2=r(2);
   r3=r(3);
   r4=r(4);

% Convert radians to degrees.

   theta1r=thetar(1);
   theta2r=thetar(2);
   theta3r=thetar(3);
   theta1=theta1r*(180/pi);
   theta2=theta2r*(180/pi);
   theta3=theta3r*(180/pi);
   phi1r=phir(1);
   phi2r=phir(2);
   phi3r=phir(3);
   phi1=phi1r*(180/pi);
   phi2=phi2r*(180/pi);
   phi3=phi3r*(180/pi);

% X,Y Scale Calculations.  First determine the x and y arcs.

   rad1=1.02*(r2);
   rad2=1.02*(r4);
   t1=(thetal(1))*(pi/180);
   t2=(thetal(2))*(pi/180);
   t3=phil(1);
   t4=phil(2);
   t12=t1:(t2-t1)/50:t2;
   t34=t3:(t4-t3)/50:t4;
   arcx1=rad1*cos(t12);
   arcy1=rad1*sin(t12);
   arcx2=(rad2*cos(t34))+r1;
   arcy2=rad2*sin(t34);

% Find the tick marks.

   tickdist=0.05*(rad1+rad2);
   dist1=[rad1 rad1+tickdist];
   dist2=[rad2 rad2+tickdist];  
   ta12=t1:(t2-t1)/4:t2;
   ta34=t3:(t4-t3)/4:t4;
   tt12=(t1+t2)*0.5;
   tt34=(t3+t4)*0.5;
   letdist1=rad1+2*tickdist;
   letdist2=rad2+2*tickdist;
   tangl=[ta12 ta34];
   for bill=1:length(tangl)
      if bill>5
         rr1=r1;
         dist=dist2;
      else
         rr1=0;
         dist=dist1;
      end
      tickx(bill,:)=((cos(tangl(bill)))*dist)+rr1;
      ticky(bill,:)=((sin(tangl(bill)))*dist);
   end

% Find the bushings coordinates

   rtot=sum(r);
   coor=bushing((rtot/100),0,0,20,0);
   bushx1=coor(:,1);
   bushy1=coor(:,2);
   coor=bushing((rtot/100),r1,0,20,0);
   bushx2=coor(:,1);
   bushy2=coor(:,2);

% Determine the circles inside the bushings   

   coor=circle2((rtot/100),0,0,20);
   circx1=coor(:,1);
   circy1=coor(:,2);
   coor=circle2((rtot/100),r1,0,20);
   circx2=coor(:,1);
   circy2=coor(:,2);
   clf;

%Define axes for the linkage.

	width=0.38;
	height=0.35;
	h1=axes('position',[0.1 .6 width height],'box','on','xcolor','k','ycolor',...
      'k');   %axis location
	set(gcf,'color', 'w')
	arc1=line('xdata',[],'ydata',[],'linestyle','-','markersize',6,...
      'erasemode','none', 'color','r');
	arc2=line('xdata',[],'ydata',[],'linestyle','-','markersize',6,...
      'erasemode','none', 'color','r');
	for bill=1:length(tangl)
      tick(bill)=line('xdata',[],'ydata',[],'linestyle','-','markersize',6,...
      'erasemode','none', 'color','r');
	end
	bush1=line('xdata',[],'ydata',[],'linestyle','-','markersize', 6,...
      'erasemode', 'none', 'color','r');
	bush2=line('xdata',[],'ydata',[],'linestyle','-','markersize', 6,...
      'erasemode', 'none', 'color','r');
	text(cos(tt12)*letdist1,sin(tt12)*letdist1,'X','color','k',...
       'fontsize',10)
	text(r1+cos(tt34)*letdist2,sin(tt34)*letdist2,'Y','color','k',...
       'fontsize',10)
	cir1=line('xdata',[],'ydata',[],'linestyle','-','markersize', 6,...
      'erasemode','none', 'color','r');
	cir2=line('xdata',[],'ydata',[],'linestyle','-','markersize', 6,...
      'erasemode','none', 'color','r');

% Define the axis location for the function generated.

	h2=axes('position', [0.6 .6 width height],'box', 'on','xcolor',...
	     'k','ycolor','k');
	set(gcf,'color', 'w')
	xlabel('input angle','color','k')
	ylabel('output angle','color', 'k')
	Displ=line('xdata',[], 'ydata', [], 'erasemode',...
      'none', 'color', 'k', 'linestyle', '-');
	dbead=line('xdata', [], 'ydata', [],'marker','o','markersize',6,...
      'erase','xor', 'color', 'k');
	precisionpt=line('xdata', [], 'ydata',[],'linestyle', 'none', ...
	  'marker','o','markersize', 6, 'erase', 'none','color','r');

% Define the axis location for the function error.

	h4=axes('position', [0.6 0.1 width height],'box', 'on','xcolor', 'k','ycolor',...
      'k');
	set(gcf,'color', 'w')
    xlabel('input angle','color','k')
	ylabel('function error (% of range)','color','k')
	error=line('xdata', [], 'ydata', [], 'erasemode',...
      'none', 'color', 'k', 'linestyle', '-');
	ebead=line('xdata', [], 'ydata', [],'marker','o','markersize',6,...
      'erase','xor','color','k');
	precpt=line('xdata', [], 'ydata', [],'linestyle', 'none','marker',...
	  'o','markersize',6,'erase', 'none','color', 'r');

	axes(h1);
	xmin=min([Bx, Bx2, Cx, r1, Cx2, min(bushx1), min(bushx2), arcx1, arcx2]) ;
	xmax=max([Bx, Bx2, Cx, r1, Cx2, max(bushx1), max(bushx2), arcx1, arcx2]) ;
	ymin=min([By, By2, Cy,  min(bushy1), min(bushy2), arcy1,arcy2]) ;
	ymax=max([By, By2, Cy,  max(bushy1), max(bushy2), arcy1,arcy2]) ;
	rangex=xmax-xmin;
	rangey=ymax-ymin;
	xmina=xmin-0.1*rangex;
	xmaxa=xmax+0.1*rangex;
	ymina=ymin-0.1*rangey;
	ymaxa=ymax+0.1*rangey;
	values=axisadjust(xmina, xmaxa, ymina, ymaxa, width, height);
	xmin=values(1);
	xmax=values(2);
	ymin=values(3);
	ymax=values(4);
	axis equal
	axis([xmin xmax ymin ymax]);
	set(arc1,'xdata',arcx1,'ydata',arcy1);
	set(arc2,'xdata',arcx2,'ydata',arcy2);
	for bill=1:length(tangl)
      tick(bill)=line('xdata',tickx(bill,:),'ydata',ticky(bill,:),...
      'linestyle', '-', 'markersize',6,'erasemode','none', 'color','r');
	end
   set(bush1,'xdata',bushx1,'ydata',bushy1);
   set(bush2,'xdata',bushx2,'ydata',bushy2);
   set(cir1,'xdata',circx1,'ydata',circy1);
   set(cir2,'xdata',circx2,'ydata',circy2);

% Set up vectors for cranks

   joint1=line('xdata', [],'ydata', [], 'marker', 'o','markersize', ...    
   6,'erasemode', 'xor', 'color', 'k');
   joint2=line('xdata', [], 'ydata', [], 'marker','o','markersize', ...    
   6, 'erasemode', 'xor', 'color','k');
   crank=line('xdata', [], 'ydata' ,[], 'linewidth' ,2, 'erasemode',...    
   'xor','color', 'k');
   coupler=line('xdata', [], 'ydata' ,[], 'linewidth' ,2, 'erasemode',...
   'xor','color', 'k');
   rocker=line('xdata', [], 'ydata' ,[], 'linewidth',2,...
   'erasemode', 'xor','color', 'k');
   opointer=line('xdata', [], 'ydata' ,[], 'linewidth',2,...
   'erasemode', 'xor','color', 'k');
   ipointer=line('xdata', [], 'ydata' ,[], 'linewidth',2,...
   'erasemode', 'xor','color', 'k');

% Check for the Grashof type

   r=[r1 r2 r3 r4];
   [rnew,Inew]=sort(r);
   gras=0;
   if (rnew(1)+rnew(4)<rnew(2)+rnew(3))    
      gras=1;
   end

% Set the axis limits for the rocker angle plot.

   axes(h2);
   xmin=min(Q22)-0.02*(max(Q22)-min(Q22));
   xmax=max(Q22)+0.02*(max(Q22)-min(Q22));
   ymin=min(Q44)-0.02*(max(Q44)-min(Q44));
   ymax=max(Q44)+0.02*(max(Q44)-min(Q44));
   axis([xmin xmax ymin ymax]);
   text(xmin+0.1*(xmax-xmin),ymax-0.1*(ymax-ymin),'Function Graph',...
      'color','k','fontsize',10);

% Plot the results.  Draw the fixed curves first.

   set(Displ,'xdata', Q22,'ydata', Q44);
   theta1p=theta1;
   theta2p=theta2;
   theta3p=theta3;
   if theta1 > 180;
      theta1p=theta1-360;
   end
   if theta2 > 180;
      theta2p=theta2-360;
   end
   if theta3 > 180;
      theta3p=theta3-360;
   end
   set(precisionpt,'xdata',[theta1p theta2p theta3p],'ydata',[phi1...
      phi2 phi3]);
   axes(h4);

% Set axis limits for the error plot

   ymin=min(err)-0.02*(max(err)-min(err));
   ymax=max(err)+0.02*(max(err)-min(err));
   axis([xmin xmax ymin ymax]);

% Plot the error curve.  Draw the fixed curves first.

   set(error,'xdata', Q22,'ydata', err);
   set(precpt,'xdata',[theta1p theta2p theta3p],'ydata',[0 0 0]);
   text(xmin+0.1*(xmax-xmin),ymax-0.1*(ymax-ymin),'Error Graph',...
    'color',[1,1,1],'fontsize',12);

% Animation linkage for its range of motion.

   ans='y';
   timesink=1;
   while ans=='y' 
   	for kk=1:1:tt
      for i=1:1:ipos+1
         set(joint1,'xdata', Bx(i),'ydata',By(i));
         set(joint2,'xdata', Cx(i), 'ydata',Cy(i));
         set(crank,'xdata',[0 Bx(i)],'ydata', [0 By(i)]);
         set(ipointer,'xdata',[0 Bx2(i)],'ydata', [0 By2(i)]);
         set(coupler,'xdata', [Bx(i) Cx(i)],'ydata', [By(i) Cy(i)]);
         set(rocker,'xdata', [r1 Cx(i)],'ydata', [0 Cy(i)]);
         set(opointer,'xdata',[r1 Cx2(i)],'ydata', [0 Cy2(i)]);
         set(coupler,'xdata', [Bx(i) Cx(i)],'ydata', [By(i) Cy(i)]); 
         set(dbead, 'xdata', Q22(i), 'ydata', Q44(i));
			set(ebead, 'xdata', Q22(i), 'ydata', err(i));
         drawnow;   % Flush the draw buffer     

% Do meaningless calculation to slow down the linkage

			for k=1:1:timesink
				zzz=log10(k);
			end
      end
	end

% Plot in final position without animation.

	i =ipos/4;
	set(joint1,'xdata', Bx(i), 'ydata',By(i));
	set(joint2,'xdata', Cx(i), 'ydata',Cy(i));
	set(crank,'xdata',[0 Bx2(i) Bx(i)],'ydata', [0 By2(i) By(i)]);
	set(ipointer,'xdata',[0 Bx2(i)],'ydata', [0 By2(i)]);
	set(coupler,'xdata', [Bx(i) Cx(i)],'ydata', [By(i) Cy(i)]);
	set(rocker,'xdata', [r1 Cx(i)],'ydata', [0 Cy(i)]);
	set(opointer,'xdata',[r1 Cx2(i)],'ydata', [0 Cy2(i)]);
	set(dbead, 'xdata', Q22(i), 'ydata', Q44(i));
	set(ebead, 'xdata', Q22(i), 'ydata', err(i));
	drawnow;

		
% Ask if animation should be repeated

	ans=input('Repeat animation? y/n [y]: ','s');
	if isempty(ans);ans='y';end
	if ans=='y'
		rep=input('Change animation speed? (+/-/0) [-]:','s');
		if isempty(rep);rep='-';end
		if rep=='+'; timesink=timesink/10; end
		if rep=='-'; timesink=timesink*10; end
		if timesink<1; timesink=1; end
	end
end
end
