% hr_slidercrank.m
% Matlab analysis of the coupler curves for a crank driven slider
% crank mechanism.

%Variables
%   r1,r11=horizontal distance to slider (cm)
%   r2=crank length (cm)
%   r3=coupler length (cm)
%   r4=slider line offset (cm)
%   r=[r2 r3 r4]
%   rtot=r2+r3+r4
%   r1d,r1dd=slider line velocity (cm/sec)
%   rd1,rd11=slider velocity (cm/sec)
%   cpr=coupler radius (cm) 
%   cpa=angle from the coulper line to coupler point (deg)
%   cpa=angle from the coulper line to coupler point (rad)
%   theta1=frame angle (deg)
%   Q11=angle between horizontal aznd slider line (deg)
%   Q2=crank angle (rad)
%   Q21=crank angle (deg)
%   Q22=crank angle (deg) (vector)
%   Q3,Q33=coupler angle (deg)
%   phi=angle between the force and the horizontal (deg)
%   phi=angle between the force and the horizontal (rad)
%   w11=angular velocity of the slider line (rad/sec)
%   w2=angular velocity of the crank (rad/sec)
%   w22=w2 (vector)
%   w33=angular velocity of the coupler (rad/sec)
%   w44=angular velocity of the rocker (rad/sec)
%   T=torque on crank (rocker) (N-cm)
%   P=force onm the slider (N)
%   sigma=assembly mode
%   flag=constant depicting extent of calculations to perform
%   tt=number of cycles to animate
%   dt=number of animation positions per revolution
%   itotal=number of animation positions
%   cycle=number of cycles as an integer
%   hcycle=number of half cycles as an integer
%   bushx,bushy=x,y coordinates of the bushing
%   pistx,pisty=x,y coordinates of the piston
%   framex,framey=x,y coordinates of the frame
%   cirx,ciry=x,y coordinates of the circle inside the bushing
%   Bx,By=x,y coordinates of the crank pin
%   Cx,Cy=x,y coordinates of the slider pin
%   Dx,Dy=x,y coordinates of the coupler pointer
%   d2r,r2d=conversion factors between radians and degrees
%   i=counting variable
%   ans=repitition variable
%   A,B,arg=algerbriac simplifying variables
%   Num=vertical coulper length (cm)
%   Den=horizontal coulper length (cm)
%   driver=constant depicting the driven portion of the linkage
%   prog=string variable representing the function to use and the variables to send
%   direc=crank return direction (top or bottom)
%   ratio=force:torque ratio - output/input
%   rg=grid row to animate
%   r33g=horizontal grid spacing
%   xg,yg=x,y coordinates of the grid points
%   rr,ppheta=polar coordinates of the grid points
%   thecount=loop starting variable
%   dc=number of loop iterations
%   dx=loop intervals
%   count=loop variable
%   aa=variable converting continuously increasing variable, count, to a variable increasing during each cycle
%   hc1,hc2=on/off variables
%   mx,my=x,y coordinates of the grid points
%	vbx=crank pin velocity in the x direction
%	vby=crank pin velocity in the y direction
%	vcx=rocker pin velocity in the x direction
%	vcy=rocker pin velocity in the y direction
%	nhgp=# of grid points in the x direction
%	nvgp=# of grid points in the y direction
%	gp=starting index of grid points to animate
%	hh=counter
%	speed=delay variable for animation speed
%	vm=velocity magnitude of selected grid point
%	nhgpoc=# of gridpoints along r3
%	tl=length along gridpoints horizontal
%	cxrc=distance to center of gridpoints
%	spacx=spacing between gridpoints
%	cxmin,cxmax,cymin,cymax=window limits based on grid points
%	xmin1,xmax1,ymin1=window limits based on grid points
%	xmin2,xmax2,ymin2=window limits based on linkage
%	xmin,xmax,ymin,ymax=window limits
%	a1=frame/crank joint x,y coordinates
%	b1=crank pin x,y coordinates
%	c1=piston pin x,y coordinates
%	d1=slider line offset/piston joint x,y coordinates
%	xg=x coordinates of grid points
%	ygy=y coordinates of grid points
%	yg=y coordinates of selected row of grid points
%	xp,yp=x,y coordinates of the mouse selected point
%	rr,ppheta=polar coordinates of the selected row of grid points
%	Qs=starting crank angle
%	mx,my=x,y coordinates of the selected grid points throughout animation
%	rep=string variable dictating a change in the spee of animation

%Graphics variables
%   xmin,xmax,ymin,ymax=axes limits
%   h1=handle on the first axes in the window (crank angle vs. rocker angle)
%   h2=handle on the second axes in the window (crank angle vs. rocker velocity)
%   h3=handle on the third axes in the window (crank angle vs. input torque)
%   h4=handle on the fourth axes in the window (linkage animation)
%   h5=handle on the small axes in the inital animation window (linkage animation)
%   h6=handle on the large axes in the inital animation window (linkage animation)   
%   displ=line representing the crank angle vs. rocker angle
%   vel=line representing the crank angle vs. rocker velocity
%   torque=line representing the crank angle vs. input torque
%   dbead=bead which follows the crank angle/rocker angle throughout animation
%   vbead=bead which follows the crank angle/rocker velocity throughout animation
%   tbead=bead which follows the crank angle/input torque throughout animation
%   busho=line representing the bushing at the crank hinge
%   pisto=line representing the piston
%   frame=line representing the frame
%   circo=line representing the circle inside the bushing at the crank hinge 
%   joint1=line representing the joint at the crank pin 
%   joint2=line representing the joint at the slider pin
%   crank=line representing the crank 
%   coupler=line representing the coupler
%   couplerptr=line representing the coupler point
%   couplerpt=line from the crank pin to the coupler point one
%	gpvel=line representing gridpoint velocity
%	gridpt=line representing gridpoints
%	gridline=line representing grid point paths
%	gridpoint=line representing gridpoints throughout animation
%	gline=line representing selected grid points
%	gpoint=line representing selected grid point

%main code
	
clf;
clear all;
ans='y';
disp('   ')
disp('         Slider-Crank Coupler Curve Program')
sigma=1;
flag=2;
driver='n';
fact=pi/180;

% Input the linkage variables

readmode=input('Enter 1 for file input and 2 for interactive input [1]: ');
if isempty(readmode); readmode=1; end
inputfile=input('Enter input file name (hrslidercrankio.dat): ', 's');
if isempty(inputfile); inputfile = 'hrslidercrankio.dat'; end
if readmode==1
	fid = fopen(inputfile);
end
if readmode==2
	tt=input('Enter number of cycles (rev) [3]: ');
	if isempty(tt);tt = 3;end
	r4=input('Enter slider-line offset [1]: ');
	if isempty(r4);r4 = 1.0;end
	r2=input('Enter the crank length [0.75]: ');
	if isempty(r2);r2 = 0.75;end
	r3=input('Enter the coupler length [2.75]: ');
	if isempty(r3);r3 = 2.75;end
	w2=input('Enter the angular velocity of crank(rad/sec) [5]: ');
	if isempty(w2);w2 = 5;end
	tl0=input('Enter total length of coupler grid [4*r3]: ');
	if isempty(tl0);tl0 = 4*r3;end
	tv0=input('Enter total height of coupler grid [2*r2]: ');
	if isempty(tv0);tv0 = 2*r3;end
	nhgp0=input('Enter number of coupler points in horizontal direction [20]: ');
	if isempty(nhgp0);nhgp0 = 20;end
	nvgp0=input('Enter number of coupler points in vertical direction [10]: ');
	if isempty(nvgp0);nvgp0 = 10;end
% save the data to the file fileinput.dat
	
	tempio(1)=tt;
	tempio(2)=r2;
	tempio(3)=r3;
	tempio(4)=r4;	
	tempio(5)=w2;
	tempio(6)=tl0;
	tempio(7)=tv0;
	tempio(8)=nhgp0;
	tempio(9)=nvgp0;
	tempiot=tempio(:);  % store the transpose of tempio for ease of reading
	fprintf(inputfile,'%f \n',tempiot)
end

% Read input data from the file hrslidercrankio.dat

if readmode==1	
	hrslidercrankio = fscanf(fid,'%f');
	tt=hrslidercrankio(1);
	r2=hrslidercrankio(2);
	r3=hrslidercrankio(3);
	r4=hrslidercrankio(4);
	w2=hrslidercrankio(5);
	tl0=hrslidercrankio(6);
	tv0=hrslidercrankio(7);
	nhgp0=hrslidercrankio(8);
	nvgp0=hrslidercrankio(9);
end
fclose('all');
r1=sqrt(((r2+r3).^2)-(r4.^2));
theta1r=(2*pi)-atan2(r4,r1);
theta1=(180/pi)*theta1r;
driver == 'c';
Q2=0;
speed=0;
ans2='y';
while ans2=='y'

%Set up the coupler-point grid

	nvgp=nvgp0;
	nhgp=nhgp0;
	nvgpoc=nvgp+1;
	tl=tl0;
	tv=tv0;
	cxrc=(1/2)*r3;
	spacx=(1/(nhgp-1))*tl;
	spacy=(1/(nvgp-1))*tv;
	cxmin=cxrc-(tl/2);
	cxmax=cxrc+(tl/2);
	cymin=-(nvgpoc/2)*spacy;
	cymax=(nvgpoc/2)*spacy;

% Locate the first position of the linkage

	a1=[0 0];
	b1=[r2 0];
	c1=[(r2+r3) 0];
	d1=[(r1*cos(theta1r)) (r1*sin(theta1r))];
	
% Find the limits for the plots

	xmin1=cxmin+r2;
	xmin2=c1(1)*.95;
	xmin3=d1(1)*.95;
	xmin=min([xmin1 xmin2 xmin3]);
	xmax1=cxmax+r2;
	xmax2=c1(1)*1.05;
	xmax3=d1(1)*1.05;
	xmax=max([xmax1 xmax2 xmax3]);
	ymin1=cymin;
	ymin2=c1(2)*.95;
	ymin3=d1(2)*.95;
	ymin=min([ymin1 ymin2 ymin3]);
	ymax=cymax;
	
% Define the piston data

	r=[r2 r3 r4];
	rtot=sum(r);
	lpist=rtot/8;
	hpist=rtot/16;
	coor=rect((lpist),(hpist),0,0,theta1,0);
	pistx=coor(:,1);
	pisty=coor(:,2);
	coor=bushing((rtot/70),0,0,20,0);
	bushx=coor(:,1);
	bushy=coor(:,2);
	coor=circle2((rtot/60),0,0,20);
	circx=coor(:,1);
	circy=coor(:,2);
	coor=frameline(((r2+r3)*1.05),(r2*cos((2*pi)-theta1r)),...
	     ((-r2*sin((2*pi)-theta1r))-(rtot/30)),20,theta1,1);
	framex=coor(:,1);
	framey=coor(:,2);	

% Compute the grid coordinates

	gxstart=cxmin-spacx;
	for i=1:nhgp
		xg(i)=b1(1)+gxstart+(i*spacx);
	end
	for i=1:nvgp
		ygy(i)=b1(2)+cymin+(i*spacy);
	end
	xmina=min([xmin d1(1) b1(1) c1(1) min(bushx) min(framex) min(xg)]);
	xmaxa=max([xmax d1(1) b1(1) c1(1) max(bushx) max(framex) max(xg)]);
	ymina=min([ymin d1(2) b1(2) c1(2) min(bushy) min(framey) min(ygy)]);
	ymaxa=max([ymax d1(2) b1(2) c1(2) max(bushy) max(framey) max(ygy)]);

% Define the region for the first plot

	width=0.9;
	height=0.9;
	h7=axes('position',[0.05 0.05 width height],'box','on');
	set(gcf,'color', 'w')
	rangex=xmaxa-xmina;
	rangey=ymaxa-ymina;
	xmin=xmina-0.05*rangex;
	xmax=xmaxa+0.05*rangex;
	ymin=ymina-0.05*rangey;
	ymax=ymaxa+0.05*rangey;
	values=axisadjust(xmin, xmax, ymin, ymax, width, height);
	xmin=values(1);
	xmax=values(2);
	ymin=values(3);
	ymax=values(4);
	axis equal
	axis([xmin xmax ymin ymax]);	
	for k=1:(nhgp*nvgp)
		gridpt(k)=line('xdata',[],'ydata',[],'marker','.','markersize', ...
			8,'erasemode','none','color','k');
	end
	joint1=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
		6, 'erasemode', 'xor', 'color', 'k');
	joint2=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
		6, 'erasemode', 'xor', 'color', 'k');
	crank=line('xdata', [], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
		'xor','color', 'k');
	rocker=line('xdata', [], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
		'xor','color', 'k');
	coupler=line('xdata', [], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
		'xor','color', 'k');
	coupline1=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
		'xor','color', 'k');
	coupline2=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
		'xor','color','k');
	pisto=line('xdata',[],'ydata',[],'linestyle','-','linewidth',2,...
	    'erasemode','xor','color','k');
	busho1=line('xdata',[],'ydata',[],'linewidth',1,'linestyle','-',...
	    'erasemode','none','color','r');
	circo1=line('xdata',[],'ydata',[],'linewidth',1,'linestyle','-',...
	    'erasemode','none','color','r');
	frame=line('xdata',[],'ydata',[],'linewidth',1,'linestyle','-',...
	    'erasemode','none','color','r');
	slline=line('xdata', [], 'ydata' ,[], 'linewidth' ,2, 'erasemode', ...
		'xor','color', 'k');

% Draw each of the grid points on the coupler.

	k=0;
	for i=1:nhgp
		for j=1:nvgp
			k=k+1;
			set(gridpt(k),'xdata',xg(i),'ydata',ygy(j));
		end
	end

% Draw the linkage in the first position.

	set(crank,'xdata',[0 b1(1)],'ydata',[0 b1(2)]);
	set(coupler,'xdata',[b1(1) c1(1)],'ydata',[b1(2) c1(2)]);
	set(slline,'xdata',[c1(1) d1(1)-(hpist/2)*sin(theta1*fact)], ...
		'ydata',[c1(2) d1(2)+(hpist/2)*cos(theta1*fact)]);
	set(pisto,'xdata',(pistx+d1(1)),'ydata',(pisty+d1(2)));
	set(joint1,'xdata', b1(1), 'ydata',b1(2));
	set(joint2,'xdata', c1(1), 'ydata',c1(2));
	set(busho1,'xdata',bushx,'ydata',bushy);
	set(circo1,'xdata',circx,'ydata',circy);
	set(frame,'xdata',framex,'ydata',framey);
	pause;
	
% Locate the row to use for coupler points

	disp ('Use mouse to indicate row to animate');
 	[xp,yp]=ginput(1);
	disp('  ')
	
% Identify the row which is closest to the y coordinate selected.

	for i=1:nvgp
		if ygy(i)>yp;break;end
	end
	if i==1
		yg1=ygy(i);
	else
		if (yp-ygy(i-1))<(ygy(i)-yp)
			yg1=ygy(i-1);
		else
			yg1=ygy(i);
		end
	end
	yg=yg1*ones(size(xg));
	xga=xg;
	xg=xg-r2;
	
% Locate each coupler point by rr and ppheta

	rr=sqrt((xg.^2)+(yg.^2));
	ppheta=atan2(yg,xg);  	 
	disp('I am working ...');
	gp=1;
	nhgpa=nhgp;
	nvgpa=nvgp;
  
% Loop to vary the linkage position

	dx=5;
	fc=360;
	dc=fc/dx;
	i=0;
	for count=0:dx:fc;
		i=i+1;
		Q2=count;
		para=sldcrkc(r2,r3,r4,Q2,w2,0,sigma,theta1,flag);
	
% Store position variables in matrices

		Q22(i)=para(6);
		Bx(i)=para(25);
		By(i)=para(26);
		Cx(i)=para(27);
		Cy(i)=para(28);
		Dx(i)=para(27)-(r4*sin((2*pi)-theta1r));
		Dy(i)=para(28)-(r4*cos((2*pi)-theta1r));
		for j=1:nhgp
			mx(j,i)=Bx(i)+rr(j)*cos((para(7)*pi/180)+ppheta(j));
			my(j,i)=By(i)+rr(j)*sin((para(7)*pi/180)+ppheta(j));
		end
		r11(i)=para(1);
		w22(i)=para(14);
		w33(i)=para(15);
		r1dd(i)=para(9);
		vbx(i)=para(29);
		vby(i)=para(30);
		vcx(i)=para(31);
		vcy(i)=para(32);	  
	end 
	clf;
	itotal=i;
	ans='y';
	hh=0;
	while hh<2

% Draw the linkage full size

		h6=axes('position',[.05 .05 .90 .90],'box','on');
		joint1=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
			6, 'erasemode', 'xor', 'color', 'k');
		joint2=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
			6, 'erasemode', 'xor', 'color', 'k');
		crank=line('xdata', [0 0], 'ydata' ,[], 'linewidth' ,2, 'erasemode', ...
			'xor','color', 'k');
		coupler=line('xdata', [], 'ydata' ,[], 'linewidth' ,2, 'erasemode', ...
			'xor','color', 'k');   
		pisto=line('xdata',[],'ydata',[],'linestyle','-','linewidth',3, ...
			'erasemode','xor','color','k');
		busho=line('xdata',[],'ydata',[],'linewidth',1,'linestyle','-', ...
			'erasemode','none','color','r');
		circo=line('xdata',[],'ydata',[],'linewidth',1,'linestyle','-', ...
			'erasemode','none','color','r');
		coupline1=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
			'xor','color', 'k');
		coupline2=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
			'xor','color', 'k');
		frame=line('xdata',[],'ydata',[],'linewidth',1,'linestyle','-', ...
			'erasemode','none','color','r');
		slline=line('xdata', [], 'ydata' ,[], 'linewidth' ,2, 'erasemode', ...
			'xor','color', 'k');
		for k=gp:(gp+nhgp-1)
			gridpoint(k)=line('xdata',[],'ydata',[],'marker','o','markersize',6,...
	  	 	 'erasemode','xor','color','k');
			for j=1:itotal
				gridline(k,j) =line('xdata',[],'ydata',[],'linewidth',1,'linestyle',...
			             '-','erasemode','none','color','r');
			end
		end
	
		xmina=min([min(min(mx(gp:(gp+nhgp-1),:))) min(Bx) ...
			min(Cx) min(Dx) min(bushx) min(framex)]);
		xmaxa=max([max(max(mx(gp:(gp+nhgp-1),:))) max(Bx) ...
			max(Cx) max(Dx) max(bushx) max(framex)]);
		ymina=min([min(min(my(gp:(gp+nhgp-1),:))) min(By) ...
			min(Cy) min(Dy) min(bushy) min(framey)]);
		ymaxa=max([max(max(my(gp:(gp+nhgp-1),:))) max(By) ...
		max(Cy) max(Dy) max(bushy) max(framey)]);
		rangex=xmaxa-xmina;
		rangey=ymaxa-ymina;
		xmin=xmina-0.05*rangex;
		xmax=xmaxa+0.05*rangex;
		ymin=ymina-0.05*rangey;
		ymax=ymaxa+0.05*rangey;
		values=axisadjust(xmin, xmax, ymin, ymax, width, height);
		xmin=values(1);
		xmax=values(2);
		ymin=values(3);
		ymax=values(4);
		axis equal
		axis([xmin xmax ymin ymax]);
		hh=hh+1;

% Write out the link lengths
		
		r1t=['r1 = ',num2str(r1)];
		r2t=['r2 = ',num2str(r2)];
		r3t=['r3 = ',num2str(r3)];
		r4t=['r4 = ',num2str(r4)];
		yyy1=ymax-0.1*(ymax-ymin);
		text(xmin+(xmax-xmin)*.1,yyy1,r1t)
		text(xmin+(xmax-xmin)*.3,yyy1,r2t)
		text(xmin+(xmax-xmin)*.5,yyy1,r3t)
		text(xmin+(xmax-xmin)*.7,yyy1,r4t) 
		
% Write the coupler point location if only one curve is displayed

		if hh==2
			r6=sqrt((Bx(1)-mx(gp,1)).^2+(By(1)-my(gp,1)).^2);
			beta=(180/pi)*atan2((my(gp,1)-By(1)),(mx(gp,1)-Bx(1)));
			r6t=['rC = ',num2str(r6)];
			betat=['beta = ',num2str(beta)];
			yyy2=yyy1-0.1*(ymax-ymin);
			text(xmin+(xmax-xmin)*.1,yyy2,r6t)
			text(xmin+(xmax-xmin)*.3,yyy2,betat)
		end

% Animate the linkage
		
		timesink=1;
		while ans=='y'
			spac=[.02 .3 .6 .8];
			xx=xmin+spac*(xmax-xmin);
			yy=ymin;

% Draw the linkage and coupler curves
	
			for i=1:1:itotal
				if i>1
			
% Draw the row of coupler curves for hh=0 and draw just one point if hh=1

					for k=gp:(gp+nhgp-1)
						midx(i)=mx(k,i-1)+(1/2)*(mx(k,i)-mx(k,i-1));
						midy(i)=my(k,i-1)+(1/2)*(my(k,i)-my(k,i-1));
						set(gridline(k,i),'xdata',[mx(k,i-1) midx(i)], 'ydata',[my(k,i-1) midy(i)]);
					end
				end
				set(pisto,'xdata',(pistx+Dx(i)),'ydata',(pisty+Dy(i)));
				set(busho,'xdata',bushx,'ydata',bushy);
				set(circo,'xdata',circx,'ydata',circy);
				set(frame,'xdata',framex,'ydata',framey);
				set(joint1,'xdata', Bx(i), 'ydata',By(i));
				set(joint2,'xdata', Cx(i), 'ydata',Cy(i));
				set(crank,'xdata',[0 Bx(i)],'ydata', [0 By(i)]);
				set(coupler,'xdata', [Bx(i) Cx(i)],'ydata', [By(i) Cy(i)]);
				set(slline,'xdata',[Cx(i) Dx(i)-(hpist/2)*sin(theta1*fact)], ...
					'ydata',[Cy(i) Dy(i)+(hpist/2)*cos(theta1*fact)]);
				for k=gp:(gp+nhgp-1)
					set(gridpoint(k),'xdata', mx(k,i), 'ydata',my(k,i));
				end

% Draw coupler lines if hh=2

				if hh==2
					set(coupline1, 'xdata', [Bx(i) mx(k,i)], 'ydata',[By(i) my(k,i)]);
					set(coupline2, 'xdata', [Cx(i) mx(k,i)], 'ydata',[Cy(i) my(k,i)]);
				end
				drawnow; %flush the draw buffer
				
% Do meaningless calculation to slow down the linkage

				for b=1:1:timesink
					zzz=log10(k);
				end
			end
			disp ('  ')
			ans=input('repeat animation? y/n [y]: ','s');
			if isempty(ans);ans='y';end
			if ans=='y'
				rep=input('Change animation speed? (+/-/0) [-]:','s');
				if isempty(rep);rep='-';end
				if rep=='+';timesink=timesink/10;end
		  	 	if rep=='-';timesink=timesink*10;end
				if timesink<1; timesink=1; end
			end
		end
		ans='y';
		if hh<2
			disp ('  ');
			fprintf('Use mouse to input point to animate')
			[xp,yp]=ginput(1);
			for i=1:nhgp
				if mx(i)>xp;break;end
			end
			if i==1
				mx1=mx(1);
				gp=1;
			 else
				if (xp-mx(i-1))<(mx(i)-xp) 
					mx1=mx(i-1);
					gp=i-1;
			else
				mx1=mx(i);
				gp=i;
			end
		end
		nhgp=1;
		clf
	end
end
clf
r6=sqrt((Bx(1)-mx(gp,1)).^2+(By(1)-my(gp,1)).^2);
beta=(180/pi)*atan2((my(gp,1)-By(1)),(mx(gp,1)-Bx(1)));
for i=1:itotal
	para=rbody1(r6,beta,Bx(i),By(i),Cx(i),Cy(i),vbx(i),vby(i),vcx(i),vcy(i),0,0,0,0,2);
	vmx=para(3);
	vmy=para(4);
	vm(i)=sqrt((vmx.^2)+(vmy.^2));
end 

% Define the axes for the first graph (input/output angle graph)
		
	width=0.38;
	height=0.35;
	h1=axes('position',[0.6 .55 width height],'box','on','xcolor','k','ycolor',...
      'k');   %axis location
	set(gcf,'color', 'w')
	if driver=='c'
		xlabel('crank angle','color', 'k')
		ylabel('slider distance ','color', 'k')
	else
		xlabel('slider distance','color', 'k')
		ylabel('crank angle ','color', 'k')
   end
   Displ=line('xdata', [], 'ydata', [], 'linestyle', '-', 'erasemode', 'none',...
      'color', 'r');
   dbead=line('xdata', [], 'ydata', [],'marker','o','markersize', 6, 'erase',...
      'xor');
	  
% Define the axes for the second graph (rocker velocity graph)
		
	h2=axes('position', [0.6 .1 width height],'box', 'on','xcolor', 'k','ycolor',...
      'k');
	set(gcf,'color', 'w')
   if driver=='c'
      xlabel('crank angle','color', 'k')
      ylabel('slider velocity','color', 'k')
   else
      xlabel('slider distance','color', 'k')
      ylabel('crank angular velocity','color', 'k')
   end
   Vel=line('xdata', [], 'ydata', [], 'erasemode', 'none',  ...
      'color', 'r', 'linestyle', '-');
   vbead=line('xdata', [], 'ydata', [],'marker','o','markersize', 6, ...
      'erase','xor');

 
% Define the axes for the third graph (crank angle graph)
		
	h3=axes('position', [0.1 .1 width height],'box', 'on','xcolor', 'k','ycolor',...
      'k');
	set(gcf,'color', 'w')
   if driver=='c'
      xlabel('crank angle','color', 'k')
      ylabel('gridpoint velocity','color', 'k')
   else
      xlabel('slider distance','color', 'k')
      ylabel('gridpoint velocity','color', 'k')
   end
   gpvel=line('xdata', [], 'ydata', [], 'erasemode','none', ...
      'color', 'r', 'linestyle', '-');
   tbead=line('xdata', [], 'ydata', [],'marker','o','markersize', 6, 'erase','xor');
   
 
% Define the axes for the fourth graph (linkage position)
		
	h4=axes('position', [0.1 .55 width height],'box', 'on', 'xcolor', 'k','ycolor',...
       'k');
	set(gcf,'color', 'w')

% Set up vectors needed to draw the linkage

	joint1=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
		6, 'erasemode', 'xor', 'color', 'k');
	joint2=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
		6, 'erasemode', 'xor', 'color', 'k');
	crank=line('xdata', [0 0], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
		'xor','color', 'k');
	coupler=line('xdata', [], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
		'xor','color', 'k');	   	      
	coupline1=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
		'xor','color','k');
	coupline2=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
		'xor','color', 'k');
	for k=gp:(gp+nhgp-1)
		for j=1:itotal
			gridline(k,j) =line('xdata',[],'ydata',[],'linewidth',1,'linestyle',...
			     '-','erasemode','none','color','r');
		end
	end
	gridpoint=line('xdata',[],'ydata',[],'marker','o','markersize',6,...
	        'erasemode','xor','color','k');
	busho=line('xdata', bushx, 'ydata',bushy, 'linestyle', '-',...
	        'markersize', 6,...
		'color', 'r');
	circo=line('xdata', circx, 'ydata',circy, 'linestyle', '-',...
	    'markersize', 6,'color', 'r');
	pisto=line('xdata',[],'ydata',[],'linestyle','-','linewidth',2,...
	     'erasemode','xor','color','k');
	frame=line('xdata',[],'ydata',[],'linewidth',1,'linestyle','-',...
	     'erasemode','none','color','r');
	slline=line('xdata', [], 'ydata' ,[], 'linewidth' ,2, 'erasemode', ...
		'xor','color', 'k');
	xmina=min([min(min(mx(k,:))) min(Bx) min(Cx)... 
		    min(bushx) min(bushy)]);
	xmaxa=max([max(max(mx(k,:))) max(Bx) max(Cx)... 
		     max(bushx) max(bushy)]);
	ymina=min([min(min(my(k,:))) min(By) min(Cy)...
		     min(bushy) min(bushy)]);
	ymaxa=max([max(max(my(k,:))) max(By) max(Cy)...
		     max(bushy) max(bushy)]);
	rangex=xmaxa-xmina;
	rangey=ymaxa-ymina;
	xmin=xmina-0.05*rangex;
	xmax=xmaxa+0.05*rangex;
	ymin=ymina-0.05*rangey;
	ymax=ymaxa+0.05*rangey;
	values=axisadjust(xmin, xmax, ymin, ymax, width, height);
	xmin=values(1);
	xmax=values(2);
	ymin=values(3);
	ymax=values(4);
	axis equal
	axis([xmin xmax ymin ymax]);

% Set the axis limits.

	axes(h3);
	axis([0 360 min(vm) max(vm)]);  %set axis limits for the torque plot
	axes(h1);
	axis([0 360 min(r11) max(r11)]);  %set axis limits for the slider length plot
	axes(h2);
	axis([0 360 min(r1dd) max(r1dd)]);  %set axis limits for the velocity plot

% Plot the fixed curves first

	set(gpvel,'xdata', Q22,'ydata', vm);
	set(Displ,'xdata', Q22,'ydata', r11);    
	set(Vel,'xdata', Q22,'ydata', r1dd);
 	set(busho,'xdata',bushx,'ydata',bushy);
	set(circo,'xdata',circx,'ydata',circy);
	set(frame,'xdata',framex,'ydata',framey);
 	for i=1:1:itotal 
		if i>1
			set(gridline(k,i),'xdata',[mx(k,i-1) midx(i)], 'ydata',[my(k,i-1) midy(i)]); 
		end
	end
	
% Animate the results as long as ans = 'y'

	ans='y';
	while ans=='y'
		for mt=1:1:tt
			for i=1:1:itotal 
				set(pisto,'xdata',(pistx+Dx(i)),'ydata',(pisty+Dy(i)));
				set(joint1,'xdata', Bx(i), 'ydata',By(i));
				set(joint2,'xdata', Cx(i), 'ydata',Cy(i));
				set(crank,'xdata',[0 Bx(i)],'ydata', [0 By(i)]);
				set(slline,'xdata',[Cx(i) Dx(i)-(hpist/2)*sin(theta1*fact)], ...
					'ydata',[Cy(i) Dy(i)+(hpist/2)*cos(theta1*fact)]);
				set(coupline1, 'xdata', [Bx(i) mx(k,i)], 'ydata',[By(i) my(k,i)]);
				set(coupline2, 'xdata', [Cx(i) mx(k,i)], 'ydata',[Cy(i) my(k,i)]);			
				set(coupler,'xdata', [Bx(i) Cx(i)],'ydata', [By(i) Cy(i)]);
				set(gridpoint,'xdata', mx(k,i), 'ydata',my(k,i));
				set(tbead, 'xdata', Q22(i), 'ydata', vm(i));
				set(dbead, 'xdata', Q22(i), 'ydata', r11(i));
				set(vbead, 'xdata', Q22(i), 'ydata', r1dd(i));
				drawnow;   %flush the draw buffer
						
% Do meaningless calculation to slow down the linkage

				for ktime=1:1:timesink
					zzz=log10(ktime);
				end 
			end
		end

% Plot figures in final position.
			
		i = 6;

% Plot position first
			
		set(pisto,'xdata',(pistx+Dx(i)),'ydata',(pisty+Dy(i)));
		set(busho,'xdata',bushx,'ydata',bushy);
		set(circo,'xdata',circx,'ydata',circy);
		set(frame,'xdata',framex,'ydata',framey);
		set(joint1,'xdata', Bx(i), 'ydata',By(i));
		set(joint2,'xdata', Cx(i), 'ydata',Cy(i));
		set(crank,'xdata',[0 Bx(i)],'ydata', [0 By(i)]);
		set(coupline1, 'xdata', [Bx(i) mx(k,i)], 'ydata',[By(i) my(k,i)]);
		set(coupline2, 'xdata', [Cx(i) mx(k,i)], 'ydata',[Cy(i) my(k,i)]);			
		set(coupler,'xdata', [Bx(i) Cx(i)],'ydata', [By(i) Cy(i)]);
		set(slline,'xdata',[Cx(i) Dx(i)-(hpist/2)*sin(theta1*fact)], ...
					'ydata',[Cy(i) Dy(i)+(hpist/2)*cos(theta1*fact)]);
		set(gridpoint,'xdata', mx(k,i), 'ydata',my(k,i));
		
% Plot the beads

		set(tbead, 'xdata', Q22(i), 'ydata', vm(i));
		set(dbead, 'xdata', Q22(i), 'ydata', r11(i));
		set(vbead, 'xdata', Q22(i), 'ydata', r1dd(i));
		
%flush the draw buffer

		drawnow; 
 
 % Ask if the animation should be repeated
 
		ans=input('Repeat animation? y/n [y]: ', 's');
		if isempty(ans);ans='y';end
		if ans=='y'
			rep=input('Change animation speed? (+/-/0) [-]:','s');
			if isempty(rep);rep='-';end
			if rep=='+'; timesink=timesink/10; end
			if rep=='-'; timesink=timesink*10; end
			if timesink<1; timesink=1; end
		end
	end
	ans2=input('Repeat animation for a new set of grid points? y/n [y]: ','s');
	if isempty(ans2);ans2='y';end
	if ans2=='y'; clf; end
end
