%MATLAB file for showing Euler-Savary equation.

%Some of the important variables used are:

%   Ax=X coordinate of point
%   Ay=Y coordinate of point
%   Ix=X coordinate of instant center
%   Iy=Y coordinate of instant center
%   Astarx=X coordinate of curvature of point path of A.
%   Astary=Y coordinate of curvature of point path of A.
%	Jx = x coordinate of J
% 	Jy = y coordinate of J
%	JAx = x coordinate of JA
% 	JAy = y coordinate of JA
%	R = radius of inflection circle
%
% This program uses the following m.files.  These must be located in the same directory
% or the path to the routines must be clearly defined:

%	centerpoint.m - Routine for finding center point given circle point

clf;
clear all;
ans = 'y';
disp('   ')
disp('      Inflection Circle Test Program')

%Input the linkage variables

readmode=input('Enter 1 for file input and 2 for interactive input [1]: ');
if isempty(readmode); readmode=1; end
inputfile=input('Enter input file name (inflectioncirio.dat): ', 's');
if isempty(inputfile); inputfile = 'inflectioncirio.dat'; end
if readmode==1
	fid = fopen(inputfile);
end
if readmode==2
	Cx =input('Enter x coordinate of center of inflection circle: ');
	if isempty(Cx)
		Cx = 4.3301; 
	end

	Cy =input('Enter y coordinate of center of inflection circle: ');
	if isempty(Cy)
		Cy = -1.5; 
	end

	theta=input('Enter arc from inflection circle for indicating path (deg): ');
	if isempty(theta)
		theta = 60;
	end

	Ix =input('Enter x coordinate of instant center: ');
	if isempty(Ix)
		Ix = 3.4641; 
	end

	Iy =input('Enter y coordinate of instant center: ');
	if isempty(Iy)
		Iy = 0; 
	end

	sizefact=input('Enter size factor for plot: ');
	if isempty(sizefact)
		sizefact = 1; 
	end
	
% save the data to the file fileinput.dat
	
	tempio(1)=Cx;
	tempio(2)=Cy;
	tempio(3)=theta;	
	tempio(4)=Ix;
	tempio(5)=Iy;
	tempio(6)=sizefact;
	tempiot=tempio(:);  % store the transpose of tempio for ease of reading
	fprintf(inputfile,'%f \n',tempiot)
end

% Read input data from the file inflectioncirio.dat

if readmode==1	
	inflectioncirio = fscanf(fid,'%f');
	Cx=inflectioncirio(1);
	Cy=inflectioncirio(2);
	theta=inflectioncirio(3);
	Ix=inflectioncirio(4);
	Iy=inflectioncirio(5);
	sizefact=inflectioncirio(6);
end
fclose('all');

% Compute radius of inflection circle and location of J.

CdIx=Cx-Ix;
CdIy=Cy-Iy;
CdI=sqrt(CdIx^2+CdIy^2);
angle=atan2(CdIy,CdIx);
R=abs(CdI);
D=2*R;
Jx=Ix+D*cos(angle);
Jy=Iy+D*sin(angle);

% Compute points on the inflection circle.

dalpha=2*pi/30;
for j=1:1:31
	alpha=(j-1)*dalpha;
	Icirx(j)=Cx+(D/2)*cos(alpha);
	Iciry(j)=Cy+(D/2)*sin(alpha);
end

% Define the plots

width=0.95;
height=0.95;
h=axes('position', [.05 .05 width height],'box', 'on', 'xcolor', 'k',...
         'ycolor','k');
Icircle=line('xdata', [], 'ydata' ,[], 'linewidth',1,'erasemode',...
               'normal','color', 'r');
Icpoint=line('xdata', [], 'ydata',[], 'marker', '+', 'markersize', 6,...
        'erasemode', 'normal','color','r');
Jpoint=line('xdata', [], 'ydata',[], 'marker', '+', 'markersize', 10,...
        'erasemode', 'normal','color', 'r');
Poletangent=line('xdata', [], 'ydata' ,[], 'linewidth',1,'erasemode',...
            'normal','color', 'r');
for i=1:1:10
	Aline(i)=line('xdata', [], 'ydata', [],'markersize', ...
       10,'erasemode', 'none', 'color', 'k');
	Aarc(i)=line('xdata', [], 'ydata', [],'markersize', ...
       10,'erasemode', 'none', 'color', 'k');
	Apoint(i)=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
       6, 'erasemode', 'none', 'color', 'k');
	Astarpt(i)=line('xdata', [], 'ydata', [], 'marker', '+','markersize', ...
       10, 'erasemode', 'none', 'color', 'r');
	JApoint(i)=line('xdata', [], 'ydata', [], 'marker', '+','markersize', ...
       10, 'erasemode', 'none', 'color','k');
end

% Draw inflecton circle.

fact=pi/180;
naxx=max(Icirx);
ninx=min(Icirx);
naxy=max(Iciry);
niny=min(Iciry);
dx=(naxx-ninx);
dy=(naxy-niny);
xmaxa=naxx+sizefact*dx;
xmina=ninx-sizefact*dx;
ymaxa=naxy+sizefact*dy;
ymina=niny-sizefact*dy;
rangex=xmaxa-xmina;
rangey=ymaxa-ymina;
xmin=xmina-0.05*rangex;
xmax=xmaxa+0.05*rangex;
ymin=ymina-0.05*rangey;
ymax=ymaxa+0.05*rangey;
values=axisadjust(xmin, xmax, ymin, ymax, width, height);
xmin=values(1);
xmax=values(2);
ymin=values(3);
ymax=values(4);
axis equal
axis([xmin xmax ymin ymax]);
set(Icircle, 'xdata', Icirx, 'ydata', Iciry);
set(Jpoint, 'xdata', Jx, 'ydata', Jy);
set(Icpoint, 'xdata', Ix, 'ydata', Iy);
text(Ix+0.1*dx,Iy+0.1*dy,'IC','color', 'r');
text(Jx+0.1*dx,Jy-0.1*dy,'J','color', 'r');

% Plot the instant center tangent

Ptanx1=Ix+D*sin(angle);
Ptanx2=Ix-D*sin(angle);
Ptany1=Iy-D*cos(angle);
Ptany2=Iy+D*cos(angle);
set(Poletangent, 'xdata',[Ptanx1, Ptanx2], 'ydata', [Ptany1, Ptany2]);
text(Ptanx2-0.1*dx,Ptany2-0.1*dy,'IC Tangent');

% While loop for point input.  Start by checking if the input
% is to be through the mouse or keyboard.
	
disp('   ')
disp('Possible modes of inputting data: ')
disp('  1 - mouse ')
disp('  2 - keyboard ')
disp('   ')
typei=input('Designate mode of input [1] ');
if isempty(typei)
	typei = 1;
end

% Input the point coordinates

ans2='y';
i=0;
while ans2=='y'
	i=i+1;
	if typei == 1
		disp('   ')
		disp('  Use mouse to locate point')
		disp('   ')
		[Ax,Ay]=ginput(1);
	end

% Input point data using the keyboard	

	if typei == 2
		Ax=input(' Input x component of point ');
		if isempty(Ax); Ax = 1.26;end				
		Ay=input(' Input y component of point ');
		if isempty(Ay); Ay = 1.99;end
	end
		
% Find the center of curvature.

	Astarx=0;
	Astary=0;
	gamma=60;
	ptflag=0;
	icflag=0;
	coords= inflection3(Ax,Ay,Ix,Iy,Astarx,Astary,Cx,Cy,Jx,Jy,ptflag,icflag);
	JAx=coords(1);
	JAy=coords(2);
	gamma=coords(5);
	Astarx=coords(11);
	Astary=coords(12);
	
% Define arc with radius AA* centered at A*

r=sqrt((Astarx-Ax)^2+(Astary-Ay)^2);
astart=atan2((Ay-Astary),(Ax-Astarx));
thetarad=theta*pi/180;

% Determine angle corresponding to arc length of theta for inflection circle.

angle=thetarad*D/(2*r);
dalpha=angle/10;
alpha=atan2((Ay-Astary),(Ax-Astarx))-angle/2-dalpha;
for j=1:1:10
	alpha=alpha+dalpha;
	Aarcx(j)=Astarx+r*cos(alpha);
	Aarcy(j)=Astary+r*sin(alpha);
end

% Plot A, Astar, and JA.

	set(Apoint(i), 'xdata',Ax, 'ydata', Ay);
	text(Ax-0.1*dx,Ay-0.1*dy,'A', 'color', 'k');
	set(Astarpt(i), 'xdata',Astarx, 'ydata', Astary);
	text(Astarx-0.1*dx,Astary-0.1*dy,'A*','color', 'r');
	set(JApoint(i), 'xdata',JAx, 'ydata', JAy);
	set(Aline(i), 'xdata',[Ax, Astarx, JAx,Ix], 'ydata', [Ay, Astary, JAy, Iy]);
	set(Aarc(i), 'xdata',Aarcx, 'ydata', Aarcy);

% Check to see if the user wants to reinput the point

	ans2=input('reenter point? y/n [y]: ', 's');
	if isempty(ans2);
		ans2='y';
	end	
	if i>9; ans2='n'; end
end
