function [r,R,ra,mode,r20,r40,thetal]=links(theta,phi,lknown,rknown,thetalim)

%Function file that calculates the other link lengths and linkage mode

%Variables
%   lknown = link with the known length
%   rknown = known link length (cm)
%   r1=frame length (cm)
%   r2=crank length (cm)
%   r3=coupler length (cm)
%   r4=rocker length (cm)
%   r = scaled link lengths [r1 r2 r3 r4]
%   R = scaled link lengths with signs preserved (cm)
%	ra = unscaled link lengths with signs preserved (cm)
%   r20=length and direction of the crank
%   r40=length and direction of the rocker
%   thetal=crank angle limits (deg)
%   thetas=initial crank angle (deg)
%   thetaf=final crank angle (deg)
%   thetalim=limiting crank angle (rad)
%   theta1r,theta2r,theta3r=crank angles at the precision points (rad)
%   theta1l,theta2l,theta3l=crank angle at the precision points accounting for
%       crank direction (rad)
%   theta=[theta1r theta2r theta3r]
%   phi1r,phi2r,phi3r=rocker angles at the precision points (rad)
%   phi1l,phi2l,phi3l=rocker angle at the precision points accounting for
%      crank direction (rad)
%   d=[C1 C2 C3]
%   x,a,C1,C2,C3,A,B,C,arg=algerbriac simplifying variables 
%   mode=assembly mode

%Program
r1=1;
thetasl=(thetalim(1))*(180/pi);
thetafl=(thetalim(2))*(180/pi);
theta1r=theta(1);
theta2r=theta(2);
theta3r=theta(3);
phi1r=phi(1);
phi2r=phi(2);
phi3r=phi(3);
C1=cos(theta1r-phi1r);
C2=cos(theta2r-phi2r);
C3=cos(theta3r-phi3r);
d=[C1; C2; C3];
a=[1 cos(phi1r) -cos(theta1r);1 cos(phi2r) -cos(theta2r);1 cos(phi3r) -cos(theta3r)];
x=a\d;
r2=r1/x(2);
r4=r1/x(3);
r3=sqrt(-x(1)*2*r2*r4+r1*r1+r2*r2+r4*r4);
ra=[r1 r2 r3 r4];

% Determine the linkage scale factor

scale = rknown/ra(lknown);
R=ra*scale;

% Determine the linkage mode by checking the first position.

theta1l=theta1r;
theta2l=theta2r;
theta3l=theta3r;
phi1l=phi1r;
phi2l=phi2r;
phi3l=phi3r;
if r2<0;
   theta1l=theta1r+pi;
   theta2l=theta2r+pi;
   theta3l=theta3r+pi;
   thetasl=thetasl+180;
   thetafl=thetafl+180;
end;
if r4<0;
   phi1l=phi1r+pi;
   phi2l=phi2r+pi;
   phi3l=phi3r+pi;
end;
Q2=theta1l;
r40=r4*scale;
r20=r2*scale;
r2=abs(r2);
r4=abs(r4);
A = r2^2 + r1^2 - r3^2 +r4^2- 2*r1*r2*cos(Q2);
B = -2*r2*r4*sin(Q2);
C = -2*r2*r4*cos(Q2) + 2*r1*r4;
arg=B^2 - A^2 +C^2;
if arg >=0 & (A-C) ~=0
   Q41 = 2 * atan((-B+arg^.5) / (A-C));
   if Q41 < 0 
      Q41=Q41+2*pi;
   end  
   Q42 = 2 * atan((-B-arg^.5) / (A-C));
   if Q42 < 0 
      Q42=Q42+2*pi;
   end
end
mode=1;
if (abs(Q42-phi1l)<abs(Q41-phi1l)); mode=-1; end;
r=[r1 r2 r3 r4]*scale;
thetal=[thetasl thetafl];
