% prob_6p8.m 
%
% This program determines the cam profile for a translating roller
% follower.  

% Variables for calculation 
%   rb=base circle radius
%   r0=radius of cam follower roller or cylindrical face
%   d = follower offset
%   xc=x coordinate of cam point
%   yc=y coordinate of cam point
%   xf=x coordinate of follower center relative to cam
%   yf=y coordinate of follower center relative to cam
%   rise = maximum follower displacement

%   Graphics Variables

%   h1=handle on the first axes in the window (cam animation)
%   h2=handle on the second axes in the window (displacement diagram)
%   h3=handle on the fourth axes in the window (pressure angle)
%   Displ=line representing the follower displacement
%   dbead=bead which follows the displacement throughout the animation
%   Pangle=line representing the pressure angle
%   pabead=bead which follows pressure angle throughout the animation
%   stem=line for follower stem
%   roller=line for follower roller
%   cam=line for cam
%   baset=line for top of slider guide
%   baseb=line for bottom of slider guide
%   pin=line for the cam axis
%   bush=line representing the cam bushing
%   xmin, xmax= x limits for the axes
%   ymin, ymax= y limits for the axes

% program 

clear all;
ansi='y';
ans='y';
disp('   ')
disp('      Cam Synthesis for Axial Roller Follower')
disp('  ')

% Input values for cam variables 

while ansi=='y'
	rb=input('Enter base circle radius [2]:  ');
	if isempty(rb); rb=2; end
	rise=input('Enter follower rise [2]:  ');
	if isempty(rise); rise=2; end
	direction=input('Enter cam rotation direction (CW(-), CCW(+)) [-]: ','s'); 
	if isempty(direction); direction='-';end
	ainc=input('Enter cam angle increment for design (deg) [10]:  '); 
	if isempty(ainc); ainc=10; end
	
	ansi=input('Reinter input variables? y/n [n]: ', 's');
	if isempty(ansi);
		ansi='n';
	end
end

% Print heading for input information

disp('   ')
fprintf('    Input Variables ') 

disp('   ')
fprintf('  Base Radius    rise') 

% Print the input values.

disp('   ')
fprintf('%10.3f %15.3f \n',rb,  rise)
disp('   ')

fact=pi/180;

% Compute the displacement of the roller follower.  The variable
% dtheta will change the resolution of the cam.  Make it smaller for
% accurate results.
		
dtheta=ainc;
if direction=='+'
	dtheta=-ainc;
end
temp=-dtheta;
n=abs(360/dtheta);

% Compute the follower displacement and follower center coordinates 
% relative to cam.

for j=1:1:n
	temp=temp+dtheta;
	theta(j)=temp;
	camangle(j)=abs(theta(j));
	[coords]=follower(camangle(j),rise);
	f(j)=coords(1);
	fp(j)=coords(2);
	fpp(j)=coords(3);
	t(j)=fp(j);
	rbmin(j)=-f(j)-fpp(j);
end

% Print a file of the cam coordinates and minimum base circle radius

disp('   ')
fprintf('                Cam coordinates') 
disp('   ')
fprintf('   cam angle         f         fp          fpp     rbmin        t') 
disp('   ')
for i=1:1:n
	fprintf('%12.0f %10.3f %10.3f %10.3f %10.3f %10.3f\n',theta(i),f(i),fp(i),fpp(i),rbmin(i),t(i))
end
