% Matlab program to show motion of rack relative to gear blank
%
%Some of the important variables used are:

%Dp      = Diametral pitch
%ar      = Addendum constant for rack
%br      = Dedendum constant for rack
%phi     = pressure angle in degrees
%rt      = tip radius of rack
%rf      = fillet radius of rack
%r       = pitch radius of gear
%ag      = Addendum constant for gear
%N       = Number of gear teeth

clf;
clear all;
ans='y';
disp('   ')
disp('         Rack Motion Program')
disp('   ')
height=0.8;
width=0.8;
h=axes('position',[.05 .05 width height],'box','on','xcolor','k','ycolor','k');
set(gcf,'color', 'w')
readmode=input('Enter 1 for file input and 2 for interactive input [1]: ');
if isempty(readmode); readmode=1; end
inputfile=input('Enter input file name (rackmotion.dat): ', 's');
if isempty(inputfile); inputfile = 'rackmotion.dat'; end
if readmode==1
	fid = fopen(inputfile);
end
if readmode==2

	Dp=input('Enter value of diametral pitch [10]: ');
	if isempty(Dp)
		Dp = 10; 
	end

	ar=input('Enter value of addendum constant for rack [1.25]: ');
	if isempty(ar)
		ar = 1.25;
	end

	br=input('Enter value of dedendum constant for rack [1.1]: ');
	if isempty(br)
		br = 1.1;
	end

	phi=input('Enter value of pressure angle in degrees [20]: ');
	if isempty(phi)
		phi = 20;
	end

	rt=input('Enter radius of tip of rack tooth [0.02]: ');
	if isempty(rt)
		rt = 0.02;
	end

	rf=input('Enter radius of fillet of rack tooth [0.04]: ');
	if isempty(rf)
		rf = 0.04;
	end

	N=input('Enter number of teeth on gear [10]: ');
	if isempty(N)
		N = 10; 
	end

	ag=input('Enter value of addendum constant for gear [1.0]: ');
	if isempty(ag)
		ag = 1;
	end
	
	npos=input('Enter number of rack positions [15]: ');
	if isempty(npos)
		npos = 15;
	end

% save the data to the file rackmotionio.dat
	
	temp1(1)=Dp;
	temp1(2)=ar;
	temp1(3)=br;
	temp1(4)=phi;
	temp1(5)=rt;
	temp1(6)=rf;
	temp1(7)=N; 
	temp1(8)=ag; 
	temp1(9)=npos; 
	temp1t=temp1(:);  % store the transpose of temp1 for ease of reading	
	fprintf(inputfile,'%f \n',temp1t)
end
	
% Read input data from the file geardrio.dat

if readmode==1	
	geardrio = fscanf(fid,'%f');
	Dp=geardrio(1);
	ar=geardrio(2);
	br=geardrio(3);
	phi=geardrio(4);
	rt=geardrio(5);
	rf=geardrio(6);
	N=geardrio(7);
	ag=geardrio(8);
	npos=geardrio(9);
end
	
% Compute basic parameter values.
	
A=ar/Dp;
B=br/Dp;
p=pi/Dp;
r=p*N/(pi*2);
theta=pi/N;
ro=r+ag/Dp;
r2d=180/(4*atan(1.0));
d2r=1/r2d;
phir=phi*d2r;
gamma=pi/2-phir;
lt=pi/(2*Dp)-2*A*tan(phir)-2*rt*tan(gamma/2);
lb=pi/(2*Dp)-2*B*tan(phir)-2*rf*tan(gamma/2);

% Check for negative values for lt and lb.  If either is negative,
% set the value to zero and compute the corresponding radius.

if lt < 0
	lt=0;
	rt=(pi/(2*Dp)-2*A*tan(phir))/(2*tan(gamma/2));
end

if lb < 0
	lb=0;
	rf=(pi/(2*Dp)-2*B*tan(phir))/(2*tan(gamma/2));
end

ptregion1 = 2;
ptregion2 = 15;
ptregion3 = 2;
ptregion4 = 15;
ptregion5 = 2;
		
% Determine a set of points in region I
	
beta=0.0;
i=0;
dbeta=1/ptregion1;
for j=1:1:ptregion1
	i=i+1;	
	beta=beta+dbeta;
	rackx(i)=beta*lt/2;
	racky(i)=A;
end
	
% Determine a set of points for region II

beta = 0.0;
dbeta=1/ptregion2;
for j=1:1:ptregion2
	i=i+1;
	beta=beta+dbeta;
	rackx(i)=lt/2+rt*sin(beta*gamma);
	racky(i)=A-rt*(1-cos(beta*gamma));
end
	
% Determine a set of points for region III

beta = 0.0;
dbeta=1/ptregion3;
for j=1:1:ptregion3
	i=i+1;
	beta=beta+dbeta;
	sgamma=sin(gamma);
	cgamma=cos(gamma);
	rackx(i)=(1-beta)*(lt/2+rt*sgamma)+beta*(pi/(2*Dp)-lb/2-rf*sgamma);
	racky(i)=(1-beta)*(A-rt*(1-cgamma))+beta*(-B+rf*(1-cgamma));
end

% Determine a set of points for region IV

beta = 0.0;
dbeta=1/ptregion4;
for j=1:1:ptregion4
	i=i+1;
	beta=beta+dbeta;
	somb=sin((1-beta)*gamma);
	comb=cos((1-beta)*gamma);
	rackx(i)=pi/(2*Dp)-lb/2-rf*somb;
	racky(i)=-B+rf*(1-comb);
end

% Determine a set of points for region V

beta = 0.0;
dbeta=1/ptregion5;
for j=1:1:ptregion5
	i=i+1;
	beta=beta+dbeta;
	somb=sin((1-beta)*gamma);
	comb=cos((1-beta)*gamma);
	rackx(i)=pi/(2*Dp)-lb/2*(1-beta);
	racky(i)=-B;
end
itotal = i;
	
% Reflect the points and translate them to get the other side of the rack gap.

xmax=max(rackx);
xmin=min(rackx);
range=pi/Dp;
j=itotal;
for i=1:1:itotal-1
	j=j+1;
	rackx(j)=-rackx(itotal-i)+range;
	racky(j)=racky(itotal-i);
end	
itotal=j;
	
% Draw the rack.  Start by defining the plots

	rackline=line('xdata', [], 'ydata' ,[], 'linewidth',1,'erasemode', 'xor',...
	              'color', [1,0,0]);
	rackpitchline=line('xdata', [], 'ydata' ,[], 'linewidth',0.4,'erasemode',...
	              'xor','color', [1,1,1], 'linestyle', '-.');
	xmax=max(rackx);
	xmin=min(rackx);
	ymax=max(-racky);
	ymin=min(-racky);
	xrange=xmax-xmin;
	yrange=ymax-ymin;
	xmin=xmin-0.05*xrange;
	xmax=xmax+0.05*xrange; 
	ymin=ymin-0.05*yrange; 
	ymax=ymax+0.05*yrange;
	values=axisadjust(xmin, xmax, ymin, ymax, width, height);
	xmin=values(1);
	xmax=values(2);
	ymin=values(3);
	ymax=values(4);
	axis equal
	axis([xmin xmax ymin ymax]);

% Plot the positions

	set(rackline, 'xdata', rackx, 'ydata', -racky);
	set(rackpitchline, 'xdata',[xmin, xmax], 'ydata', [0,0]);
	text(xmax-0.15*xrange, 0.01,'Pitch line');
	title('Hob tooth gap');
	pause;

% Draw the rack as it rolls about the gear through an angle theta.

dth=4*theta/npos;
th=-theta-dth/1.5;
beta=-theta;
for k=1:1:npos
	th=th+dth;
	cth=cos(th);
	sth=sin(th);
	for i=1:1:itotal
		tempx=-cth*(rackx(i)-r*th)+sth*(racky(i)-r);
		tempy=-sth*(rackx(i)-r*th)-cth*(racky(i)-r);

% Rotate the coordinate system by -pi/N so that the y axis is along the 
% centerline of the gear tooth instead of the centerline of the gap.

		racktx(k,i)=tempx*cos(beta)-tempy*sin(beta);
		rackty(k,i)=tempx*sin(beta)+tempy*cos(beta);
	end
end

% Define the pitch circle and blank circle arcs

maxang=theta;
minang=-theta;
dk=(maxang-minang)/20;
i=0;
for k=minang:dk:maxang
	i=i+1;
	plx(i)=r*sin(k);
	ply(i)=r*cos(k);
	blx(i)=ro*sin(k);
	bly(i)=ro*cos(k);
end	

% Draw the hob in different positions

clf;
axes('position', [.08 .05 .8 .8],'box', 'on', 'xcolor', [1,1,1],'ycolor',...
       [1,1,1]);
for k=1:1:npos
	hobline(k)=line('xdata', [], 'ydata' ,[], 'linewidth',1,'erasemode',...
         'none','color', [1,0,0]);
end
gearblankline=line('xdata', [], 'ydata' ,[], 'linewidth',0.4,...
         'erasemode', 'xor','color', [0,1,0], 'linestyle', '-.');
gearpitchline=line('xdata', [], 'ydata' ,[], 'linewidth',0.4,...
         'erasemode', 'xor','color', [0,1,0], 'linestyle', '-.');

for k=1:1:npos
	xmax1(k)=max(racktx(k,:));
	ymax1(k)=max(rackty(k,:));
	xmin1(k)=min(racktx(k,:));
	ymin1(k)=min(rackty(k,:));
end
xmax=max(xmax1);
ymax=max(ymax1);
xmin=min(xmin1);
ymin=min(ymin1);
xrange=xmax-xmin;
yrange=ymax-ymin;
xmin=xmin-0.05*xrange;
xmax=xmax+0.05*xrange; 
ymin=ymin-0.05*yrange; 
ymax=ymax+0.05*yrange;
values=axisadjust(xmin, xmax, ymin, ymax, width, height);
xmin=values(1);
xmax=values(2);
ymin=values(3);
ymax=values(4);
axis equal
axis([xmin xmax ymin ymax]);

% Plot the pitch circle and blank circle

set(gearblankline, 'xdata',blx, 'ydata', bly);
set(gearpitchline, 'xdata',plx, 'ydata', ply);
text(xmin-0.15*xrange, ply(6), 'Pitch Circle');
text(xmin-0.15*xrange, bly(6), 'Blank Circle');
title('Motion of Rack Relative to Gear');

% plot the rack in different positions

for k=1:1:npos
	set(hobline(k), 'xdata', racktx(k,:), 'ydata', rackty(k,:));
end
