% shake.m
% MATLAB program for balancing a slider-crank mechanism

%Variables

%   r1=frame length
%   r2=crank length
%   r3=coupler length
%   r4=rocker length
%   cpad=coupler angle (rad) (to point D2 from the rocker pin)
%   Q1=frame angle (deg)
%   Q11=frame angle (rad)
%   Q2=crank angle (rad)
%   Q21=crank angle (deg)
%   Q22=crank angle (deg) (vector)
%   Q3,Q33=coupler angle (deg)
%   Q4,Q44=rocker angle (deg)
%   w2=angular velocity of the crank (rad/sec)
%   w22=w2 (vector)
%   w33=angular velocity of the coupler (rad/sec)
%   w44=angular velocity of the rocker (rad/sec)
%   mode = assembly mode
%   tt=number of cycles to animate
%   dt=number of animation positions per revolution
%   itotal=number of animation positions
%   cycle=number of cycles as an integer
%   bush1,bush2=x,y coordinates of the bushings
%   cir1,cir2=x,y coordinates of the circles inside the bushings
%   Bx,By=x,y coordinates of the crank pin
%   Cx,Cy=x,y coordinates of the rocker pin
%   Bx2,By2=x,y coordinates of the crank pointer
%   Cx2,Cy2=x,y coordinates of the rocker pointer
%   d2r,r2d=conversion factors between radians and degrees
%   i=counting variable
%	W2= weight of the crank
%	R2= distance from O2 to crank CG
%	W3= weight of the coupler
%	R3= distance from coupler CG to point A
%	W4= weight of the piston
%	Wcb= counter balance weight
%	g= acceleration of gravity


%Graphics variables
%   xmin,xmax,ymin,ymax=axes limits
%   h1=handle on the first axes in the window (crank angle vs. slider displacement)
%   h2=handle on the second axes in the window (crank angle vs. slider velocity)
%   h3=handle on the third axes in the window (crank angle vs. input torque)
%   h4=handle on the fourth axes in the window (linkage animation)
%   displ=line representing the crank angle vs. rocker angle
%   vel=line representing the crank angle vs. rocker velocity
%   dbead=bead which follows the crank angle/slider displacement throughout animation
%   vbead=bead which follows the crank angle/slider velocity throughout animation
%   sbead=bead which follows the shaking force plot throughout animation
%   bushy1=line representing the bushing at the crank hinge
%   circ1=line representing the circle inside the bushing at the crank hinge 
%   joint1=line representing the joint at the crank pin 
%   joint2=line representing the joint at the rocker pin
%   crank=line representing the crank 
%   coupler=line representing the coupler
%   couplerptr=line representing the coupler point
%   couplerpt1=line from the crank pin to the coupler point one

% Program  

clf;
clear all;
ans='y';
disp('   ')
disp('    Slider-Crank Analysis Program to Determine Shaking Forces')

% Input values for linkage variables

readmode=input('Enter 1 for file input and 2 for interactive input [1]: ');
if isempty(readmode); readmode=1; end
inputfile=input('Enter input file name (shake.dat): ', 's');
if isempty(inputfile); inputfile = 'shake.dat'; end
if readmode==1
	fid = fopen(inputfile);
end
if readmode==2
	tt=input('Enter number of cycles (rev) [3]: ');
	if isempty(tt);tt = 3; end
	r2=input('Enter the crank length [4]: ');
	if isempty(r2);r2 = 4;end
	r3=input('Enter the coupler length [14]: ');
	if isempty(r3); r3 = 14;end
	mode=input('Enter the assembly mode (+1 or -1) [1]: ');
	if isempty(mode);mode = 1;end
	w2=input('Enter the angular velocity of crank(rad/sec) [4]: ');
	if isempty(w2); w2 = 104.719755; end
	W2=input('Enter the weight of the crank [1.875]: ');
	if isempty(W2); W2 = 3.75; end
	R2=input('Enter distance from O2 to crank CG [2]: ');
	if isempty(R2); R2 = 4; end
	W3=input('Enter the weight of the coupler [34]: ');
	if isempty(W3); W3 = 34; end
	R3=input('Enter distance from coupler CG to point A [4]: ');
	if isempty(R3); R3 = 4; end
	W4=input('Enter the weight of the piston [20]: ');
	if isempty(W4); W4 = 20; end
	Wcb=input('Enter the counter balance weight [47.85]: ');
	if isempty(Wcb); Wcb = 47.85; end
	g=input('Enter the acceleration of gravity [386]: ');
	if isempty(g); g = 386; end
	
% save the data to the file sliderio.dat
	
	temp1(1)=tt;
	temp1(2)=r2;
	temp1(3)=r3;
	temp1(4)=mode;
	temp1(5)=w2;
	temp1(6)=W2;
	temp1(7)=R2; 
	temp1(8)=W3; 
	temp1(9)=R3; 
	temp1(10)=W4;
	temp1(11)=Wcb;
	temp1(12)=g;
	temp1t=temp1(:);  % store the transpose of tempio for ease of reading	
	fprintf(inputfile,'%f \n',temp1t)
end

% Read input data from the file fourbario.dat

if readmode==1	
	sliderio = fscanf(fid,'%f');
	tt=sliderio(1);
	r2=sliderio(2);
	r3=sliderio(3);
	mode=sliderio(4);
	w2=sliderio(5);
	W2=sliderio(6);
	R2=sliderio(7);
	W3=sliderio(8);
	R3=sliderio(9);
	W4=sliderio(10);
	Wcb=sliderio(11);	
	g=sliderio(12);
end
fclose('all');
disp(' ');
disp(' ');
driver=1;
r4=0;
times=1;
Q1=0;

disp(' ');
fprintf('    tt      r2      r3      mode    w2')
disp(' ');
fprintf(' %6.3f  %6.3f  %6.3f  %6.3f  %6.3f \n \n', tt, r2, r3,mode, w2 )
disp(' ');
fprintf('    W2      R2      W3      R3      W4') 
disp(' ');
fprintf(' %6.3f  %6.3f  %6.3f  %6.3f  %6.3f \n', W2, R2, W3, R3, W4 )
disp(' ');
fprintf('    Wcb     g')
disp(' ');
fprintf(' %6.3f  %6.3f  \n',  Wcb, g )

% Define constants

i=0;
d2r=pi/180;
r2d=180/pi;
Q11=Q1*d2r;
[qstart, qstop]=sc_angle_limits_cr(r2,r3,r4,Q1); 
npos=100;
dq=(qstop-qstart)/(npos-1);
Astar=[0;0];
rpivot=0.15*r2;
delta=0.3*r2;
QM1=qstart-dq;	

% Compute the masses at points A and B

mA=(W2/g)*(R2/r2);
mAprime=(W3/g)*(r3-R3)/r3;
mBprime=(W3/g)*(R3/r3);
MA0=mA+mAprime;
MA=MA0-Wcb/g;
MB=mBprime+W4/g;

% Loop to analyze the linkage for tt full cycles

for motion=1:1:npos
	QM1=QM1+dq;
	i=i+1;
	QM = QM1*d2r;

% Call function to compute the position

	para = sldcrkc(r2,r3,r4,QM1,w2,0,mode,Q1,3);
	
	Q2=para(6);
	if Q2<0; Q2=Q2+360; end
	Q22(i)=Q2;
	w22(i)=para(14);
	Q3=para(7);
	Q33(i)=Q3;
	w33(i)=para(15);
	r1(i)=para(1);
	rd1(i)=para(9);
	Addx(i)=para(33);
	Addy(i)=para(34);
	Bddx(i)=para(35);
	Bddy(i)=para(36);	
	assem=para(37);
	
% Compute the shaking force components
	fBx(i)=-MB*Bddx(i);
	fBy(i)=-MB*Bddy(i);
	fsx(i)=-MA*Addx(i)+fBx(i);
	fsy(i)=-MA*Addy(i)+fBy(i);
	fsx0(i)=-MA0*Addx(i)+fBx(i);
	fsy0(i)=-MA0*Addy(i)+fBy(i);
	fstotal(i)=sqrt(fsx(i)^2+fsy(i)^2);
	fstotal0(i)=sqrt(fsx0(i)^2+fsy0(i)^2);

% Store position information in matrices.

	Bx(i)= para(25);
	By(i)= para(26);
	Cx(i)= para(27);
	Cy(i)= para(28);

% Locate the slider block coordinates

	xpin=Cx(i);
	ypin=Cy(i);
	height=delta;
	length=2*height;
	coords = rect(length,height,xpin,ypin,Q1,0);
	for j=1:1:5
		xblocka(i,j)=coords(j,1);
		yblocka(i,j)=coords(j,2);
	end
end

% Print the maximum value of the shaking force for Wcg=0 to the screen.

[fsmax0,j]=max(fstotal0);
disp(' ')
disp(' ')
fprintf	('The maximum shaking force corresponding to Wcb=0 is %10.2f \n',fsmax0)
fprintf ('at theta = %10.2f \n',Q22(j))

% Print the maximum value of the shaking force for the given value for Wcg 
% to the screen.

[fsmax,j]=max(fstotal);
disp(' ')
disp(' ')
fprintf	('The maximum shaking force corresponding to Wcb is %10.2f \n',fsmax)
fprintf ('at theta = %10.2f \n',Q22(j))
fclose('all');
itotal=i;

% ************************************************************************
% Optimization of shaking force.

% Find the optimum counter balance force using the golden section
% method.

x(1)=0;
x(4)=(W2+W3+W4)/g;
tau=(sqrt(5)-1)/2;
x(2)=x(4)-tau*x(4);
x(3)=x(1)+tau*x(4);

% Compute the shaking force at the three initial points

for k=1:1:4
	if k==1; MA=MA0-x(1);end
	if k==2; MA=MA0-x(2);end
	if k==3; MA=MA0-x(3);end
	if k==4; MA=MA0-x(4);end
	for j=1:1:npos
		fsxo(j)=-MA*Addx(j)+fBx(j);
		fsyo(j)=-MA*Addy(j)+fBy(j);
		fstotalo(j)=sqrt(fsxo(j)^2+fsyo(j)^2);
	end
	if k==1; f(1)=max(fstotalo);end
	if k==2; f(2)=max(fstotalo);end
	if k==3; f(3)=max(fstotalo);end
	if k==4; f(4)=max(fstotalo);end
end

% Make n function evaluations to find the optimum

for k=1:1:20
	[fmin,i]=min(f);
	if i==1;
		dx=x(3)-x(2);
		x(4)=x(3);f(4)=f(3);
		x(3)=x(2);f(3)=f(2);
		x(2)=x(1)+dx;
		MA=MA0-x(2);
		for j=1:1:npos
			fsxo(j)=-MA*Addx(j)+fBx(j);
			fsyo(j)=-MA*Addy(j)+fBy(j);
			fstotalo(j)=sqrt(fsxo(j)^2+fsyo(j)^2);
		end
		f(2)=max(fstotalo);
	end
	if i==2
		dx=x(3)-x(2);
		x(4)=x(3);f(4)=f(3);
		x(3)=x(2);f(3)=f(2);
		x(2)=x(1)+dx;
		MA=MA0-x(2);
		for j=1:1:npos
			fsxo(j)=-MA*Addx(j)+fBx(j);
			fsyo(j)=-MA*Addy(j)+fBy(j);
			fstotalo(j)=sqrt(fsxo(j)^2+fsyo(j)^2);
		end
		f(2)=max(fstotalo);
	end
	if i==3
		dx=x(3)-x(2);
		x(1)=x(2);f(1)=f(2);
		x(2)=x(3);f(2)=f(3);
		x(3)=x(4)-dx;
		MA=MA0-x(3);
		for j=1:1:npos
			fsxo(j)=-MA*Addx(j)+fBx(j);
			fsyo(j)=-MA*Addy(j)+fBy(j);
			fstotalo(j)=sqrt(fsxo(j)^2+fsyo(j)^2);
		end
		f(3)=max(fstotalo);
	end
	if i==4;
		dx=x(3)-x(2);
		x(1)=x(2);f(1)=f(2);
		x(2)=x(3);f(2)=f(3);
		x(3)=x(4)-dx;
		MA=MA0-x(3);
		for j=1:1:npos
			fsxo(j)=-MA*Addx(j)+fBx(j);
			fsyo(j)=-MA*Addy(j)+fBy(j);
			fstotalo(j)=sqrt(fsxo(j)^2+fsyo(j)^2);
		end
		f(3)=max(fstotalo);
	end
end
[y,i]=min(f);
Wcbm=x(i)*g;
MA=MA0-x(i);

% Compute the shaking force

for j=1:1:npos
	fsxo(j)=-MA*Addx(j)+fBx(j);
	fsyo(j)=-MA*Addy(j)+fBy(j);
	fstotalo(j)=sqrt(fsxo(j)^2+fsyo(j)^2);
end
[optsf,j]=max(fstotalo);
optcb=Wcbm;

% ********************************************************************

disp(' ')
fprintf	('The optimum counter balance weight is %10.2f \n',optcb)
fprintf	('The corresponding maximum shaking force is %10.2f \n',optsf)
fprintf ('at theta = %10.2f \n',Q22(j))
disp(' ')

% Compute shaking force with optimum counterbalance

MA=mA+mAprime-optcb/g;
for j=1:1:npos
	fAxo=-MA*Addx(j);
	fAyo=-MA*Addy(j);
	fsxo(j)=fAxo+fBx(j);
	fsyo(j)=fAyo+fBy(j);
end

% Determine the coordinates of the slider line				

smax=max(r1);
smin=min(r1);	
cmin=min(Cx);
cymin=min(Cy);
length1=smax-smin+length;
ndash=20;
csang=cos(Q11);
ssang=sin(Q11);	
xe = cmin-(0.5*length)*csang;
ye = cymin-(0.5*length)*ssang;
slflag=1;
coord=frameline(length1,xe,ye,ndash,Q1,slflag);					
npoints1=3*ndash;
					
% Offset slider line by half the height of the slider block.
					
for i=1:1:npoints1
	xsl1(i)=coord(i,1)+(0.6*height)*ssang;
	ysl1(i)=coord(i,2)-(0.6*height)*csang;
end					

% Define the axes for the graph showing the slider-crank mechanism

clf;
h0=axes('position', [.05 .05 .95 .95],'box', 'on', 'xcolor','k','ycolor','k');
set(gcf,'color', 'w');;
	   
% Define the pin and bushing coordinates
	
bush=bushing(r2/20,0,0,20,0);
cir1=circle2(r2/20,0,0,20);

% Find the limits for the plots

xmina=min([min(Bx) min(Cx) min(bush(:,1)) ...
      min(xsl1) min(xblocka)]);
xmaxa=max([max(Bx) max(Cx) max(bush(:,1)) ...
      max(xsl1) max(xblocka)]);
ymina=min([min(By) min(Cy) min(bush(:,2)) ...
      min(ysl1) min(yblocka)]);
ymaxa=max([max(By) max(Cy) max(bush(:,2)) ...
      max(ysl1) max(yblocka)]);
xmin=xmina-0.05*abs(xmaxa-xmina);
xmax=xmaxa+0.05*abs(xmaxa-xmina);
ymin=ymina-0.05*abs(ymaxa-ymina);
ymax=ymaxa+0.05*abs(ymaxa-ymina);
axis([xmin xmax ymin ymax]);
axis('equal')
	    
% Set up the vectors needed to draw the linkage

joint1=line('xdata', [], 'ydata', [], 'marker', 'o', ...
        'erasemode', 'xor', 'color', 'k');
joint2=line('xdata', [], 'ydata', [], 'marker', 'o', ...
       'erasemode', 'xor', 'color', 'k');
block=line('xdata', [], 'ydata', [], 'linewidth',2,'erasemode', ...
       'xor', 'color', 'k');
crank=line('xdata', [], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
       'xor','color', 'k');
coupler=line('xdata', [], 'ydata' ,[], 'linewidth',2, 'erasemode', ...
       'xor','color', 'k');
bush1=line('xdata', bush(:,1), 'ydata',bush(:,2), 'linestyle', '-', ...
        'color', 'r');
circ1=line('xdata', cir1(:,1), 'ydata',cir1(:,2), 'linestyle', '-',...
        'color', 'r');
sliderline1=line('xdata', [], 'ydata',[], 'linestyle', '-', ...
        'color', 'r');

% Plot the of the linkage alone

ans='y';

% Draw the frame line.

set(sliderline1, 'xdata', xsl1, 'ydata', ysl1);

% Animate the linkage as long as ans = 'y'
	
timesink=10;
while ans=='y'
	for j=1:1:tt
		for i=1:1:itotal
			set(joint1,'xdata', Bx(i), 'ydata',By(i));
			set(joint2,'xdata', Cx(i), 'ydata',Cy(i));
			set(crank,'xdata',[0 Bx(i)],'ydata', [0 By(i)]);
			set(coupler,'xdata', [Bx(i) Cx(i)],'ydata', [By(i) Cy(i)]);
			set(block,'xdata', [xblocka(i,:)],'ydata', [yblocka(i,:)]);
			drawnow;   %flush the draw buffer

% Do meaningless calculation to slow down the linkage

			for k=1:1:timesink
				zzz=log10(k);
			end
		end
	end

% Plot linkage in fixed position.

	i = 6;
	set(joint1,'xdata', Bx(i), 'ydata',By(i));
	set(joint2,'xdata', Cx(i), 'ydata',Cy(i));
	set(crank,'xdata',[0 Bx(i)],'ydata', [0 By(i)]);
	set(coupler,'xdata', [Bx(i) Cx(i)],'ydata', [By(i) Cy(i)]);
	set(block,'xdata', [xblocka(i,:)],'ydata', [yblocka(i,:)]);
   
%flush the draw buffer

	drawnow; 
		
% Ask if animation should be repeated

	ans=input('Repeat animation? y/n [y]: ','s');
	if isempty(ans);ans='y';end
	if ans=='y'
		rep=input('Change animation speed? (+/-/0) [-]:','s');
		if isempty(rep);rep='-';end
		if rep=='+'; timesink=timesink/10; end
		if rep=='-'; timesink=timesink*10; end
		if timesink<1; timesink=1; end
	end
end

% Pause the graphics before showing four plots per graph

pause;
clf;

% Identify the variable that is the input

inputv=Q22;

% Define the axes for the graph in the position (1,2)-shaking 
% force for given Wcg

width=0.40;
height=0.30;

h1=axes('position', [0.45 .55 width height],'box', 'on','xcolor','k','ycolor','k');
set(gca,'color', 'w');   %axis location
xlabel('Shaking Force \itx\rm (given Wcb)','color','k'); 
ylabel('Shaking Force \ity\rm (given Wcb)','color', 'k')
shakef=line('xdata', [], 'ydata', [], 'linewidth' ,1,'erasemode', ...
       'none', 'color', 'r');
origin=line('xdata', [], 'ydata', [], 'linewidth' ,1, 'erasemode', 'none', ...
	'color', 'r', 'marker', '+','markersize', 6);	
sbead=line('xdata', [], 'ydata', [],'marker','o','markersize', 5, ...
	'erasemode','xor','color', 'k','linewidth' ,1);
sline=line('xdata', [], 'ydata', [],'linestyle','-', ...
	'erasemode','xor','color', 'k','linewidth' ,1);

% Define the axes for the graph in the position (2,1)-shaking force for Wcg=0.

h2=axes('position', [0.45 .1 width height],'box', 'on','xcolor','k','ycolor','k');
set(gca,'color', 'w');
xlabel('Shaking Force \itx\rm (opt Wcb)','color','k'); 
ylabel('Shaking Force \ity\rm (opt Wcb)','color', 'k')
shakefo=line('xdata', [], 'ydata', [], 'linewidth' ,1,'erasemode', ...
       'none', 'color', 'r');
origino=line('xdata', [], 'ydata', [], 'linewidth' ,1, 'erasemode', 'none', ...
	'color', 'r', 'marker', '+','markersize', 6);	
sbeado=line('xdata', [], 'ydata', [],'marker','o','markersize', 5, ...
	'erasemode','xor','color', 'k','linewidth' ,1);
slineo=line('xdata', [], 'ydata', [],'linestyle','-', ...
	'erasemode','xor','color', 'k','linewidth' ,1);

% Define the axes for the graph in the position (2,2)-shaking force for 
% optimum Wcg.

h3=axes('position', [0.05 0.1 width height],'box', 'on','xcolor','k','ycolor','k');
set(gca,'color', 'w');
xlabel('Shaking Force \itx\rm (zero Wcb)','color','k'); 
ylabel('Shaking Force \ity\rm (zero Wcb)','color','k')
shakef0=line('xdata', [], 'ydata', [], 'linewidth' ,1,'erasemode', ...
       'none', 'color', 'r');
origin0=line('xdata', [], 'ydata', [], 'linewidth' ,1, 'erasemode', 'none', ...
	'color', 'r', 'marker', '+','markersize', 6);	
sbead0=line('xdata', [], 'ydata', [],'marker','o','markersize', 5, ...
	'erasemode','xor','color', 'k','linewidth' ,1);
sline0=line('xdata', [], 'ydata', [],'linestyle','-', ...
	'erasemode','xor','color', 'k','linewidth' ,1);

% Define the axes for the graph in the (1,1) position - linkage position

h4=axes('position', [0.05 .55 width height],'box', 'on', 'xcolor','k','ycolor','k');
set(gca,'color', 'w');
axis equal;
values=axisadjust(xmin, xmax, ymin, ymax, width, height);
xmin=values(1);
xmax=values(2);
ymin=values(3);
ymax=values(4);
axis([xmin xmax ymin ymax]);
     
% Set up the vectors needed to draw the linkage

joint1=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
       5, 'erasemode', 'xor', 'color', 'k');
joint2=line('xdata', [], 'ydata', [], 'marker', 'o','markersize', ...
       5, 'erasemode', 'xor', 'color', 'k');
gridpt=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
       'xor','markersize',5,'color', 'r', 'marker', 'o');	
block=line('xdata', [], 'ydata', [], 'linewidth' ,1,'erasemode', ...
       'xor', 'color', 'k');
crank=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
       'xor','color', 'k');
coupler=line('xdata', [], 'ydata' ,[], 'linewidth' ,1, 'erasemode', ...
       'xor','color', 'k');
bush1=line('xdata', bush(:,1), 'ydata',bush(:,2), 'linestyle', '-', 'markersize', 10,...
        'color', 'r');
circ1=line('xdata', cir1(:,1), 'ydata',cir1(:,2), 'linestyle', '-', 'markersize', 10,...
        'color', 'r');
sliderline1=line('xdata', [], 'ydata',[], 'linestyle', '-', ...
        'color', 'r');

% Draw four plots on one graph.  Start by setting the axis limits for the graphs

axes(h3);
min1=min(fsx0);
max1=max(fsx0);
min2=min(fsy0);
max2=max(fsy0);
rangex=max1-min1;
minx=min1-0.02*rangex;
maxx=max1+0.02*rangex;
rangey=max2-min2;
miny=min2-0.02*rangey;
maxy=max2+0.02*rangey;
axis equal;
values=axisadjust(minx, maxx, miny, maxy, width, height);
minx=values(1);
maxx=values(2);
miny=values(3);
maxy=values(4);
axis([minx maxx miny maxy]); 

axes(h1);
axis equal;
axis([minx maxx miny maxy]); 

axes(h2);
axis equal;
axis([minx maxx miny maxy]); 

% Plot the results.

ans='y';
	
% Draw the fixed curves first.

set(sliderline1, 'xdata', xsl1, 'ydata', ysl1);
set(shakef,'xdata', fsx,'ydata', fsy);
set(shakefo,'xdata', fsxo,'ydata', fsyo);
set(shakef0,'xdata', fsx0,'ydata', fsy0);
set(origino,'xdata', 0,'ydata', 0);
set(origin0,'xdata', 0,'ydata', 0);
set(origin,'xdata', 0,'ydata', 0);

% Animate the results as long as ans = 'y'

while ans=='y'
	for k=1:1:tt
		for i=1:1:itotal
			set(joint1,'xdata', Bx(i), 'ydata',By(i));
			set(joint2,'xdata', Cx(i), 'ydata',Cy(i));
			set(crank,'xdata',[0 Bx(i)],'ydata', [0 By(i)]);
			set(coupler,'xdata', [Bx(i) Cx(i)],'ydata', [By(i) Cy(i)]);
			set(block,'xdata', [xblocka(i,:)],'ydata', [yblocka(i,:)]);

  			set(sbead0, 'xdata', fsx0(i), 'ydata', fsy0(i));
 			set(sline0, 'xdata', [0,fsx0(i)], 'ydata', [0,fsy0(i)]);			

  			set(sbead, 'xdata', fsx(i), 'ydata', fsy(i));
  			set(sline, 'xdata', [0,fsx(i)], 'ydata', [0,fsy(i)]);			

  			set(sbeado, 'xdata', fsxo(i), 'ydata', fsyo(i));
  			set(slineo, 'xdata', [0,fsxo(i)], 'ydata', [0,fsyo(i)]);			
			drawnow;   %flush the draw buffer
		end
	end

% Plot figures in final position.

	i = 6;

% Plot position first

	set(joint1,'xdata', Bx(i), 'ydata',By(i));
	set(joint2,'xdata', Cx(i), 'ydata',Cy(i));
	set(crank,'xdata',[0 Bx(i)],'ydata', [0 By(i)]);
	set(coupler,'xdata', [Bx(i) Cx(i)],'ydata', [By(i) Cy(i)]);
	set(block,'xdata', [xblocka(i,:)],'ydata', [yblocka(i,:)]);
   
% Plot Torque information

 	set(sbead0, 'xdata', fsx0(i), 'ydata', fsy0(i));
 	set(sline0, 'xdata', [0,fsx0(i)], 'ydata', [0,fsy0(i)]);			
 
% Plot angle information

 	set(sbead, 'xdata', fsx(i), 'ydata', fsy(i));
 	set(sline, 'xdata', [0,fsx(i)], 'ydata', [0,fsy(i)]);			

% Plot velocity information

 	set(sbeado, 'xdata', fsxo(i), 'ydata', fsyo(i));
 	set(slineo, 'xdata', [0,fsxo(i)], 'ydata', [0,fsyo(i)]);			

%flush the draw buffer

	drawnow; 

% Ask if the animation should be repeated

	ans=input('Repeat animation? y/n [y]: ', 's');
	if isempty(ans);
		ans='y';
	end
end



